Class: Google::Cloud::ApiHub::V1::APIMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/collect_service.rb

Overview

The API metadata.

Instance Attribute Summary collapse

Instance Attribute Details

#api::Google::Cloud::ApiHub::V1::Api

Returns Required. The API resource to be pushed to Hub's collect layer. The ID of the API resource will be generated by Hub to ensure uniqueness across all APIs across systems.

Returns:

  • (::Google::Cloud::ApiHub::V1::Api)

    Required. The API resource to be pushed to Hub's collect layer. The ID of the API resource will be generated by Hub to ensure uniqueness across all APIs across systems.



88
89
90
91
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 88

class APIMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#original_create_time::Google::Protobuf::Timestamp

Returns Optional. Timestamp indicating when the API was created at the source.

Returns:



88
89
90
91
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 88

class APIMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#original_id::String

Returns Optional. The unique identifier of the API in the system where it was originally created.

Returns:

  • (::String)

    Optional. The unique identifier of the API in the system where it was originally created.



88
89
90
91
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 88

class APIMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#original_update_time::Google::Protobuf::Timestamp

Returns Required. Timestamp indicating when the API was last updated at the source.

Returns:



88
89
90
91
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 88

class APIMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#versions::Array<::Google::Cloud::ApiHub::V1::VersionMetadata>

Returns Optional. The list of versions present in an API resource.

Returns:



88
89
90
91
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 88

class APIMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end