Module: Google::Cloud::ApiHub::V1::ApiHubCollect

Defined in:
lib/google/cloud/api_hub/v1/api_hub_collect.rb,
lib/google/cloud/api_hub/v1/api_hub_collect/rest.rb,
lib/google/cloud/api_hub/v1/api_hub_collect/paths.rb,
lib/google/cloud/api_hub/v1/api_hub_collect/credentials.rb,
lib/google/cloud/api_hub/v1/api_hub_collect/rest/client.rb,
lib/google/cloud/api_hub/v1/api_hub_collect/rest/operations.rb,
lib/google/cloud/api_hub/v1/api_hub_collect/rest/service_stub.rb

Overview

This service exposes methods used for collecting various types of data from different first party and third party sources and push it to Hub's collect layer.

To load this service and instantiate a REST client:

require "google/cloud/api_hub/v1/api_hub_collect/rest"
client = ::Google::Cloud::ApiHub::V1::ApiHubCollect::Rest::Client.new

Defined Under Namespace

Modules: Paths, Rest Classes: Credentials