Class: Google::Cloud::ApiHub::V1::ApiHubCollect::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ApiHubCollect::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/api_hub/v1/api_hub_collect/rest/client.rb
Overview
REST client for the ApiHubCollect service.
This service exposes methods used for collecting various types of data from different first party and third party sources and push it to Hub's collect layer.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
-
#operations_client ⇒ ::Google::Cloud::ApiHub::V1::ApiHubCollect::Rest::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the ApiHubCollect Client class.
Instance Method Summary collapse
-
#collect_api_data(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Collect API data from a source and push it to Hub's collect layer.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the ApiHubCollect Client instance.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new ApiHubCollect REST client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#api_operation_path, #api_path, #attribute_path, #definition_path, #deployment_path, #location_path, #plugin_instance_path, #spec_path, #version_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new ApiHubCollect REST client object.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/google/cloud/api_hub/v1/api_hub_collect/rest/client.rb', line 129 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = ::Google::Cloud::ApiHub::V1::ApiHubCollect::Rest::Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @api_hub_collect_stub = ::Google::Cloud::ApiHub::V1::ApiHubCollect::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @api_hub_collect_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @api_hub_collect_stub.endpoint config.universe_domain = @api_hub_collect_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @api_hub_collect_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
199 200 201 |
# File 'lib/google/cloud/api_hub/v1/api_hub_collect/rest/client.rb', line 199 def location_client @location_client end |
#operations_client ⇒ ::Google::Cloud::ApiHub::V1::ApiHubCollect::Rest::Operations (readonly)
Get the associated client for long-running operations.
192 193 194 |
# File 'lib/google/cloud/api_hub/v1/api_hub_collect/rest/client.rb', line 192 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the ApiHubCollect Client class.
See Configuration for a description of the configuration fields.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/google/cloud/api_hub/v1/api_hub_collect/rest/client.rb', line 67 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "ApiHub", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#collect_api_data(request, options = nil) ⇒ ::Gapic::Operation #collect_api_data(location: nil, collection_type: nil, plugin_instance: nil, action_id: nil, api_data: nil) ⇒ ::Gapic::Operation
Collect API data from a source and push it to Hub's collect layer.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/google/cloud/api_hub/v1/api_hub_collect/rest/client.rb', line 276 def collect_api_data request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ApiHub::V1::CollectApiDataRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.collect_api_data..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ApiHub::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.collect_api_data.timeout, metadata: , retry_policy: @config.rpcs.collect_api_data.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @api_hub_collect_stub.collect_api_data request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the ApiHubCollect Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
99 100 101 102 |
# File 'lib/google/cloud/api_hub/v1/api_hub_collect/rest/client.rb', line 99 def configure yield @config if block_given? @config end |
#logger ⇒ Logger
The logger used for request/response debug logging.
206 207 208 |
# File 'lib/google/cloud/api_hub/v1/api_hub_collect/rest/client.rb', line 206 def logger @api_hub_collect_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
109 110 111 |
# File 'lib/google/cloud/api_hub/v1/api_hub_collect/rest/client.rb', line 109 def universe_domain @api_hub_collect_stub.universe_domain end |