Class: Google::Cloud::ApiHub::V1::ApiHubDiscovery::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/api_hub/v1/api_hub_discovery/rest/client.rb

Overview

REST client for the ApiHubDiscovery service.

This service exposes methods used to manage DiscoveredApiObservations and DiscoveredApiOperations.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#discovered_api_observation_path, #discovered_api_operation_path, #location_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new ApiHubDiscovery REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::ApiHub::V1::ApiHubDiscovery::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::ApiHub::V1::ApiHubDiscovery::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the ApiHubDiscovery client.

Yield Parameters:



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/google/cloud/api_hub/v1/api_hub_discovery/rest/client.rb', line 128

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @api_hub_discovery_stub = ::Google::Cloud::ApiHub::V1::ApiHubDiscovery::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @api_hub_discovery_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @api_hub_discovery_stub.endpoint
    config.universe_domain = @api_hub_discovery_stub.universe_domain
    config.bindings_override = @config.bindings_override
    config.logger = @api_hub_discovery_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Rest::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Rest::Client)


184
185
186
# File 'lib/google/cloud/api_hub/v1/api_hub_discovery/rest/client.rb', line 184

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the ApiHubDiscovery Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all ApiHubDiscovery clients
::Google::Cloud::ApiHub::V1::ApiHubDiscovery::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/google/cloud/api_hub/v1/api_hub_discovery/rest/client.rb', line 66

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "ApiHub", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the ApiHubDiscovery Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



98
99
100
101
# File 'lib/google/cloud/api_hub/v1/api_hub_discovery/rest/client.rb', line 98

def configure
  yield @config if block_given?
  @config
end

#get_discovered_api_observation(request, options = nil) ⇒ ::Google::Cloud::ApiHub::V1::DiscoveredApiObservation #get_discovered_api_observation(name: nil) ⇒ ::Google::Cloud::ApiHub::V1::DiscoveredApiObservation

Gets a DiscoveredAPIObservation in a given project, location and ApiObservation.

Examples:

Basic example

require "google/cloud/api_hub/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::ApiHub::V1::ApiHubDiscovery::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::ApiHub::V1::GetDiscoveredApiObservationRequest.new

# Call the get_discovered_api_observation method.
result = client.get_discovered_api_observation request

# The returned object is of type Google::Cloud::ApiHub::V1::DiscoveredApiObservation.
p result

Overloads:

  • #get_discovered_api_observation(request, options = nil) ⇒ ::Google::Cloud::ApiHub::V1::DiscoveredApiObservation

    Pass arguments to get_discovered_api_observation via a request object, either of type GetDiscoveredApiObservationRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::ApiHub::V1::GetDiscoveredApiObservationRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_discovered_api_observation(name: nil) ⇒ ::Google::Cloud::ApiHub::V1::DiscoveredApiObservation

    Pass arguments to get_discovered_api_observation via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the DiscoveredApiObservation to retrieve. Format: projects/{project}/locations/{location}/discoveredApiObservations/{discovered_api_observation}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/google/cloud/api_hub/v1/api_hub_discovery/rest/client.rb', line 341

def get_discovered_api_observation request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ApiHub::V1::GetDiscoveredApiObservationRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_discovered_api_observation..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::ApiHub::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_discovered_api_observation.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_discovered_api_observation.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @api_hub_discovery_stub.get_discovered_api_observation request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_discovered_api_operation(request, options = nil) ⇒ ::Google::Cloud::ApiHub::V1::DiscoveredApiOperation #get_discovered_api_operation(name: nil) ⇒ ::Google::Cloud::ApiHub::V1::DiscoveredApiOperation

Gets a DiscoveredAPIOperation in a given project, location, ApiObservation and ApiOperation.

Examples:

Basic example

require "google/cloud/api_hub/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::ApiHub::V1::ApiHubDiscovery::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::ApiHub::V1::GetDiscoveredApiOperationRequest.new

# Call the get_discovered_api_operation method.
result = client.get_discovered_api_operation request

# The returned object is of type Google::Cloud::ApiHub::V1::DiscoveredApiOperation.
p result

Overloads:

  • #get_discovered_api_operation(request, options = nil) ⇒ ::Google::Cloud::ApiHub::V1::DiscoveredApiOperation

    Pass arguments to get_discovered_api_operation via a request object, either of type GetDiscoveredApiOperationRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::ApiHub::V1::GetDiscoveredApiOperationRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_discovered_api_operation(name: nil) ⇒ ::Google::Cloud::ApiHub::V1::DiscoveredApiOperation

    Pass arguments to get_discovered_api_operation via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the DiscoveredApiOperation to retrieve. Format: projects/{project}/locations/{location}/discoveredApiObservations/{discovered_api_observation}/discoveredApiOperations/{discovered_api_operation}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
# File 'lib/google/cloud/api_hub/v1/api_hub_discovery/rest/client.rb', line 520

def get_discovered_api_operation request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ApiHub::V1::GetDiscoveredApiOperationRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_discovered_api_operation..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::ApiHub::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_discovered_api_operation.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_discovered_api_operation.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @api_hub_discovery_stub.get_discovered_api_operation request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_discovered_api_observations(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ApiHub::V1::DiscoveredApiObservation> #list_discovered_api_observations(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ApiHub::V1::DiscoveredApiObservation>

Lists all the DiscoveredAPIObservations in a given project and location.

Examples:

Basic example

require "google/cloud/api_hub/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::ApiHub::V1::ApiHubDiscovery::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::ApiHub::V1::ListDiscoveredApiObservationsRequest.new

# Call the list_discovered_api_observations method.
result = client.list_discovered_api_observations request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::ApiHub::V1::DiscoveredApiObservation.
  p item
end

Overloads:

  • #list_discovered_api_observations(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ApiHub::V1::DiscoveredApiObservation>

    Pass arguments to list_discovered_api_observations via a request object, either of type ListDiscoveredApiObservationsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::ApiHub::V1::ListDiscoveredApiObservationsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_discovered_api_observations(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ApiHub::V1::DiscoveredApiObservation>

    Pass arguments to list_discovered_api_observations via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent, which owns this collection of ApiObservations. Format: projects/{project}/locations/{location}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of ApiObservations to return. The service may return fewer than this value. If unspecified, at most 10 ApiObservations will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListApiObservations call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListApiObservations must match the call that provided the page token.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/google/cloud/api_hub/v1/api_hub_discovery/rest/client.rb', line 258

def list_discovered_api_observations request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ApiHub::V1::ListDiscoveredApiObservationsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_discovered_api_observations..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::ApiHub::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_discovered_api_observations.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_discovered_api_observations.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @api_hub_discovery_stub.list_discovered_api_observations request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @api_hub_discovery_stub, :list_discovered_api_observations, "discovered_api_observations", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_discovered_api_operations(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ApiHub::V1::DiscoveredApiOperation> #list_discovered_api_operations(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ApiHub::V1::DiscoveredApiOperation>

Lists all the DiscoveredAPIOperations in a given project, location and ApiObservation.

Examples:

Basic example

require "google/cloud/api_hub/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::ApiHub::V1::ApiHubDiscovery::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::ApiHub::V1::ListDiscoveredApiOperationsRequest.new

# Call the list_discovered_api_operations method.
result = client.list_discovered_api_operations request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::ApiHub::V1::DiscoveredApiOperation.
  p item
end

Overloads:

  • #list_discovered_api_operations(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ApiHub::V1::DiscoveredApiOperation>

    Pass arguments to list_discovered_api_operations via a request object, either of type ListDiscoveredApiOperationsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::ApiHub::V1::ListDiscoveredApiOperationsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_discovered_api_operations(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ApiHub::V1::DiscoveredApiOperation>

    Pass arguments to list_discovered_api_operations via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent, which owns this collection of DiscoveredApiOperations. Format: projects/{project}/locations/{location}/discoveredApiObservations/{discovered_api_observation}

    • page_size (::Integer) (defaults to: nil)

      Optional. DiscoveredApiOperations will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListDiscoveredApiApiOperations call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListDiscoveredApiApiOperations must match the call that provided the page token.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
# File 'lib/google/cloud/api_hub/v1/api_hub_discovery/rest/client.rb', line 437

def list_discovered_api_operations request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ApiHub::V1::ListDiscoveredApiOperationsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_discovered_api_operations..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::ApiHub::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_discovered_api_operations.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_discovered_api_operations.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @api_hub_discovery_stub.list_discovered_api_operations request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @api_hub_discovery_stub, :list_discovered_api_operations, "discovered_api_operations", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


191
192
193
# File 'lib/google/cloud/api_hub/v1/api_hub_discovery/rest/client.rb', line 191

def logger
  @api_hub_discovery_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


108
109
110
# File 'lib/google/cloud/api_hub/v1/api_hub_discovery/rest/client.rb', line 108

def universe_domain
  @api_hub_discovery_stub.universe_domain
end