Class: Google::Cloud::ApiHub::V1::ApiHubInstance

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

An ApiHubInstance represents the instance resources of the API Hub. Currently, only one ApiHub instance is allowed for each project.

Defined Under Namespace

Modules: State Classes: Config, LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#config::Google::Cloud::ApiHub::V1::ApiHubInstance::Config

Returns Required. Config of the ApiHub instance.

Returns:



1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1269

class ApiHubInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Available configurations to provision an ApiHub Instance.
  # @!attribute [rw] cmek_key_name
  #   @return [::String]
  #     Optional. The Customer Managed Encryption Key (CMEK) used for data
  #     encryption. The CMEK name should follow the format of
  #     `projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/cryptoKeys/([^/]+)`,
  #     where the location must match the instance location.
  #     If the CMEK is not provided, a GMEK will be created for the instance.
  # @!attribute [rw] disable_search
  #   @return [::Boolean]
  #     Optional. If true, the search will be disabled for the instance. The
  #     default value is false.
  # @!attribute [rw] vertex_location
  #   @return [::String]
  #     Optional. The name of the Vertex AI location where the data store is
  #     stored.
  # @!attribute [rw] encryption_type
  #   @return [::Google::Cloud::ApiHub::V1::ApiHubInstance::Config::EncryptionType]
  #     Optional. Encryption type for the region. If the encryption type is CMEK,
  #     the cmek_key_name must be provided. If no encryption type is provided,
  #     GMEK will be used.
  class Config
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Types of data encryption.
    module EncryptionType
      # Encryption type unspecified.
      ENCRYPTION_TYPE_UNSPECIFIED = 0

      # Default encryption using Google managed encryption key.
      GMEK = 1

      # Encryption using customer managed encryption key.
      CMEK = 2
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the ApiHub Instance.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The ApiHub instance has not been initialized or has been deleted.
    INACTIVE = 1

    # The ApiHub instance is being created.
    CREATING = 2

    # The ApiHub instance has been created and is ready for use.
    ACTIVE = 3

    # The ApiHub instance is being updated.
    UPDATING = 4

    # The ApiHub instance is being deleted.
    DELETING = 5

    # The ApiHub instance encountered an error during a state change.
    FAILED = 6
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Creation timestamp.

Returns:



1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1269

class ApiHubInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Available configurations to provision an ApiHub Instance.
  # @!attribute [rw] cmek_key_name
  #   @return [::String]
  #     Optional. The Customer Managed Encryption Key (CMEK) used for data
  #     encryption. The CMEK name should follow the format of
  #     `projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/cryptoKeys/([^/]+)`,
  #     where the location must match the instance location.
  #     If the CMEK is not provided, a GMEK will be created for the instance.
  # @!attribute [rw] disable_search
  #   @return [::Boolean]
  #     Optional. If true, the search will be disabled for the instance. The
  #     default value is false.
  # @!attribute [rw] vertex_location
  #   @return [::String]
  #     Optional. The name of the Vertex AI location where the data store is
  #     stored.
  # @!attribute [rw] encryption_type
  #   @return [::Google::Cloud::ApiHub::V1::ApiHubInstance::Config::EncryptionType]
  #     Optional. Encryption type for the region. If the encryption type is CMEK,
  #     the cmek_key_name must be provided. If no encryption type is provided,
  #     GMEK will be used.
  class Config
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Types of data encryption.
    module EncryptionType
      # Encryption type unspecified.
      ENCRYPTION_TYPE_UNSPECIFIED = 0

      # Default encryption using Google managed encryption key.
      GMEK = 1

      # Encryption using customer managed encryption key.
      CMEK = 2
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the ApiHub Instance.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The ApiHub instance has not been initialized or has been deleted.
    INACTIVE = 1

    # The ApiHub instance is being created.
    CREATING = 2

    # The ApiHub instance has been created and is ready for use.
    ACTIVE = 3

    # The ApiHub instance is being updated.
    UPDATING = 4

    # The ApiHub instance is being deleted.
    DELETING = 5

    # The ApiHub instance encountered an error during a state change.
    FAILED = 6
  end
end

#description::String

Returns Optional. Description of the ApiHub instance.

Returns:

  • (::String)

    Optional. Description of the ApiHub instance.



1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1269

class ApiHubInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Available configurations to provision an ApiHub Instance.
  # @!attribute [rw] cmek_key_name
  #   @return [::String]
  #     Optional. The Customer Managed Encryption Key (CMEK) used for data
  #     encryption. The CMEK name should follow the format of
  #     `projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/cryptoKeys/([^/]+)`,
  #     where the location must match the instance location.
  #     If the CMEK is not provided, a GMEK will be created for the instance.
  # @!attribute [rw] disable_search
  #   @return [::Boolean]
  #     Optional. If true, the search will be disabled for the instance. The
  #     default value is false.
  # @!attribute [rw] vertex_location
  #   @return [::String]
  #     Optional. The name of the Vertex AI location where the data store is
  #     stored.
  # @!attribute [rw] encryption_type
  #   @return [::Google::Cloud::ApiHub::V1::ApiHubInstance::Config::EncryptionType]
  #     Optional. Encryption type for the region. If the encryption type is CMEK,
  #     the cmek_key_name must be provided. If no encryption type is provided,
  #     GMEK will be used.
  class Config
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Types of data encryption.
    module EncryptionType
      # Encryption type unspecified.
      ENCRYPTION_TYPE_UNSPECIFIED = 0

      # Default encryption using Google managed encryption key.
      GMEK = 1

      # Encryption using customer managed encryption key.
      CMEK = 2
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the ApiHub Instance.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The ApiHub instance has not been initialized or has been deleted.
    INACTIVE = 1

    # The ApiHub instance is being created.
    CREATING = 2

    # The ApiHub instance has been created and is ready for use.
    ACTIVE = 3

    # The ApiHub instance is being updated.
    UPDATING = 4

    # The ApiHub instance is being deleted.
    DELETING = 5

    # The ApiHub instance encountered an error during a state change.
    FAILED = 6
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Instance labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/compute/docs/labeling-resources.

Returns:



1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1269

class ApiHubInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Available configurations to provision an ApiHub Instance.
  # @!attribute [rw] cmek_key_name
  #   @return [::String]
  #     Optional. The Customer Managed Encryption Key (CMEK) used for data
  #     encryption. The CMEK name should follow the format of
  #     `projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/cryptoKeys/([^/]+)`,
  #     where the location must match the instance location.
  #     If the CMEK is not provided, a GMEK will be created for the instance.
  # @!attribute [rw] disable_search
  #   @return [::Boolean]
  #     Optional. If true, the search will be disabled for the instance. The
  #     default value is false.
  # @!attribute [rw] vertex_location
  #   @return [::String]
  #     Optional. The name of the Vertex AI location where the data store is
  #     stored.
  # @!attribute [rw] encryption_type
  #   @return [::Google::Cloud::ApiHub::V1::ApiHubInstance::Config::EncryptionType]
  #     Optional. Encryption type for the region. If the encryption type is CMEK,
  #     the cmek_key_name must be provided. If no encryption type is provided,
  #     GMEK will be used.
  class Config
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Types of data encryption.
    module EncryptionType
      # Encryption type unspecified.
      ENCRYPTION_TYPE_UNSPECIFIED = 0

      # Default encryption using Google managed encryption key.
      GMEK = 1

      # Encryption using customer managed encryption key.
      CMEK = 2
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the ApiHub Instance.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The ApiHub instance has not been initialized or has been deleted.
    INACTIVE = 1

    # The ApiHub instance is being created.
    CREATING = 2

    # The ApiHub instance has been created and is ready for use.
    ACTIVE = 3

    # The ApiHub instance is being updated.
    UPDATING = 4

    # The ApiHub instance is being deleted.
    DELETING = 5

    # The ApiHub instance encountered an error during a state change.
    FAILED = 6
  end
end

#name::String

Returns Identifier. Format: projects/{project}/locations/{location}/apiHubInstances/{apiHubInstance}.

Returns:

  • (::String)

    Identifier. Format: projects/{project}/locations/{location}/apiHubInstances/{apiHubInstance}.



1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1269

class ApiHubInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Available configurations to provision an ApiHub Instance.
  # @!attribute [rw] cmek_key_name
  #   @return [::String]
  #     Optional. The Customer Managed Encryption Key (CMEK) used for data
  #     encryption. The CMEK name should follow the format of
  #     `projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/cryptoKeys/([^/]+)`,
  #     where the location must match the instance location.
  #     If the CMEK is not provided, a GMEK will be created for the instance.
  # @!attribute [rw] disable_search
  #   @return [::Boolean]
  #     Optional. If true, the search will be disabled for the instance. The
  #     default value is false.
  # @!attribute [rw] vertex_location
  #   @return [::String]
  #     Optional. The name of the Vertex AI location where the data store is
  #     stored.
  # @!attribute [rw] encryption_type
  #   @return [::Google::Cloud::ApiHub::V1::ApiHubInstance::Config::EncryptionType]
  #     Optional. Encryption type for the region. If the encryption type is CMEK,
  #     the cmek_key_name must be provided. If no encryption type is provided,
  #     GMEK will be used.
  class Config
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Types of data encryption.
    module EncryptionType
      # Encryption type unspecified.
      ENCRYPTION_TYPE_UNSPECIFIED = 0

      # Default encryption using Google managed encryption key.
      GMEK = 1

      # Encryption using customer managed encryption key.
      CMEK = 2
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the ApiHub Instance.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The ApiHub instance has not been initialized or has been deleted.
    INACTIVE = 1

    # The ApiHub instance is being created.
    CREATING = 2

    # The ApiHub instance has been created and is ready for use.
    ACTIVE = 3

    # The ApiHub instance is being updated.
    UPDATING = 4

    # The ApiHub instance is being deleted.
    DELETING = 5

    # The ApiHub instance encountered an error during a state change.
    FAILED = 6
  end
end

#state::Google::Cloud::ApiHub::V1::ApiHubInstance::State (readonly)

Returns Output only. The current state of the ApiHub instance.

Returns:



1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1269

class ApiHubInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Available configurations to provision an ApiHub Instance.
  # @!attribute [rw] cmek_key_name
  #   @return [::String]
  #     Optional. The Customer Managed Encryption Key (CMEK) used for data
  #     encryption. The CMEK name should follow the format of
  #     `projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/cryptoKeys/([^/]+)`,
  #     where the location must match the instance location.
  #     If the CMEK is not provided, a GMEK will be created for the instance.
  # @!attribute [rw] disable_search
  #   @return [::Boolean]
  #     Optional. If true, the search will be disabled for the instance. The
  #     default value is false.
  # @!attribute [rw] vertex_location
  #   @return [::String]
  #     Optional. The name of the Vertex AI location where the data store is
  #     stored.
  # @!attribute [rw] encryption_type
  #   @return [::Google::Cloud::ApiHub::V1::ApiHubInstance::Config::EncryptionType]
  #     Optional. Encryption type for the region. If the encryption type is CMEK,
  #     the cmek_key_name must be provided. If no encryption type is provided,
  #     GMEK will be used.
  class Config
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Types of data encryption.
    module EncryptionType
      # Encryption type unspecified.
      ENCRYPTION_TYPE_UNSPECIFIED = 0

      # Default encryption using Google managed encryption key.
      GMEK = 1

      # Encryption using customer managed encryption key.
      CMEK = 2
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the ApiHub Instance.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The ApiHub instance has not been initialized or has been deleted.
    INACTIVE = 1

    # The ApiHub instance is being created.
    CREATING = 2

    # The ApiHub instance has been created and is ready for use.
    ACTIVE = 3

    # The ApiHub instance is being updated.
    UPDATING = 4

    # The ApiHub instance is being deleted.
    DELETING = 5

    # The ApiHub instance encountered an error during a state change.
    FAILED = 6
  end
end

#state_message::String (readonly)

Returns Output only. Extra information about ApiHub instance state. Currently the message would be populated when state is FAILED.

Returns:

  • (::String)

    Output only. Extra information about ApiHub instance state. Currently the message would be populated when state is FAILED.



1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1269

class ApiHubInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Available configurations to provision an ApiHub Instance.
  # @!attribute [rw] cmek_key_name
  #   @return [::String]
  #     Optional. The Customer Managed Encryption Key (CMEK) used for data
  #     encryption. The CMEK name should follow the format of
  #     `projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/cryptoKeys/([^/]+)`,
  #     where the location must match the instance location.
  #     If the CMEK is not provided, a GMEK will be created for the instance.
  # @!attribute [rw] disable_search
  #   @return [::Boolean]
  #     Optional. If true, the search will be disabled for the instance. The
  #     default value is false.
  # @!attribute [rw] vertex_location
  #   @return [::String]
  #     Optional. The name of the Vertex AI location where the data store is
  #     stored.
  # @!attribute [rw] encryption_type
  #   @return [::Google::Cloud::ApiHub::V1::ApiHubInstance::Config::EncryptionType]
  #     Optional. Encryption type for the region. If the encryption type is CMEK,
  #     the cmek_key_name must be provided. If no encryption type is provided,
  #     GMEK will be used.
  class Config
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Types of data encryption.
    module EncryptionType
      # Encryption type unspecified.
      ENCRYPTION_TYPE_UNSPECIFIED = 0

      # Default encryption using Google managed encryption key.
      GMEK = 1

      # Encryption using customer managed encryption key.
      CMEK = 2
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the ApiHub Instance.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The ApiHub instance has not been initialized or has been deleted.
    INACTIVE = 1

    # The ApiHub instance is being created.
    CREATING = 2

    # The ApiHub instance has been created and is ready for use.
    ACTIVE = 3

    # The ApiHub instance is being updated.
    UPDATING = 4

    # The ApiHub instance is being deleted.
    DELETING = 5

    # The ApiHub instance encountered an error during a state change.
    FAILED = 6
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Last update timestamp.

Returns:



1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1269

class ApiHubInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Available configurations to provision an ApiHub Instance.
  # @!attribute [rw] cmek_key_name
  #   @return [::String]
  #     Optional. The Customer Managed Encryption Key (CMEK) used for data
  #     encryption. The CMEK name should follow the format of
  #     `projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/cryptoKeys/([^/]+)`,
  #     where the location must match the instance location.
  #     If the CMEK is not provided, a GMEK will be created for the instance.
  # @!attribute [rw] disable_search
  #   @return [::Boolean]
  #     Optional. If true, the search will be disabled for the instance. The
  #     default value is false.
  # @!attribute [rw] vertex_location
  #   @return [::String]
  #     Optional. The name of the Vertex AI location where the data store is
  #     stored.
  # @!attribute [rw] encryption_type
  #   @return [::Google::Cloud::ApiHub::V1::ApiHubInstance::Config::EncryptionType]
  #     Optional. Encryption type for the region. If the encryption type is CMEK,
  #     the cmek_key_name must be provided. If no encryption type is provided,
  #     GMEK will be used.
  class Config
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Types of data encryption.
    module EncryptionType
      # Encryption type unspecified.
      ENCRYPTION_TYPE_UNSPECIFIED = 0

      # Default encryption using Google managed encryption key.
      GMEK = 1

      # Encryption using customer managed encryption key.
      CMEK = 2
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the ApiHub Instance.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The ApiHub instance has not been initialized or has been deleted.
    INACTIVE = 1

    # The ApiHub instance is being created.
    CREATING = 2

    # The ApiHub instance has been created and is ready for use.
    ACTIVE = 3

    # The ApiHub instance is being updated.
    UPDATING = 4

    # The ApiHub instance is being deleted.
    DELETING = 5

    # The ApiHub instance encountered an error during a state change.
    FAILED = 6
  end
end