Class: Google::Cloud::ApiHub::V1::ApiHubInstance::Config

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

Available configurations to provision an ApiHub Instance.

Defined Under Namespace

Modules: EncryptionType

Instance Attribute Summary collapse

Instance Attribute Details

#cmek_key_name::String

Returns Optional. The Customer Managed Encryption Key (CMEK) used for data encryption. The CMEK name should follow the format of projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/cryptoKeys/([^/]+), where the location must match the instance location. If the CMEK is not provided, a GMEK will be created for the instance.

Returns:

  • (::String)

    Optional. The Customer Managed Encryption Key (CMEK) used for data encryption. The CMEK name should follow the format of projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/cryptoKeys/([^/]+), where the location must match the instance location. If the CMEK is not provided, a GMEK will be created for the instance.



1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1294

class Config
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of data encryption.
  module EncryptionType
    # Encryption type unspecified.
    ENCRYPTION_TYPE_UNSPECIFIED = 0

    # Default encryption using Google managed encryption key.
    GMEK = 1

    # Encryption using customer managed encryption key.
    CMEK = 2
  end
end

#disable_search::Boolean

Returns Optional. If true, the search will be disabled for the instance. The default value is false.

Returns:

  • (::Boolean)

    Optional. If true, the search will be disabled for the instance. The default value is false.



1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1294

class Config
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of data encryption.
  module EncryptionType
    # Encryption type unspecified.
    ENCRYPTION_TYPE_UNSPECIFIED = 0

    # Default encryption using Google managed encryption key.
    GMEK = 1

    # Encryption using customer managed encryption key.
    CMEK = 2
  end
end

#encryption_type::Google::Cloud::ApiHub::V1::ApiHubInstance::Config::EncryptionType

Returns Optional. Encryption type for the region. If the encryption type is CMEK, the cmek_key_name must be provided. If no encryption type is provided, GMEK will be used.

Returns:



1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1294

class Config
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of data encryption.
  module EncryptionType
    # Encryption type unspecified.
    ENCRYPTION_TYPE_UNSPECIFIED = 0

    # Default encryption using Google managed encryption key.
    GMEK = 1

    # Encryption using customer managed encryption key.
    CMEK = 2
  end
end

#vertex_location::String

Returns Optional. The name of the Vertex AI location where the data store is stored.

Returns:

  • (::String)

    Optional. The name of the Vertex AI location where the data store is stored.



1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1294

class Config
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of data encryption.
  module EncryptionType
    # Encryption type unspecified.
    ENCRYPTION_TYPE_UNSPECIFIED = 0

    # Default encryption using Google managed encryption key.
    GMEK = 1

    # Encryption using customer managed encryption key.
    CMEK = 2
  end
end