Module: Google::Cloud::ApiHub::V1::ApiHubInstance::State
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
State of the ApiHub Instance.
Constant Summary collapse
- STATE_UNSPECIFIED =
The default value. This value is used if the state is omitted.
0- INACTIVE =
The ApiHub instance has not been initialized or has been deleted.
1- CREATING =
The ApiHub instance is being created.
2- ACTIVE =
The ApiHub instance has been created and is ready for use.
3- UPDATING =
The ApiHub instance is being updated.
4- DELETING =
The ApiHub instance is being deleted.
5- FAILED =
The ApiHub instance encountered an error during a state change.
6