Class: Google::Cloud::ApiHub::V1::ApiHubResource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/apihub_service.rb

Overview

ApiHubResource is one of the resources such as Api, Operation, Deployment, Definition, Spec and Version resources stored in API-Hub.

Instance Attribute Summary collapse

Instance Attribute Details

#api::Google::Cloud::ApiHub::V1::Api

Returns This represents Api resource in search results. Only name, display_name, description and owner fields are populated in search results.

Note: The following fields are mutually exclusive: api, operation, deployment, spec, definition, version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ApiHub::V1::Api)

    This represents Api resource in search results. Only name, display_name, description and owner fields are populated in search results.

    Note: The following fields are mutually exclusive: api, operation, deployment, spec, definition, version. If a field in that set is populated, all other fields in the set will automatically be cleared.



1284
1285
1286
1287
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1284

class ApiHubResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#definition::Google::Cloud::ApiHub::V1::Definition

Returns This represents Definition resource in search results. Only name field is populated in search results.

Note: The following fields are mutually exclusive: definition, api, operation, deployment, spec, version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ApiHub::V1::Definition)

    This represents Definition resource in search results. Only name field is populated in search results.

    Note: The following fields are mutually exclusive: definition, api, operation, deployment, spec, version. If a field in that set is populated, all other fields in the set will automatically be cleared.



1284
1285
1286
1287
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1284

class ApiHubResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#deployment::Google::Cloud::ApiHub::V1::Deployment

Returns This represents Deployment resource in search results. Only name, display_name, description, deployment_type and api_versions fields are populated in search results.

Note: The following fields are mutually exclusive: deployment, api, operation, spec, definition, version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ApiHub::V1::Deployment)

    This represents Deployment resource in search results. Only name, display_name, description, deployment_type and api_versions fields are populated in search results.

    Note: The following fields are mutually exclusive: deployment, api, operation, spec, definition, version. If a field in that set is populated, all other fields in the set will automatically be cleared.



1284
1285
1286
1287
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1284

class ApiHubResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#operation::Google::Cloud::ApiHub::V1::ApiOperation

Returns This represents ApiOperation resource in search results. Only name, description, spec and details fields are populated in search results.

Note: The following fields are mutually exclusive: operation, api, deployment, spec, definition, version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ApiHub::V1::ApiOperation)

    This represents ApiOperation resource in search results. Only name, description, spec and details fields are populated in search results.

    Note: The following fields are mutually exclusive: operation, api, deployment, spec, definition, version. If a field in that set is populated, all other fields in the set will automatically be cleared.



1284
1285
1286
1287
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1284

class ApiHubResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#spec::Google::Cloud::ApiHub::V1::Spec

Returns This represents Spec resource in search results. Only name, display_name, description, spec_type and documentation fields are populated in search results.

Note: The following fields are mutually exclusive: spec, api, operation, deployment, definition, version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ApiHub::V1::Spec)

    This represents Spec resource in search results. Only name, display_name, description, spec_type and documentation fields are populated in search results.

    Note: The following fields are mutually exclusive: spec, api, operation, deployment, definition, version. If a field in that set is populated, all other fields in the set will automatically be cleared.



1284
1285
1286
1287
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1284

class ApiHubResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#version::Google::Cloud::ApiHub::V1::Version

Returns This represents Version resource in search results. Only name, display_name, description, lifecycle, compliance and accreditation fields are populated in search results.

Note: The following fields are mutually exclusive: version, api, operation, deployment, spec, definition. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ApiHub::V1::Version)

    This represents Version resource in search results. Only name, display_name, description, lifecycle, compliance and accreditation fields are populated in search results.

    Note: The following fields are mutually exclusive: version, api, operation, deployment, spec, definition. If a field in that set is populated, all other fields in the set will automatically be cleared.



1284
1285
1286
1287
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1284

class ApiHubResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end