Class: Google::Cloud::ApiHub::V1::ApiOperation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

Represents an operation contained in an API version in the API Hub. An operation is added/updated/deleted in an API version when a new spec is added or an existing spec is updated/deleted in a version. Currently, an operation will be created only corresponding to OpenAPI spec as parsing is supported for OpenAPI spec. Alternatively operations can be managed via create,update and delete APIs, creation of apiOperation can be possible only for version with no parsed operations and update/delete can be possible only for operations created via create API.

Defined Under Namespace

Classes: AttributesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#attributes::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues}

Returns Optional. The list of user defined attributes associated with the API operation resource. The key is the attribute name. It will be of the format: projects/{project}/locations/{location}/attributes/{attribute}. The value is the attribute values associated with the resource.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues})

    Optional. The list of user defined attributes associated with the API operation resource. The key is the attribute name. It will be of the format: projects/{project}/locations/{location}/attributes/{attribute}. The value is the attribute values associated with the resource.



537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 537

class ApiOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the operation was created.

Returns:



537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 537

class ApiOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#details::Google::Cloud::ApiHub::V1::OperationDetails

Returns Optional. Operation details. Note: Even though this field is optional, it is required for CreateApiOperation API and we will fail the request if not provided.

Returns:



537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 537

class ApiOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. The name of the operation.

Format: projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}.

Returns:

  • (::String)

    Identifier. The name of the operation.

    Format: projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}



537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 537

class ApiOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#source_metadata::Array<::Google::Cloud::ApiHub::V1::SourceMetadata> (readonly)

Returns Output only. The list of sources and metadata from the sources of the API operation.

Returns:



537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 537

class ApiOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#spec::String (readonly)

Returns Output only. The name of the spec will be of the format: projects/{project}/locations/{location}/apis/{api}/versions/{version}/specs/{spec} Note:The name of the spec will be empty if the operation is created via CreateApiOperation API.

Returns:

  • (::String)

    Output only. The name of the spec will be of the format: projects/{project}/locations/{location}/apis/{api}/versions/{version}/specs/{spec} Note:The name of the spec will be empty if the operation is created via CreateApiOperation API.



537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 537

class ApiOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the operation was last updated.

Returns:



537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 537

class ApiOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end