Module: Google::Cloud::ApiHub::V1::Attribute::Scope
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
Enumeration for the scope of the attribute representing the resource in the API Hub to which the attribute can be linked.
Constant Summary collapse
- SCOPE_UNSPECIFIED =
Scope Unspecified.
0- API =
Attribute can be linked to an API.
1- VERSION =
Attribute can be linked to an API version.
2- SPEC =
Attribute can be linked to a Spec.
3- API_OPERATION =
Attribute can be linked to an API Operation.
4- DEPLOYMENT =
Attribute can be linked to a Deployment.
5- DEPENDENCY =
Attribute can be linked to a Dependency.
6- DEFINITION =
Attribute can be linked to a definition.
7- EXTERNAL_API =
Attribute can be linked to a ExternalAPI.
8- PLUGIN =
Attribute can be linked to a Plugin.
9