Class: Google::Cloud::ApiHub::V1::AttributeValues

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

The attribute values associated with resource.

Defined Under Namespace

Classes: EnumAttributeValues, StringAttributeValues

Instance Attribute Summary collapse

Instance Attribute Details

#attribute::String (readonly)

Returns Output only. The name of the attribute. Format: projects/{project}/locations/{location}/attributes/{attribute}.

Returns:

  • (::String)

    Output only. The name of the attribute. Format: projects/{project}/locations/{location}/attributes/{attribute}



975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 975

class AttributeValues
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The attribute values of data type enum.
  # @!attribute [rw] values
  #   @return [::Array<::Google::Cloud::ApiHub::V1::Attribute::AllowedValue>]
  #     Required. The attribute values in case attribute data type is enum.
  class EnumAttributeValues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The attribute values of data type string or JSON.
  # @!attribute [rw] values
  #   @return [::Array<::String>]
  #     Required. The attribute values in case attribute data type is string or
  #     JSON.
  class StringAttributeValues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#enum_values::Google::Cloud::ApiHub::V1::AttributeValues::EnumAttributeValues

Returns The attribute values associated with a resource in case attribute data type is enum.

Note: The following fields are mutually exclusive: enum_values, string_values, json_values, uri_values. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ApiHub::V1::AttributeValues::EnumAttributeValues)

    The attribute values associated with a resource in case attribute data type is enum.

    Note: The following fields are mutually exclusive: enum_values, string_values, json_values, uri_values. If a field in that set is populated, all other fields in the set will automatically be cleared.



975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 975

class AttributeValues
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The attribute values of data type enum.
  # @!attribute [rw] values
  #   @return [::Array<::Google::Cloud::ApiHub::V1::Attribute::AllowedValue>]
  #     Required. The attribute values in case attribute data type is enum.
  class EnumAttributeValues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The attribute values of data type string or JSON.
  # @!attribute [rw] values
  #   @return [::Array<::String>]
  #     Required. The attribute values in case attribute data type is string or
  #     JSON.
  class StringAttributeValues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#json_values::Google::Cloud::ApiHub::V1::AttributeValues::StringAttributeValues

Returns The attribute values associated with a resource in case attribute data type is JSON.

Note: The following fields are mutually exclusive: json_values, enum_values, string_values, uri_values. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ApiHub::V1::AttributeValues::StringAttributeValues)

    The attribute values associated with a resource in case attribute data type is JSON.

    Note: The following fields are mutually exclusive: json_values, enum_values, string_values, uri_values. If a field in that set is populated, all other fields in the set will automatically be cleared.



975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 975

class AttributeValues
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The attribute values of data type enum.
  # @!attribute [rw] values
  #   @return [::Array<::Google::Cloud::ApiHub::V1::Attribute::AllowedValue>]
  #     Required. The attribute values in case attribute data type is enum.
  class EnumAttributeValues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The attribute values of data type string or JSON.
  # @!attribute [rw] values
  #   @return [::Array<::String>]
  #     Required. The attribute values in case attribute data type is string or
  #     JSON.
  class StringAttributeValues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#string_values::Google::Cloud::ApiHub::V1::AttributeValues::StringAttributeValues

Returns The attribute values associated with a resource in case attribute data type is string.

Note: The following fields are mutually exclusive: string_values, enum_values, json_values, uri_values. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ApiHub::V1::AttributeValues::StringAttributeValues)

    The attribute values associated with a resource in case attribute data type is string.

    Note: The following fields are mutually exclusive: string_values, enum_values, json_values, uri_values. If a field in that set is populated, all other fields in the set will automatically be cleared.



975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 975

class AttributeValues
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The attribute values of data type enum.
  # @!attribute [rw] values
  #   @return [::Array<::Google::Cloud::ApiHub::V1::Attribute::AllowedValue>]
  #     Required. The attribute values in case attribute data type is enum.
  class EnumAttributeValues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The attribute values of data type string or JSON.
  # @!attribute [rw] values
  #   @return [::Array<::String>]
  #     Required. The attribute values in case attribute data type is string or
  #     JSON.
  class StringAttributeValues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uri_values::Google::Cloud::ApiHub::V1::AttributeValues::StringAttributeValues

Returns The attribute values associated with a resource in case attribute data type is URL, URI or IP, like gs://bucket-name/object-name.

Note: The following fields are mutually exclusive: uri_values, enum_values, string_values, json_values. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ApiHub::V1::AttributeValues::StringAttributeValues)

    The attribute values associated with a resource in case attribute data type is URL, URI or IP, like gs://bucket-name/object-name.

    Note: The following fields are mutually exclusive: uri_values, enum_values, string_values, json_values. If a field in that set is populated, all other fields in the set will automatically be cleared.



975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 975

class AttributeValues
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The attribute values of data type enum.
  # @!attribute [rw] values
  #   @return [::Array<::Google::Cloud::ApiHub::V1::Attribute::AllowedValue>]
  #     Required. The attribute values in case attribute data type is enum.
  class EnumAttributeValues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The attribute values of data type string or JSON.
  # @!attribute [rw] values
  #   @return [::Array<::String>]
  #     Required. The attribute values in case attribute data type is string or
  #     JSON.
  class StringAttributeValues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end