Class: Google::Cloud::ApiHub::V1::AuthConfig::ApiKeyConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

Config for authentication with API key.

Defined Under Namespace

Modules: HttpElementLocation

Instance Attribute Summary collapse

Instance Attribute Details

#api_key::Google::Cloud::ApiHub::V1::Secret

Returns Required. The name of the SecretManager secret version resource storing the API key. Format: projects/{project}/secrets/{secrete}/versions/{version}. The secretmanager.versions.access permission should be granted to the service account accessing the secret.

Returns:

  • (::Google::Cloud::ApiHub::V1::Secret)

    Required. The name of the SecretManager secret version resource storing the API key. Format: projects/{project}/secrets/{secrete}/versions/{version}. The secretmanager.versions.access permission should be granted to the service account accessing the secret.



1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1655

class ApiKeyConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum of location an HTTP element can be.
  module HttpElementLocation
    # HTTP element location not specified.
    HTTP_ELEMENT_LOCATION_UNSPECIFIED = 0

    # Element is in the HTTP request query.
    QUERY = 1

    # Element is in the HTTP request header.
    HEADER = 2

    # Element is in the HTTP request path.
    PATH = 3

    # Element is in the HTTP request body.
    BODY = 4

    # Element is in the HTTP request cookie.
    COOKIE = 5
  end
end

#http_element_location::Google::Cloud::ApiHub::V1::AuthConfig::ApiKeyConfig::HttpElementLocation

Returns Required. The location of the API key. The default value is QUERY.

Returns:



1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1655

class ApiKeyConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum of location an HTTP element can be.
  module HttpElementLocation
    # HTTP element location not specified.
    HTTP_ELEMENT_LOCATION_UNSPECIFIED = 0

    # Element is in the HTTP request query.
    QUERY = 1

    # Element is in the HTTP request header.
    HEADER = 2

    # Element is in the HTTP request path.
    PATH = 3

    # Element is in the HTTP request body.
    BODY = 4

    # Element is in the HTTP request cookie.
    COOKIE = 5
  end
end

#name::String

Returns Required. The parameter name of the API key. E.g. If the API request is "https://example.com/act?api_key=", "api_key" would be the parameter name.

Returns:

  • (::String)

    Required. The parameter name of the API key. E.g. If the API request is "https://example.com/act?api_key=", "api_key" would be the parameter name.



1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1655

class ApiKeyConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum of location an HTTP element can be.
  module HttpElementLocation
    # HTTP element location not specified.
    HTTP_ELEMENT_LOCATION_UNSPECIFIED = 0

    # Element is in the HTTP request query.
    QUERY = 1

    # Element is in the HTTP request header.
    HEADER = 2

    # Element is in the HTTP request path.
    PATH = 3

    # Element is in the HTTP request body.
    BODY = 4

    # Element is in the HTTP request cookie.
    COOKIE = 5
  end
end