Class: Google::Cloud::ApiHub::V1::AuthConfig::Oauth2ClientCredentialsConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

Parameters to support Oauth 2.0 client credentials grant authentication. See https://tools.ietf.org/html/rfc6749#section-1.3.4 for more details.

Instance Attribute Summary collapse

Instance Attribute Details

#client_id::String

Returns Required. The client identifier.

Returns:

  • (::String)

    Required. The client identifier.



1633
1634
1635
1636
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1633

class Oauth2ClientCredentialsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#client_secret::Google::Cloud::ApiHub::V1::Secret

Returns Required. Secret version reference containing the client secret. The secretmanager.versions.access permission should be granted to the service account accessing the secret.

Returns:

  • (::Google::Cloud::ApiHub::V1::Secret)

    Required. Secret version reference containing the client secret. The secretmanager.versions.access permission should be granted to the service account accessing the secret.



1633
1634
1635
1636
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1633

class Oauth2ClientCredentialsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end