Class: Google::Cloud::ApiHub::V1::AuthConfig::UserPasswordConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

Parameters to support Username and Password Authentication.

Instance Attribute Summary collapse

Instance Attribute Details

#password::Google::Cloud::ApiHub::V1::Secret

Returns Required. Secret version reference containing the password. The secretmanager.versions.access permission should be granted to the service account accessing the secret.

Returns:

  • (::Google::Cloud::ApiHub::V1::Secret)

    Required. Secret version reference containing the password. The secretmanager.versions.access permission should be granted to the service account accessing the secret.



1618
1619
1620
1621
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1618

class UserPasswordConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#username::String

Returns Required. Username.

Returns:

  • (::String)

    Required. Username.



1618
1619
1620
1621
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1618

class UserPasswordConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end