Class: Google::Cloud::ApiHub::V1::CollectApiDataRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/collect_service.rb

Overview

The CollectApiData method's request.

Instance Attribute Summary collapse

Instance Attribute Details

#action_id::String

Returns Required. The action ID to be used for collecting the API data. This should map to one of the action IDs specified in action configs in the plugin.

Returns:

  • (::String)

    Required. The action ID to be used for collecting the API data. This should map to one of the action IDs specified in action configs in the plugin.



46
47
48
49
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 46

class CollectApiDataRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#api_data::Google::Cloud::ApiHub::V1::ApiData

Returns Required. The API data to be collected.

Returns:



46
47
48
49
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 46

class CollectApiDataRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#collection_type::Google::Cloud::ApiHub::V1::CollectionType

Returns Required. The type of collection. Applies to all entries in api_data.

Returns:



46
47
48
49
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 46

class CollectApiDataRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location::String

Returns Required. The regional location of the API hub instance and its resources. Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The regional location of the API hub instance and its resources. Format: projects/{project}/locations/{location}



46
47
48
49
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 46

class CollectApiDataRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#plugin_instance::String

Returns Required. The plugin instance collecting the API data. Format: projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}.

Returns:

  • (::String)

    Required. The plugin instance collecting the API data. Format: projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}.



46
47
48
49
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 46

class CollectApiDataRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end