Class: Google::Cloud::ApiHub::V1::ConfigVariable::MultiIntValues
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ConfigVariable::MultiIntValues
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
The config variable value of data type multi int.
Instance Attribute Summary collapse
-
#values ⇒ ::Array<::Integer>
Optional.
Instance Attribute Details
#values ⇒ ::Array<::Integer>
Returns Optional. The config variable value of data type multi int.
1563 1564 1565 1566 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1563 class MultiIntValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |