Class: Google::Cloud::ApiHub::V1::ConfigVariableTemplate

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

ConfigVariableTemplate represents a configuration variable template present in a Plugin Config.

Defined Under Namespace

Modules: ValueType

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Optional. Description.

Returns:

  • (::String)

    Optional. Description.



1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1447

class ConfigVariableTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # ValueType indicates the data type of the value.
  module ValueType
    # Value type is not specified.
    VALUE_TYPE_UNSPECIFIED = 0

    # Value type is string.
    STRING = 1

    # Value type is integer.
    INT = 2

    # Value type is boolean.
    BOOL = 3

    # Value type is secret.
    SECRET = 4

    # Value type is enum.
    ENUM = 5

    # Value type is multi select.
    MULTI_SELECT = 6

    # Value type is multi string.
    MULTI_STRING = 7

    # Value type is multi int.
    MULTI_INT = 8
  end
end

#enum_options::Array<::Google::Cloud::ApiHub::V1::ConfigValueOption>

Returns Optional. Enum options. To be populated if ValueType is ENUM.

Returns:



1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1447

class ConfigVariableTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # ValueType indicates the data type of the value.
  module ValueType
    # Value type is not specified.
    VALUE_TYPE_UNSPECIFIED = 0

    # Value type is string.
    STRING = 1

    # Value type is integer.
    INT = 2

    # Value type is boolean.
    BOOL = 3

    # Value type is secret.
    SECRET = 4

    # Value type is enum.
    ENUM = 5

    # Value type is multi select.
    MULTI_SELECT = 6

    # Value type is multi string.
    MULTI_STRING = 7

    # Value type is multi int.
    MULTI_INT = 8
  end
end

#id::String

Returns Required. ID of the config variable. Must be unique within the configuration.

Returns:

  • (::String)

    Required. ID of the config variable. Must be unique within the configuration.



1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1447

class ConfigVariableTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # ValueType indicates the data type of the value.
  module ValueType
    # Value type is not specified.
    VALUE_TYPE_UNSPECIFIED = 0

    # Value type is string.
    STRING = 1

    # Value type is integer.
    INT = 2

    # Value type is boolean.
    BOOL = 3

    # Value type is secret.
    SECRET = 4

    # Value type is enum.
    ENUM = 5

    # Value type is multi select.
    MULTI_SELECT = 6

    # Value type is multi string.
    MULTI_STRING = 7

    # Value type is multi int.
    MULTI_INT = 8
  end
end

#multi_select_options::Array<::Google::Cloud::ApiHub::V1::ConfigValueOption>

Returns Optional. Multi select options. To be populated if ValueType is MULTI_SELECT.

Returns:



1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1447

class ConfigVariableTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # ValueType indicates the data type of the value.
  module ValueType
    # Value type is not specified.
    VALUE_TYPE_UNSPECIFIED = 0

    # Value type is string.
    STRING = 1

    # Value type is integer.
    INT = 2

    # Value type is boolean.
    BOOL = 3

    # Value type is secret.
    SECRET = 4

    # Value type is enum.
    ENUM = 5

    # Value type is multi select.
    MULTI_SELECT = 6

    # Value type is multi string.
    MULTI_STRING = 7

    # Value type is multi int.
    MULTI_INT = 8
  end
end

#required::Boolean

Returns Optional. Flag represents that this ConfigVariable must be provided for a PluginInstance.

Returns:

  • (::Boolean)

    Optional. Flag represents that this ConfigVariable must be provided for a PluginInstance.



1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1447

class ConfigVariableTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # ValueType indicates the data type of the value.
  module ValueType
    # Value type is not specified.
    VALUE_TYPE_UNSPECIFIED = 0

    # Value type is string.
    STRING = 1

    # Value type is integer.
    INT = 2

    # Value type is boolean.
    BOOL = 3

    # Value type is secret.
    SECRET = 4

    # Value type is enum.
    ENUM = 5

    # Value type is multi select.
    MULTI_SELECT = 6

    # Value type is multi string.
    MULTI_STRING = 7

    # Value type is multi int.
    MULTI_INT = 8
  end
end

#validation_regex::String

Returns Optional. Regular expression in RE2 syntax used for validating the value of a ConfigVariable.

Returns:

  • (::String)

    Optional. Regular expression in RE2 syntax used for validating the value of a ConfigVariable.



1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1447

class ConfigVariableTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # ValueType indicates the data type of the value.
  module ValueType
    # Value type is not specified.
    VALUE_TYPE_UNSPECIFIED = 0

    # Value type is string.
    STRING = 1

    # Value type is integer.
    INT = 2

    # Value type is boolean.
    BOOL = 3

    # Value type is secret.
    SECRET = 4

    # Value type is enum.
    ENUM = 5

    # Value type is multi select.
    MULTI_SELECT = 6

    # Value type is multi string.
    MULTI_STRING = 7

    # Value type is multi int.
    MULTI_INT = 8
  end
end

#value_type::Google::Cloud::ApiHub::V1::ConfigVariableTemplate::ValueType

Returns Required. Type of the parameter: string, int, bool etc.

Returns:



1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1447

class ConfigVariableTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # ValueType indicates the data type of the value.
  module ValueType
    # Value type is not specified.
    VALUE_TYPE_UNSPECIFIED = 0

    # Value type is string.
    STRING = 1

    # Value type is integer.
    INT = 2

    # Value type is boolean.
    BOOL = 3

    # Value type is secret.
    SECRET = 4

    # Value type is enum.
    ENUM = 5

    # Value type is multi select.
    MULTI_SELECT = 6

    # Value type is multi string.
    MULTI_STRING = 7

    # Value type is multi int.
    MULTI_INT = 8
  end
end