Class: Google::Cloud::ApiHub::V1::CreateAttributeRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::CreateAttributeRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/apihub_service.rb
Overview
The CreateAttribute method's request.
Instance Attribute Summary collapse
-
#attribute ⇒ ::Google::Cloud::ApiHub::V1::Attribute
Required.
-
#attribute_id ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#attribute ⇒ ::Google::Cloud::ApiHub::V1::Attribute
Returns Required. The attribute to create.
1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1059 class CreateAttributeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#attribute_id ⇒ ::String
Returns Optional. The ID to use for the attribute, which will become the final component of the attribute's resource name. This field is optional.
- If provided, the same will be used. The service will throw an error if the specified id is already used by another attribute resource in the API hub.
- If not provided, a system generated id will be used.
This value should be 4-500 characters, and valid characters are /[a-z][A-Z][0-9]-_/.
1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1059 class CreateAttributeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource for Attribute.
Format: projects/{project}/locations/{location}.
1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1059 class CreateAttributeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |