Class: Google::Cloud::ApiHub::V1::CreatePluginRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::CreatePluginRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/plugin_service.rb
Overview
The CreatePlugin method's request.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#plugin ⇒ ::Google::Cloud::ApiHub::V1::Plugin
Required.
-
#plugin_id ⇒ ::String
Optional.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The parent resource where this plugin will be created.
Format: projects/{project}/locations/{location}.
548 549 550 551 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 548 class CreatePluginRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#plugin ⇒ ::Google::Cloud::ApiHub::V1::Plugin
Returns Required. The plugin to create.
548 549 550 551 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 548 class CreatePluginRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#plugin_id ⇒ ::String
Returns Optional. The ID to use for the Plugin resource, which will become the final component of the Plugin's resource name. This field is optional.
- If provided, the same will be used. The service will throw an error if the specified id is already used by another Plugin resource in the API hub instance.
- If not provided, a system generated id will be used.
This value should be 4-63 characters, overall resource name which will be
of format
projects/{project}/locations/{location}/plugins/{plugin},
its length is limited to 1000 characters and valid characters are
/[a-z][A-Z][0-9]-_/.
548 549 550 551 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 548 class CreatePluginRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |