Class: Google::Cloud::ApiHub::V1::CreateVersionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::CreateVersionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/apihub_service.rb
Overview
The CreateVersion method's request.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#version ⇒ ::Google::Cloud::ApiHub::V1::Version
Required.
-
#version_id ⇒ ::String
Optional.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The parent resource for API version.
Format: projects/{project}/locations/{location}/apis/{api}.
261 262 263 264 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 261 class CreateVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#version ⇒ ::Google::Cloud::ApiHub::V1::Version
Returns Required. The version to create.
261 262 263 264 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 261 class CreateVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#version_id ⇒ ::String
Returns Optional. The ID to use for the API version, which will become the final component of the version's resource name. This field is optional.
- If provided, the same will be used. The service will throw an error if the specified id is already used by another version in the API resource.
- If not provided, a system generated id will be used.
This value should be 4-500 characters, overall resource name which will be
of format
projects/{project}/locations/{location}/apis/{api}/versions/{version},
its length is limited to 700 characters and valid characters are
/[a-z][A-Z][0-9]-_/.
261 262 263 264 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 261 class CreateVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |