Class: Google::Cloud::ApiHub::V1::Curation::PluginInstanceActionID

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/curate_service.rb

Overview

The plugin instance and associated action that is using the curation.

Instance Attribute Summary collapse

Instance Attribute Details

#action_id::String (readonly)

Returns Output only. The action ID that is using the curation. This should map to one of the action IDs specified in action configs in the plugin.

Returns:

  • (::String)

    Output only. The action ID that is using the curation. This should map to one of the action IDs specified in action configs in the plugin.



205
206
207
208
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 205

class PluginInstanceActionID
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#plugin_instance::String (readonly)

Returns Output only. Plugin instance that is using the curation. Format is projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}.

Returns:

  • (::String)

    Output only. Plugin instance that is using the curation. Format is projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}



205
206
207
208
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 205

class PluginInstanceActionID
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end