Class: Google::Cloud::ApiHub::V1::Definition

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

Represents a definition for example schema, request, response definitions contained in an API version. A definition is added/updated/deleted in an API version when a new spec is added or an existing spec is updated/deleted in a version. Currently, definition will be created only corresponding to OpenAPI spec as parsing is supported for OpenAPI spec. Also, within OpenAPI spec, only schema object is supported.

Defined Under Namespace

Modules: Type Classes: AttributesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#attributes::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues}

Returns Optional. The list of user defined attributes associated with the definition resource. The key is the attribute name. It will be of the format: projects/{project}/locations/{location}/attributes/{attribute}. The value is the attribute values associated with the resource.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues})

    Optional. The list of user defined attributes associated with the definition resource. The key is the attribute name. It will be of the format: projects/{project}/locations/{location}/attributes/{attribute}. The value is the attribute values associated with the resource.



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 587

class Definition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enumeration of definition types.
  module Type
    # Definition type unspecified.
    TYPE_UNSPECIFIED = 0

    # Definition type schema.
    SCHEMA = 1
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the definition was created.

Returns:



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 587

class Definition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enumeration of definition types.
  module Type
    # Definition type unspecified.
    TYPE_UNSPECIFIED = 0

    # Definition type schema.
    SCHEMA = 1
  end
end

#name::String

Returns Identifier. The name of the definition.

Format: projects/{project}/locations/{location}/apis/{api}/versions/{version}/definitions/{definition}.

Returns:

  • (::String)

    Identifier. The name of the definition.

    Format: projects/{project}/locations/{location}/apis/{api}/versions/{version}/definitions/{definition}



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 587

class Definition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enumeration of definition types.
  module Type
    # Definition type unspecified.
    TYPE_UNSPECIFIED = 0

    # Definition type schema.
    SCHEMA = 1
  end
end

#schema::Google::Cloud::ApiHub::V1::Schema (readonly)

Returns Output only. The value of a schema definition.

Returns:



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 587

class Definition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enumeration of definition types.
  module Type
    # Definition type unspecified.
    TYPE_UNSPECIFIED = 0

    # Definition type schema.
    SCHEMA = 1
  end
end

#spec::String (readonly)

Returns Output only. The name of the spec from where the definition was parsed. Format is projects/{project}/locations/{location}/apis/{api}/versions/{version}/specs/{spec}.

Returns:

  • (::String)

    Output only. The name of the spec from where the definition was parsed. Format is projects/{project}/locations/{location}/apis/{api}/versions/{version}/specs/{spec}



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 587

class Definition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enumeration of definition types.
  module Type
    # Definition type unspecified.
    TYPE_UNSPECIFIED = 0

    # Definition type schema.
    SCHEMA = 1
  end
end

#type::Google::Cloud::ApiHub::V1::Definition::Type (readonly)

Returns Output only. The type of the definition.

Returns:



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 587

class Definition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enumeration of definition types.
  module Type
    # Definition type unspecified.
    TYPE_UNSPECIFIED = 0

    # Definition type schema.
    SCHEMA = 1
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the definition was last updated.

Returns:



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 587

class Definition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enumeration of definition types.
  module Type
    # Definition type unspecified.
    TYPE_UNSPECIFIED = 0

    # Definition type schema.
    SCHEMA = 1
  end
end