Class: Google::Cloud::ApiHub::V1::DeleteVersionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::DeleteVersionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/apihub_service.rb
Overview
The DeleteVersion method's request.
Instance Attribute Summary collapse
-
#force ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#force ⇒ ::Boolean
Returns Optional. If set to true, any specs from this version will also be deleted. Otherwise, the request will only work if the version has no specs.
305 306 307 308 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 305 class DeleteVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the version to delete.
Format:
projects/{project}/locations/{location}/apis/{api}/versions/{version}.
305 306 307 308 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 305 class DeleteVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |