Class: Google::Cloud::ApiHub::V1::Dependency

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

A dependency resource defined in the API hub describes a dependency directed from a consumer to a supplier entity. A dependency can be defined between two Operations or between an Operation and [External API][google.cloud.apihub.v1.ExternalApi].

Defined Under Namespace

Modules: DiscoveryMode, State Classes: AttributesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#attributes::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues}

Returns Optional. The list of user defined attributes associated with the dependency resource. The key is the attribute name. It will be of the format: projects/{project}/locations/{location}/attributes/{attribute}. The value is the attribute values associated with the resource.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues})

    Optional. The list of user defined attributes associated with the dependency resource. The key is the attribute name. It will be of the format: projects/{project}/locations/{location}/attributes/{attribute}. The value is the attribute values associated with the resource.



1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1040

class Dependency
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states for a dependency.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Dependency will be in a proposed state when it is newly identified by the
    # API hub on its own.
    PROPOSED = 1

    # Dependency will be in a validated state when it is validated by the
    # admin or manually created in the API hub.
    VALIDATED = 2
  end

  # Possible modes of discovering the dependency.
  module DiscoveryMode
    # Default value. This value is unused.
    DISCOVERY_MODE_UNSPECIFIED = 0

    # Manual mode of discovery when the dependency is defined by the user.
    MANUAL = 1
  end
end

#consumer::Google::Cloud::ApiHub::V1::DependencyEntityReference

Returns Required. Immutable. The entity acting as the consumer in the dependency.

Returns:



1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1040

class Dependency
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states for a dependency.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Dependency will be in a proposed state when it is newly identified by the
    # API hub on its own.
    PROPOSED = 1

    # Dependency will be in a validated state when it is validated by the
    # admin or manually created in the API hub.
    VALIDATED = 2
  end

  # Possible modes of discovering the dependency.
  module DiscoveryMode
    # Default value. This value is unused.
    DISCOVERY_MODE_UNSPECIFIED = 0

    # Manual mode of discovery when the dependency is defined by the user.
    MANUAL = 1
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the dependency was created.

Returns:



1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1040

class Dependency
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states for a dependency.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Dependency will be in a proposed state when it is newly identified by the
    # API hub on its own.
    PROPOSED = 1

    # Dependency will be in a validated state when it is validated by the
    # admin or manually created in the API hub.
    VALIDATED = 2
  end

  # Possible modes of discovering the dependency.
  module DiscoveryMode
    # Default value. This value is unused.
    DISCOVERY_MODE_UNSPECIFIED = 0

    # Manual mode of discovery when the dependency is defined by the user.
    MANUAL = 1
  end
end

#description::String

Returns Optional. Human readable description corresponding of the dependency.

Returns:

  • (::String)

    Optional. Human readable description corresponding of the dependency.



1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1040

class Dependency
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states for a dependency.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Dependency will be in a proposed state when it is newly identified by the
    # API hub on its own.
    PROPOSED = 1

    # Dependency will be in a validated state when it is validated by the
    # admin or manually created in the API hub.
    VALIDATED = 2
  end

  # Possible modes of discovering the dependency.
  module DiscoveryMode
    # Default value. This value is unused.
    DISCOVERY_MODE_UNSPECIFIED = 0

    # Manual mode of discovery when the dependency is defined by the user.
    MANUAL = 1
  end
end

#discovery_mode::Google::Cloud::ApiHub::V1::Dependency::DiscoveryMode (readonly)

Returns Output only. Discovery mode of the dependency.

Returns:



1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1040

class Dependency
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states for a dependency.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Dependency will be in a proposed state when it is newly identified by the
    # API hub on its own.
    PROPOSED = 1

    # Dependency will be in a validated state when it is validated by the
    # admin or manually created in the API hub.
    VALIDATED = 2
  end

  # Possible modes of discovering the dependency.
  module DiscoveryMode
    # Default value. This value is unused.
    DISCOVERY_MODE_UNSPECIFIED = 0

    # Manual mode of discovery when the dependency is defined by the user.
    MANUAL = 1
  end
end

#error_detail::Google::Cloud::ApiHub::V1::DependencyErrorDetail (readonly)

Returns Output only. Error details of a dependency if the system has detected it internally.

Returns:



1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1040

class Dependency
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states for a dependency.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Dependency will be in a proposed state when it is newly identified by the
    # API hub on its own.
    PROPOSED = 1

    # Dependency will be in a validated state when it is validated by the
    # admin or manually created in the API hub.
    VALIDATED = 2
  end

  # Possible modes of discovering the dependency.
  module DiscoveryMode
    # Default value. This value is unused.
    DISCOVERY_MODE_UNSPECIFIED = 0

    # Manual mode of discovery when the dependency is defined by the user.
    MANUAL = 1
  end
end

#name::String

Returns Identifier. The name of the dependency in the API Hub.

Format: projects/{project}/locations/{location}/dependencies/{dependency}.

Returns:

  • (::String)

    Identifier. The name of the dependency in the API Hub.

    Format: projects/{project}/locations/{location}/dependencies/{dependency}



1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1040

class Dependency
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states for a dependency.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Dependency will be in a proposed state when it is newly identified by the
    # API hub on its own.
    PROPOSED = 1

    # Dependency will be in a validated state when it is validated by the
    # admin or manually created in the API hub.
    VALIDATED = 2
  end

  # Possible modes of discovering the dependency.
  module DiscoveryMode
    # Default value. This value is unused.
    DISCOVERY_MODE_UNSPECIFIED = 0

    # Manual mode of discovery when the dependency is defined by the user.
    MANUAL = 1
  end
end

#state::Google::Cloud::ApiHub::V1::Dependency::State (readonly)

Returns Output only. State of the dependency.

Returns:



1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1040

class Dependency
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states for a dependency.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Dependency will be in a proposed state when it is newly identified by the
    # API hub on its own.
    PROPOSED = 1

    # Dependency will be in a validated state when it is validated by the
    # admin or manually created in the API hub.
    VALIDATED = 2
  end

  # Possible modes of discovering the dependency.
  module DiscoveryMode
    # Default value. This value is unused.
    DISCOVERY_MODE_UNSPECIFIED = 0

    # Manual mode of discovery when the dependency is defined by the user.
    MANUAL = 1
  end
end

#supplier::Google::Cloud::ApiHub::V1::DependencyEntityReference

Returns Required. Immutable. The entity acting as the supplier in the dependency.

Returns:



1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1040

class Dependency
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states for a dependency.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Dependency will be in a proposed state when it is newly identified by the
    # API hub on its own.
    PROPOSED = 1

    # Dependency will be in a validated state when it is validated by the
    # admin or manually created in the API hub.
    VALIDATED = 2
  end

  # Possible modes of discovering the dependency.
  module DiscoveryMode
    # Default value. This value is unused.
    DISCOVERY_MODE_UNSPECIFIED = 0

    # Manual mode of discovery when the dependency is defined by the user.
    MANUAL = 1
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the dependency was last updated.

Returns:



1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1040

class Dependency
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states for a dependency.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Dependency will be in a proposed state when it is newly identified by the
    # API hub on its own.
    PROPOSED = 1

    # Dependency will be in a validated state when it is validated by the
    # admin or manually created in the API hub.
    VALIDATED = 2
  end

  # Possible modes of discovering the dependency.
  module DiscoveryMode
    # Default value. This value is unused.
    DISCOVERY_MODE_UNSPECIFIED = 0

    # Manual mode of discovery when the dependency is defined by the user.
    MANUAL = 1
  end
end