Class: Google::Cloud::ApiHub::V1::DependencyErrorDetail
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::DependencyErrorDetail
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
Details describing error condition of a dependency.
Defined Under Namespace
Modules: Error
Instance Attribute Summary collapse
-
#error ⇒ ::Google::Cloud::ApiHub::V1::DependencyErrorDetail::Error
Optional.
-
#error_time ⇒ ::Google::Protobuf::Timestamp
Optional.
Instance Attribute Details
#error ⇒ ::Google::Cloud::ApiHub::V1::DependencyErrorDetail::Error
Returns Optional. Error in the dependency.
1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1109 class DependencyErrorDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible values representing an error in the dependency. module Error # Default value used for no error in the dependency. ERROR_UNSPECIFIED = 0 # Supplier entity has been deleted. SUPPLIER_NOT_FOUND = 1 # Supplier entity has been recreated. SUPPLIER_RECREATED = 2 end end |
#error_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. Timestamp at which the error was found.
1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1109 class DependencyErrorDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible values representing an error in the dependency. module Error # Default value used for no error in the dependency. ERROR_UNSPECIFIED = 0 # Supplier entity has been deleted. SUPPLIER_NOT_FOUND = 1 # Supplier entity has been recreated. SUPPLIER_RECREATED = 2 end end |