Class: Google::Cloud::ApiHub::V1::DeploymentMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::DeploymentMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/collect_service.rb
Overview
The metadata associated with a deployment.
Instance Attribute Summary collapse
-
#deployment ⇒ ::Google::Cloud::ApiHub::V1::Deployment
Required.
-
#original_create_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#original_id ⇒ ::String
Optional.
-
#original_update_time ⇒ ::Google::Protobuf::Timestamp
Required.
Instance Attribute Details
#deployment ⇒ ::Google::Cloud::ApiHub::V1::Deployment
Returns Required. The deployment resource to be pushed to Hub's collect layer. The ID of the deployment will be generated by Hub.
161 162 163 164 |
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 161 class DeploymentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#original_create_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. Timestamp indicating when the deployment was created at the source.
161 162 163 164 |
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 161 class DeploymentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#original_id ⇒ ::String
Returns Optional. The unique identifier of the deployment in the system where it was originally created.
161 162 163 164 |
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 161 class DeploymentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#original_update_time ⇒ ::Google::Protobuf::Timestamp
Returns Required. Timestamp indicating when the deployment was last updated at the source.
161 162 163 164 |
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 161 class DeploymentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |