Class: Google::Cloud::ApiHub::V1::Endpoint

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/curate_service.rb

Overview

The endpoint to be triggered for curation. The endpoint will be invoked with a request payload containing [ApiMetadata][google.cloud.apihub.v1.ApiHub.ApiMetadata]. Response should contain curated data in the form of [ApiMetadata][google.cloud.apihub.v1.ApiHub.ApiMetadata].

Instance Attribute Summary collapse

Instance Attribute Details

#application_integration_endpoint_details::Google::Cloud::ApiHub::V1::ApplicationIntegrationEndpointDetails

Returns Required. The details of the Application Integration endpoint to be triggered for curation.

Returns:



244
245
246
247
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 244

class Endpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end