Class: Google::Cloud::ApiHub::V1::ExecutionStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/plugin_service.rb

Overview

The execution status for the plugin instance.

Defined Under Namespace

Modules: CurrentExecutionState Classes: LastExecution

Instance Attribute Summary collapse

Instance Attribute Details

#current_execution_state::Google::Cloud::ApiHub::V1::ExecutionStatus::CurrentExecutionState (readonly)

Returns Output only. The current state of the execution.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 476

class ExecutionStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The result of the last execution of the plugin instance.
  # @!attribute [r] result
  #   @return [::Google::Cloud::ApiHub::V1::ExecutionStatus::LastExecution::Result]
  #     Output only. The result of the last execution of the plugin instance.
  # @!attribute [r] error_message
  #   @return [::String]
  #     Output only. Error message describing the failure, if any, during the
  #     last execution.
  # @!attribute [r] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The last execution start time of the plugin instance.
  # @!attribute [r] end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The last execution end time of the plugin instance.
  class LastExecution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enum for the result of the last execution of the plugin instance.
    module Result
      # Default unspecified execution result.
      RESULT_UNSPECIFIED = 0

      # The plugin instance executed successfully.
      SUCCEEDED = 1

      # The plugin instance execution failed.
      FAILED = 2
    end
  end

  # Enum for the current state of the execution.
  module CurrentExecutionState
    # Default unspecified execution state.
    CURRENT_EXECUTION_STATE_UNSPECIFIED = 0

    # The plugin instance is executing.
    RUNNING = 1

    # The plugin instance is not running an execution.
    NOT_RUNNING = 2
  end
end

#last_execution::Google::Cloud::ApiHub::V1::ExecutionStatus::LastExecution (readonly)

Returns Output only. The last execution of the plugin instance.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 476

class ExecutionStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The result of the last execution of the plugin instance.
  # @!attribute [r] result
  #   @return [::Google::Cloud::ApiHub::V1::ExecutionStatus::LastExecution::Result]
  #     Output only. The result of the last execution of the plugin instance.
  # @!attribute [r] error_message
  #   @return [::String]
  #     Output only. Error message describing the failure, if any, during the
  #     last execution.
  # @!attribute [r] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The last execution start time of the plugin instance.
  # @!attribute [r] end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The last execution end time of the plugin instance.
  class LastExecution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enum for the result of the last execution of the plugin instance.
    module Result
      # Default unspecified execution result.
      RESULT_UNSPECIFIED = 0

      # The plugin instance executed successfully.
      SUCCEEDED = 1

      # The plugin instance execution failed.
      FAILED = 2
    end
  end

  # Enum for the current state of the execution.
  module CurrentExecutionState
    # Default unspecified execution state.
    CURRENT_EXECUTION_STATE_UNSPECIFIED = 0

    # The plugin instance is executing.
    RUNNING = 1

    # The plugin instance is not running an execution.
    NOT_RUNNING = 2
  end
end