Class: Google::Cloud::ApiHub::V1::GoogleServiceAccountConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

Config for Google service account authentication.

Instance Attribute Summary collapse

Instance Attribute Details

#service_account::String

Returns Required. The service account to be used for authenticating request.

The iam.serviceAccounts.getAccessToken permission should be granted on this service account to the impersonator service account.

Returns:

  • (::String)

    Required. The service account to be used for authenticating request.

    The iam.serviceAccounts.getAccessToken permission should be granted on this service account to the impersonator service account.



1576
1577
1578
1579
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1576

class GoogleServiceAccountConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end