Class: Google::Cloud::ApiHub::V1::HttpOperationDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

An HTTP-based API Operation, sometimes called a "REST" Operation.

Defined Under Namespace

Modules: DataType Classes: Header, HttpRequest, HttpResponse, PathParam, QueryParam, QueryParamsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#http_operation::Google::Cloud::ApiHub::V1::HttpOperation

Returns Required. An HTTP Operation.

Returns:



1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1893

class HttpOperationDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # HTTP Path parameter.
  # @!attribute [rw] position
  #   @return [::Integer]
  #     Optional. Segment location in the path, 1-indexed
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Optional. Data type of path param
  class PathParam
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP query parameter occurrences.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. Name of query param
  # @!attribute [rw] count
  #   @return [::Integer]
  #     Optional. The number of occurrences of this query parameter across
  #     transactions.
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Optional. Data type of path param
  class QueryParam
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP header occurrences.
  # @!attribute [rw] name
  #   @return [::String]
  #     Header name.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The number of occurrences of this Header across transactions.
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Data type of header
  class Header
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP requests.
  # @!attribute [rw] headers
  #   @return [::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header}]
  #     Optional. Unordered map from header name to header metadata
  class HttpRequest
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header]
    class HeadersEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # An aggregation of HTTP responses.
  # @!attribute [rw] headers
  #   @return [::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header}]
  #     Optional. Unordered map from header name to header metadata
  # @!attribute [rw] response_codes
  #   @return [::Google::Protobuf::Map{::Integer => ::Integer}]
  #     Optional. Map of status code to observed count
  class HttpResponse
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header]
    class HeadersEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # @!attribute [rw] key
    #   @return [::Integer]
    # @!attribute [rw] value
    #   @return [::Integer]
    class ResponseCodesEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::QueryParam]
  class QueryParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of data
  module DataType
    # Unspecified data type
    DATA_TYPE_UNSPECIFIED = 0

    # Boolean data type
    BOOL = 1

    # Integer data type
    INTEGER = 2

    # Float data type
    FLOAT = 3

    # String data type
    STRING = 4

    # UUID data type
    UUID = 5
  end
end

#path_params::Array<::Google::Cloud::ApiHub::V1::HttpOperationDetails::PathParam>

Returns Optional. Path params of HttpOperation.

Returns:



1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1893

class HttpOperationDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # HTTP Path parameter.
  # @!attribute [rw] position
  #   @return [::Integer]
  #     Optional. Segment location in the path, 1-indexed
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Optional. Data type of path param
  class PathParam
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP query parameter occurrences.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. Name of query param
  # @!attribute [rw] count
  #   @return [::Integer]
  #     Optional. The number of occurrences of this query parameter across
  #     transactions.
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Optional. Data type of path param
  class QueryParam
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP header occurrences.
  # @!attribute [rw] name
  #   @return [::String]
  #     Header name.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The number of occurrences of this Header across transactions.
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Data type of header
  class Header
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP requests.
  # @!attribute [rw] headers
  #   @return [::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header}]
  #     Optional. Unordered map from header name to header metadata
  class HttpRequest
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header]
    class HeadersEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # An aggregation of HTTP responses.
  # @!attribute [rw] headers
  #   @return [::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header}]
  #     Optional. Unordered map from header name to header metadata
  # @!attribute [rw] response_codes
  #   @return [::Google::Protobuf::Map{::Integer => ::Integer}]
  #     Optional. Map of status code to observed count
  class HttpResponse
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header]
    class HeadersEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # @!attribute [rw] key
    #   @return [::Integer]
    # @!attribute [rw] value
    #   @return [::Integer]
    class ResponseCodesEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::QueryParam]
  class QueryParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of data
  module DataType
    # Unspecified data type
    DATA_TYPE_UNSPECIFIED = 0

    # Boolean data type
    BOOL = 1

    # Integer data type
    INTEGER = 2

    # Float data type
    FLOAT = 3

    # String data type
    STRING = 4

    # UUID data type
    UUID = 5
  end
end

#query_params::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::HttpOperationDetails::QueryParam}

Returns Optional. Query params of HttpOperation.

Returns:



1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1893

class HttpOperationDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # HTTP Path parameter.
  # @!attribute [rw] position
  #   @return [::Integer]
  #     Optional. Segment location in the path, 1-indexed
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Optional. Data type of path param
  class PathParam
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP query parameter occurrences.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. Name of query param
  # @!attribute [rw] count
  #   @return [::Integer]
  #     Optional. The number of occurrences of this query parameter across
  #     transactions.
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Optional. Data type of path param
  class QueryParam
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP header occurrences.
  # @!attribute [rw] name
  #   @return [::String]
  #     Header name.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The number of occurrences of this Header across transactions.
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Data type of header
  class Header
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP requests.
  # @!attribute [rw] headers
  #   @return [::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header}]
  #     Optional. Unordered map from header name to header metadata
  class HttpRequest
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header]
    class HeadersEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # An aggregation of HTTP responses.
  # @!attribute [rw] headers
  #   @return [::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header}]
  #     Optional. Unordered map from header name to header metadata
  # @!attribute [rw] response_codes
  #   @return [::Google::Protobuf::Map{::Integer => ::Integer}]
  #     Optional. Map of status code to observed count
  class HttpResponse
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header]
    class HeadersEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # @!attribute [rw] key
    #   @return [::Integer]
    # @!attribute [rw] value
    #   @return [::Integer]
    class ResponseCodesEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::QueryParam]
  class QueryParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of data
  module DataType
    # Unspecified data type
    DATA_TYPE_UNSPECIFIED = 0

    # Boolean data type
    BOOL = 1

    # Integer data type
    INTEGER = 2

    # Float data type
    FLOAT = 3

    # String data type
    STRING = 4

    # UUID data type
    UUID = 5
  end
end

#request::Google::Cloud::ApiHub::V1::HttpOperationDetails::HttpRequest

Returns Optional. Request metadata.

Returns:



1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1893

class HttpOperationDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # HTTP Path parameter.
  # @!attribute [rw] position
  #   @return [::Integer]
  #     Optional. Segment location in the path, 1-indexed
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Optional. Data type of path param
  class PathParam
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP query parameter occurrences.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. Name of query param
  # @!attribute [rw] count
  #   @return [::Integer]
  #     Optional. The number of occurrences of this query parameter across
  #     transactions.
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Optional. Data type of path param
  class QueryParam
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP header occurrences.
  # @!attribute [rw] name
  #   @return [::String]
  #     Header name.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The number of occurrences of this Header across transactions.
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Data type of header
  class Header
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP requests.
  # @!attribute [rw] headers
  #   @return [::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header}]
  #     Optional. Unordered map from header name to header metadata
  class HttpRequest
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header]
    class HeadersEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # An aggregation of HTTP responses.
  # @!attribute [rw] headers
  #   @return [::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header}]
  #     Optional. Unordered map from header name to header metadata
  # @!attribute [rw] response_codes
  #   @return [::Google::Protobuf::Map{::Integer => ::Integer}]
  #     Optional. Map of status code to observed count
  class HttpResponse
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header]
    class HeadersEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # @!attribute [rw] key
    #   @return [::Integer]
    # @!attribute [rw] value
    #   @return [::Integer]
    class ResponseCodesEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::QueryParam]
  class QueryParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of data
  module DataType
    # Unspecified data type
    DATA_TYPE_UNSPECIFIED = 0

    # Boolean data type
    BOOL = 1

    # Integer data type
    INTEGER = 2

    # Float data type
    FLOAT = 3

    # String data type
    STRING = 4

    # UUID data type
    UUID = 5
  end
end

#response::Google::Cloud::ApiHub::V1::HttpOperationDetails::HttpResponse

Returns Optional. Response metadata.

Returns:



1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1893

class HttpOperationDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # HTTP Path parameter.
  # @!attribute [rw] position
  #   @return [::Integer]
  #     Optional. Segment location in the path, 1-indexed
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Optional. Data type of path param
  class PathParam
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP query parameter occurrences.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. Name of query param
  # @!attribute [rw] count
  #   @return [::Integer]
  #     Optional. The number of occurrences of this query parameter across
  #     transactions.
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Optional. Data type of path param
  class QueryParam
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP header occurrences.
  # @!attribute [rw] name
  #   @return [::String]
  #     Header name.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The number of occurrences of this Header across transactions.
  # @!attribute [rw] data_type
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType]
  #     Data type of header
  class Header
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An aggregation of HTTP requests.
  # @!attribute [rw] headers
  #   @return [::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header}]
  #     Optional. Unordered map from header name to header metadata
  class HttpRequest
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header]
    class HeadersEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # An aggregation of HTTP responses.
  # @!attribute [rw] headers
  #   @return [::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header}]
  #     Optional. Unordered map from header name to header metadata
  # @!attribute [rw] response_codes
  #   @return [::Google::Protobuf::Map{::Integer => ::Integer}]
  #     Optional. Map of status code to observed count
  class HttpResponse
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::Header]
    class HeadersEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # @!attribute [rw] key
    #   @return [::Integer]
    # @!attribute [rw] value
    #   @return [::Integer]
    class ResponseCodesEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::HttpOperationDetails::QueryParam]
  class QueryParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of data
  module DataType
    # Unspecified data type
    DATA_TYPE_UNSPECIFIED = 0

    # Boolean data type
    BOOL = 1

    # Integer data type
    INTEGER = 2

    # Float data type
    FLOAT = 3

    # String data type
    STRING = 4

    # UUID data type
    UUID = 5
  end
end