Class: Google::Cloud::ApiHub::V1::HttpOperationDetails::QueryParam

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

An aggregation of HTTP query parameter occurrences.

Instance Attribute Summary collapse

Instance Attribute Details

#count::Integer

Returns Optional. The number of occurrences of this query parameter across transactions.

Returns:

  • (::Integer)

    Optional. The number of occurrences of this query parameter across transactions.



1920
1921
1922
1923
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1920

class QueryParam
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_type::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType

Returns Optional. Data type of path param.

Returns:



1920
1921
1922
1923
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1920

class QueryParam
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. Name of query param.

Returns:

  • (::String)

    Required. Name of query param



1920
1921
1922
1923
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1920

class QueryParam
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end