Class: Google::Cloud::ApiHub::V1::ListCurationsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ListCurationsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/curate_service.rb
Overview
The [ListCurations][ApiHub.ListCurations] method's response.
Instance Attribute Summary collapse
-
#curations ⇒ ::Array<::Google::Cloud::ApiHub::V1::Curation>
The curation resources present in the API hub.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#curations ⇒ ::Array<::Google::Cloud::ApiHub::V1::Curation>
Returns The curation resources present in the API hub.
147 148 149 150 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 147 class ListCurationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
147 148 149 150 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 147 class ListCurationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |