Class: Google::Cloud::ApiHub::V1::ListDependenciesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ListDependenciesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/apihub_service.rb
Overview
The ListDependencies method's request.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. An expression that filters the list of Dependencies.
A filter expression consists of a field name, a comparison operator, and
a value for filtering. The value must be a string. Allowed comparison
operator is =. Filters are not case sensitive.
The following fields in the Dependency are eligible for filtering:
consumer.operation_resource_name- The operation resource name for the consumer entity involved in a dependency. Allowed comparison operators:=.consumer.external_api_resource_name- The external api resource name for the consumer entity involved in a dependency. Allowed comparison operators:=.supplier.operation_resource_name- The operation resource name for the supplier entity involved in a dependency. Allowed comparison operators:=.supplier.external_api_resource_name- The external api resource name for the supplier entity involved in a dependency. Allowed comparison operators:=.
Expressions are combined with either AND logic operator or OR logical
operator but not both of them together i.e. only one of the AND or OR
operator can be used throughout the filter string and both the operators
cannot be used together. No other logical operators are supported. At most
three filter fields are allowed in the filter string and if provided
more than that then INVALID_ARGUMENT error is returned by the API.
For example, consumer.operation_resource_name =
\"projects/p1/locations/global/apis/a1/versions/v1/operations/o1\" OR
supplier.operation_resource_name =
\"projects/p1/locations/global/apis/a1/versions/v1/operations/o1\" - The
dependencies with either consumer or supplier operation resource name as
projects/p1/locations/global/apis/a1/versions/v1/operations/o1.
1437 1438 1439 1440 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1437 class ListDependenciesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of dependency resources to return. The service may return fewer than this value. If unspecified, at most 50 dependencies will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
1437 1438 1439 1440 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1437 class ListDependenciesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous ListDependencies call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListDependencies must
match the call that provided the page token.
1437 1438 1439 1440 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1437 class ListDependenciesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent which owns this collection of dependency resources.
Format: projects/{project}/locations/{location}.
1437 1438 1439 1440 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1437 class ListDependenciesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |