Class: Google::Cloud::ApiHub::V1::ListDependenciesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ListDependenciesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/apihub_service.rb
Overview
The ListDependencies method's response.
Instance Attribute Summary collapse
-
#dependencies ⇒ ::Array<::Google::Cloud::ApiHub::V1::Dependency>
The dependency resources present in the API hub.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#dependencies ⇒ ::Array<::Google::Cloud::ApiHub::V1::Dependency>
Returns The dependency resources present in the API hub.
1452 1453 1454 1455 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1452 class ListDependenciesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
1452 1453 1454 1455 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1452 class ListDependenciesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |