Class: Google::Cloud::ApiHub::V1::ListDiscoveredApiObservationsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/discovery_service.rb

Overview

Message for requesting list of DiscoveredApiObservations

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Optional. The maximum number of ApiObservations to return. The service may return fewer than this value. If unspecified, at most 10 ApiObservations will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of ApiObservations to return. The service may return fewer than this value. If unspecified, at most 10 ApiObservations will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



44
45
46
47
# File 'proto_docs/google/cloud/apihub/v1/discovery_service.rb', line 44

class ListDiscoveredApiObservationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListApiObservations call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListApiObservations must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListApiObservations call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListApiObservations must match the call that provided the page token.



44
45
46
47
# File 'proto_docs/google/cloud/apihub/v1/discovery_service.rb', line 44

class ListDiscoveredApiObservationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which owns this collection of ApiObservations. Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent, which owns this collection of ApiObservations. Format: projects/{project}/locations/{location}



44
45
46
47
# File 'proto_docs/google/cloud/apihub/v1/discovery_service.rb', line 44

class ListDiscoveredApiObservationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end