Class: Google::Cloud::ApiHub::V1::ListDiscoveredApiOperationsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/discovery_service.rb

Overview

Message for response to listing DiscoveredApiOperations

Instance Attribute Summary collapse

Instance Attribute Details

#discovered_api_operations::Array<::Google::Cloud::ApiHub::V1::DiscoveredApiOperation>

Returns The DiscoveredApiOperations from the specified project, location and DiscoveredApiObservation.

Returns:



95
96
97
98
# File 'proto_docs/google/cloud/apihub/v1/discovery_service.rb', line 95

class ListDiscoveredApiOperationsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



95
96
97
98
# File 'proto_docs/google/cloud/apihub/v1/discovery_service.rb', line 95

class ListDiscoveredApiOperationsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end