Class: Google::Cloud::ApiHub::V1::ListPluginInstancesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/plugin_service.rb

Overview

The ListPluginInstances method's request.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Optional. An expression that filters the list of plugin instances.

A filter expression consists of a field name, a comparison operator, and a value for filtering. The value must be a string. The comparison operator must be one of: <, > or =. Filters are not case sensitive.

The following fields in the PluginInstances are eligible for filtering:

  • state - The state of the Plugin Instance. Allowed comparison operators: =.

A filter function is also supported in the filter string. The filter function is id(name). The id(name) function returns the id of the resource name. For example, id(name) = \"plugin-instance-1\" is equivalent to name = \"projects/test-project-id/locations/test-location-id/plugins/plugin-1/instances/plugin-instance-1\" provided the parent is projects/test-project-id/locations/test-location-id/plugins/plugin-1.

Expressions are combined with either AND logic operator or OR logical operator but not both of them together i.e. only one of the AND or OR operator can be used throughout the filter string and both the operators cannot be used together. No other logical operators are supported. At most three filter fields are allowed in the filter string and if provided more than that then INVALID_ARGUMENT error is returned by the API. Here are a few examples:

  • state = ENABLED - The plugin instance is in enabled state.

Returns:

  • (::String)

    Optional. An expression that filters the list of plugin instances.

    A filter expression consists of a field name, a comparison operator, and a value for filtering. The value must be a string. The comparison operator must be one of: <, > or =. Filters are not case sensitive.

    The following fields in the PluginInstances are eligible for filtering:

    • state - The state of the Plugin Instance. Allowed comparison operators: =.

    A filter function is also supported in the filter string. The filter function is id(name). The id(name) function returns the id of the resource name. For example, id(name) = \"plugin-instance-1\" is equivalent to name = \"projects/test-project-id/locations/test-location-id/plugins/plugin-1/instances/plugin-instance-1\" provided the parent is projects/test-project-id/locations/test-location-id/plugins/plugin-1.

    Expressions are combined with either AND logic operator or OR logical operator but not both of them together i.e. only one of the AND or OR operator can be used throughout the filter string and both the operators cannot be used together. No other logical operators are supported. At most three filter fields are allowed in the filter string and if provided more than that then INVALID_ARGUMENT error is returned by the API. Here are a few examples:

    • state = ENABLED - The plugin instance is in enabled state.


754
755
756
757
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 754

class ListPluginInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Optional. The maximum number of hub plugins to return. The service may return fewer than this value. If unspecified, at most 50 hub plugins will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of hub plugins to return. The service may return fewer than this value. If unspecified, at most 50 hub plugins will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



754
755
756
757
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 754

class ListPluginInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListPluginInstances call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListPluginInstances must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListPluginInstances call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListPluginInstances must match the call that provided the page token.



754
755
756
757
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 754

class ListPluginInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this plugin will be created. Format: projects/{project}/locations/{location}/plugins/{plugin}. To list plugin instances for multiple plugins, use the - character instead of the plugin ID.

Returns:

  • (::String)

    Required. The parent resource where this plugin will be created. Format: projects/{project}/locations/{location}/plugins/{plugin}. To list plugin instances for multiple plugins, use the - character instead of the plugin ID.



754
755
756
757
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 754

class ListPluginInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end