Class: Google::Cloud::ApiHub::V1::ListPluginInstancesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ListPluginInstancesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/plugin_service.rb
Overview
The ListPluginInstances method's response.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#plugin_instances ⇒ ::Array<::Google::Cloud::ApiHub::V1::PluginInstance>
The plugin instances from the specified parent resource.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
769 770 771 772 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 769 class ListPluginInstancesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#plugin_instances ⇒ ::Array<::Google::Cloud::ApiHub::V1::PluginInstance>
Returns The plugin instances from the specified parent resource.
769 770 771 772 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 769 class ListPluginInstancesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |