Class: Google::Cloud::ApiHub::V1::ListPluginsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ListPluginsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/plugin_service.rb
Overview
The ListPlugins method's request.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Optional. An expression that filters the list of plugins.
A filter expression consists of a field name, a comparison
operator, and a value for filtering. The value must be a string. The
comparison operator must be one of: <, > or
=. Filters are not case sensitive.
The following fields in the Plugins are eligible for filtering:
plugin_category- The category of the Plugin. Allowed comparison operators:=.
Expressions are combined with either AND logic operator or OR logical
operator but not both of them together i.e. only one of the AND or OR
operator can be used throughout the filter string and both the operators
cannot be used together. No other logical operators are
supported. At most three filter fields are allowed in the filter
string and if provided more than that then INVALID_ARGUMENT error is
returned by the API.
Here are a few examples:
plugin_category = ON_RAMP- The plugin is of category on ramp.
607 608 609 610 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 607 class ListPluginsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Optional. The maximum number of hub plugins to return. The service may return fewer than this value. If unspecified, at most 50 hub plugins will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
607 608 609 610 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 607 class ListPluginsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous ListPlugins call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters (except page_size) provided to
ListPlugins must match the call that provided the page token.
607 608 609 610 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 607 class ListPluginsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource where this plugin will be created.
Format: projects/{project}/locations/{location}.
607 608 609 610 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 607 class ListPluginsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |