Class: Google::Cloud::ApiHub::V1::ListPluginsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ListPluginsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/plugin_service.rb
Overview
The ListPlugins method's response.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#plugins ⇒ ::Array<::Google::Cloud::ApiHub::V1::Plugin>
The plugins from the specified parent resource.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
621 622 623 624 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 621 class ListPluginsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#plugins ⇒ ::Array<::Google::Cloud::ApiHub::V1::Plugin>
Returns The plugins from the specified parent resource.
621 622 623 624 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 621 class ListPluginsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |