Class: Google::Cloud::ApiHub::V1::ListSpecsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ListSpecsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/apihub_service.rb
Overview
The [ListSpecs][ListSpecs] method's request.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Optional. An expression that filters the list of Specs.
A filter expression consists of a field name, a comparison
operator, and a value for filtering. The value must be a string. The
comparison operator must be one of: <, >, : or =. Filters are not
case sensitive.
The following fields in the Spec are eligible for filtering:
display_name- The display name of the Spec. Allowed comparison operators:=.create_time- The time at which the Spec was created. The value should be in the (RFC3339)[https://tools.ietf.org/html/rfc3339] format. Allowed comparison operators:>and<.spec_type.enum_values.values.id- The allowed value id of the spec_type attribute associated with the Spec. Allowed comparison operators::.spec_type.enum_values.values.display_name- The allowed value display name of the spec_type attribute associated with the Spec. Allowed comparison operators::.lint_response.json_values.values- The json value of the lint_response attribute associated with the Spec. Allowed comparison operators::.mime_type- The MIME type of the Spec. Allowed comparison operators:=.attributes.projects/test-project-id/locations/test-location-id/ attributes/user-defined-attribute-id.enum_values.values.id- The allowed value id of the user defined enum attribute associated with the Resource. Allowed comparison operator is:. Here user-defined-attribute-enum-id is a placeholder that can be replaced with any user defined enum attribute name.attributes.projects/test-project-id/locations/test-location-id/ attributes/user-defined-attribute-id.enum_values.values.display_name- The allowed value display name of the user defined enum attribute
associated with the Resource. Allowed comparison operator is
:. Here user-defined-attribute-enum-display-name is a placeholder that can be replaced with any user defined enum attribute enum name. attributes.projects/test-project-id/locations/test-location-id/ attributes/user-defined-attribute-id.string_values.values- The allowed value of the user defined string attribute associated with the Resource. Allowed comparison operator is:. Here user-defined-attribute-string is a placeholder that can be replaced with any user defined string attribute name.attributes.projects/test-project-id/locations/test-location-id/ attributes/user-defined-attribute-id.json_values.values- The allowed value of the user defined JSON attribute associated with the Resource. Allowed comparison operator is:. Here user-defined-attribute-json is a placeholder that can be replaced with any user defined JSON attribute name.
Expressions are combined with either AND logic operator or OR logical
operator but not both of them together i.e. only one of the AND or OR
operator can be used throughout the filter string and both the operators
cannot be used together. No other logical operators are
supported. At most three filter fields are allowed in the filter
string and if provided more than that then INVALID_ARGUMENT error is
returned by the API.
Here are a few examples:
spec_type.enum_values.values.id: rest-id- The filter string specifies that the id of the allowed value associated with the spec_type attribute is rest-id.spec_type.enum_values.values.display_name: \"Rest Display Name\"- The filter string specifies that the display name of the allowed value associated with the spec_type attribute isRest Display Name.spec_type.enum_values.values.id: grpc-id AND create_time < \"2021-08-15T14:50:00Z\" AND create_time > \"2021-08-10T12:00:00Z\"- The id of the allowed value associated with the spec_type attribute is grpc-id and the spec was created before 2021-08-15 14:50:00 UTC and after 2021-08-10 12:00:00 UTC.spec_type.enum_values.values.id: rest-id OR spec_type.enum_values.values.id: grpc-id- The id of the allowed value associated with the spec_type attribute is rest-id or grpc-id.
spec_type.enum_values.values.id: rest-id AND attributes.projects/test-project-id/locations/test-location-id/ attributes/17650f90-4a29-4971-b3c0-d5532da3764b.enum_values.values.id: test- The filter string specifies that the id of the allowed value associated with the spec_type attribute is rest-id and the id of the allowed value associated with the user defined attribute of type enum is test.
609 610 611 612 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 609 class ListSpecsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Optional. The maximum number of specs to return. The service may return fewer than this value. If unspecified, at most 50 specs will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
609 610 611 612 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 609 class ListSpecsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous ListSpecs call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListSpecs must
match the call that provided the page token.
609 610 611 612 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 609 class ListSpecsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent, which owns this collection of specs.
Format:
projects/{project}/locations/{location}/apis/{api}/versions/{version}.
609 610 611 612 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 609 class ListSpecsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |