Class: Google::Cloud::ApiHub::V1::ListSpecsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ListSpecsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/apihub_service.rb
Overview
The ListSpecs method's response.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#specs ⇒ ::Array<::Google::Cloud::ApiHub::V1::Spec>
The specs corresponding to an API Version.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
622 623 624 625 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 622 class ListSpecsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#specs ⇒ ::Array<::Google::Cloud::ApiHub::V1::Spec>
Returns The specs corresponding to an API Version.
622 623 624 625 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 622 class ListSpecsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |