Class: Google::Cloud::ApiHub::V1::LookupRuntimeProjectAttachmentResponse
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::LookupRuntimeProjectAttachmentResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/runtime_project_attachment_service.rb
Overview
The ListRuntimeProjectAttachments method's response.
Instance Attribute Summary collapse
-
#runtime_project_attachment ⇒ ::Google::Cloud::ApiHub::V1::RuntimeProjectAttachment
Runtime project attachment for a project if exists, empty otherwise.
Instance Attribute Details
#runtime_project_attachment ⇒ ::Google::Cloud::ApiHub::V1::RuntimeProjectAttachment
Returns Runtime project attachment for a project if exists, empty otherwise.
153 154 155 156 |
# File 'proto_docs/google/cloud/apihub/v1/runtime_project_attachment_service.rb', line 153 class LookupRuntimeProjectAttachmentResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |