Class: Google::Cloud::ApiHub::V1::OperationDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

The operation details parsed from the spec.

Instance Attribute Summary collapse

Instance Attribute Details

#deprecated::Boolean

Returns Optional. For OpenAPI spec, this will be set if operation.deprecatedis marked as true in the spec.

Returns:

  • (::Boolean)

    Optional. For OpenAPI spec, this will be set if operation.deprecatedis marked as true in the spec.



839
840
841
842
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 839

class OperationDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String

Returns Optional. Description of the operation behavior. For OpenAPI spec, this will map to operation.description in the spec, in case description is empty, operation.summary will be used.

Returns:

  • (::String)

    Optional. Description of the operation behavior. For OpenAPI spec, this will map to operation.description in the spec, in case description is empty, operation.summary will be used.



839
840
841
842
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 839

class OperationDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#documentation::Google::Cloud::ApiHub::V1::Documentation

Returns Optional. Additional external documentation for this operation. For OpenAPI spec, this will map to operation.documentation in the spec.

Returns:



839
840
841
842
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 839

class OperationDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#http_operation::Google::Cloud::ApiHub::V1::HttpOperation

Returns The HTTP Operation.

Returns:



839
840
841
842
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 839

class OperationDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end