Class: Google::Cloud::ApiHub::V1::Path

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

The path details derived from the spec.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Optional. A short description for the path applicable to all operations.

Returns:

  • (::String)

    Optional. A short description for the path applicable to all operations.



902
903
904
905
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 902

class Path
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#path::String

Returns Optional. Complete path relative to server endpoint. Note: Even though this field is optional, it is required for CreateApiOperation API and we will fail the request if not provided.

Returns:

  • (::String)

    Optional. Complete path relative to server endpoint. Note: Even though this field is optional, it is required for CreateApiOperation API and we will fail the request if not provided.



902
903
904
905
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 902

class Path
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end