Class: Google::Cloud::ApiHub::V1::Plugin::ConfigTemplate

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/plugin_service.rb

Overview

ConfigTemplate represents the configuration template for a plugin.

Defined Under Namespace

Classes: AuthConfigTemplate

Instance Attribute Summary collapse

Instance Attribute Details

#additional_config_template::Array<::Google::Cloud::ApiHub::V1::ConfigVariableTemplate>

Returns Optional. The list of additional configuration variables for the plugin's configuration.

Returns:



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 122

class ConfigTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AuthConfigTemplate represents the authentication template for a plugin.
  # @!attribute [rw] supported_auth_types
  #   @return [::Array<::Google::Cloud::ApiHub::V1::AuthType>]
  #     Required. The list of authentication types supported by the plugin.
  # @!attribute [rw] service_account
  #   @return [::Google::Cloud::ApiHub::V1::GoogleServiceAccountConfig]
  #     Optional. The service account of the plugin hosting service.
  #     This service account should be granted the required permissions on the
  #     Auth Config parameters provided while creating the plugin instances
  #     corresponding to this plugin.
  #
  #     For example, if the plugin instance auth config requires a secret
  #     manager secret, the service account should be granted the
  #     secretmanager.versions.access permission on the corresponding secret,
  #     if the plugin instance auth config contains a service account, the
  #     service account should be granted the
  #     iam.serviceAccounts.getAccessToken permission on the corresponding
  #     service account.
  class AuthConfigTemplate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#auth_config_template::Google::Cloud::ApiHub::V1::Plugin::ConfigTemplate::AuthConfigTemplate

Returns Optional. The authentication template for the plugin.

Returns:



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 122

class ConfigTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AuthConfigTemplate represents the authentication template for a plugin.
  # @!attribute [rw] supported_auth_types
  #   @return [::Array<::Google::Cloud::ApiHub::V1::AuthType>]
  #     Required. The list of authentication types supported by the plugin.
  # @!attribute [rw] service_account
  #   @return [::Google::Cloud::ApiHub::V1::GoogleServiceAccountConfig]
  #     Optional. The service account of the plugin hosting service.
  #     This service account should be granted the required permissions on the
  #     Auth Config parameters provided while creating the plugin instances
  #     corresponding to this plugin.
  #
  #     For example, if the plugin instance auth config requires a secret
  #     manager secret, the service account should be granted the
  #     secretmanager.versions.access permission on the corresponding secret,
  #     if the plugin instance auth config contains a service account, the
  #     service account should be granted the
  #     iam.serviceAccounts.getAccessToken permission on the corresponding
  #     service account.
  class AuthConfigTemplate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end