Class: Google::Cloud::ApiHub::V1::PluginActionConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/plugin_service.rb

Overview

PluginActionConfig represents the configuration of an action supported by a plugin.

Defined Under Namespace

Modules: TriggerMode

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Required. The description of the operation performed by the action.

Returns:

  • (::String)

    Required. The description of the operation performed by the action.



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 194

class PluginActionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution mode of the action.
  module TriggerMode
    # Default unspecified mode.
    TRIGGER_MODE_UNSPECIFIED = 0

    # This action can be executed by invoking
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#execute_plugin_instance_action ExecutePluginInstanceAction}
    # API with the given action id. To support this, the plugin hosting service
    # should handle this action id as part of execute call.
    API_HUB_ON_DEMAND_TRIGGER = 1

    # This action will be executed on schedule by invoking
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#execute_plugin_instance_action ExecutePluginInstanceAction}
    # API with the given action id. To set the schedule, the user can provide
    # the cron expression in the
    # [PluginAction][PluginAction.schedule_cron_expression] field for a given
    # plugin instance. To support this, the plugin hosting service should
    # handle this action id as part of execute call.
    # Note, on demand execution will be supported by default in this trigger
    # mode.
    API_HUB_SCHEDULE_TRIGGER = 2

    # The execution of this plugin is not handled by API hub. In this case,
    # the plugin hosting service need not handle this action id as part of
    # the execute call.
    NON_API_HUB_MANAGED = 3
  end
end

#display_name::String

Returns Required. The display name of the action.

Returns:

  • (::String)

    Required. The display name of the action.



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 194

class PluginActionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution mode of the action.
  module TriggerMode
    # Default unspecified mode.
    TRIGGER_MODE_UNSPECIFIED = 0

    # This action can be executed by invoking
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#execute_plugin_instance_action ExecutePluginInstanceAction}
    # API with the given action id. To support this, the plugin hosting service
    # should handle this action id as part of execute call.
    API_HUB_ON_DEMAND_TRIGGER = 1

    # This action will be executed on schedule by invoking
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#execute_plugin_instance_action ExecutePluginInstanceAction}
    # API with the given action id. To set the schedule, the user can provide
    # the cron expression in the
    # [PluginAction][PluginAction.schedule_cron_expression] field for a given
    # plugin instance. To support this, the plugin hosting service should
    # handle this action id as part of execute call.
    # Note, on demand execution will be supported by default in this trigger
    # mode.
    API_HUB_SCHEDULE_TRIGGER = 2

    # The execution of this plugin is not handled by API hub. In this case,
    # the plugin hosting service need not handle this action id as part of
    # the execute call.
    NON_API_HUB_MANAGED = 3
  end
end

#id::String

Returns Required. The id of the action.

Returns:

  • (::String)

    Required. The id of the action.



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 194

class PluginActionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution mode of the action.
  module TriggerMode
    # Default unspecified mode.
    TRIGGER_MODE_UNSPECIFIED = 0

    # This action can be executed by invoking
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#execute_plugin_instance_action ExecutePluginInstanceAction}
    # API with the given action id. To support this, the plugin hosting service
    # should handle this action id as part of execute call.
    API_HUB_ON_DEMAND_TRIGGER = 1

    # This action will be executed on schedule by invoking
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#execute_plugin_instance_action ExecutePluginInstanceAction}
    # API with the given action id. To set the schedule, the user can provide
    # the cron expression in the
    # [PluginAction][PluginAction.schedule_cron_expression] field for a given
    # plugin instance. To support this, the plugin hosting service should
    # handle this action id as part of execute call.
    # Note, on demand execution will be supported by default in this trigger
    # mode.
    API_HUB_SCHEDULE_TRIGGER = 2

    # The execution of this plugin is not handled by API hub. In this case,
    # the plugin hosting service need not handle this action id as part of
    # the execute call.
    NON_API_HUB_MANAGED = 3
  end
end

#trigger_mode::Google::Cloud::ApiHub::V1::PluginActionConfig::TriggerMode

Returns Required. The trigger mode supported by the action.

Returns:



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 194

class PluginActionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution mode of the action.
  module TriggerMode
    # Default unspecified mode.
    TRIGGER_MODE_UNSPECIFIED = 0

    # This action can be executed by invoking
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#execute_plugin_instance_action ExecutePluginInstanceAction}
    # API with the given action id. To support this, the plugin hosting service
    # should handle this action id as part of execute call.
    API_HUB_ON_DEMAND_TRIGGER = 1

    # This action will be executed on schedule by invoking
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#execute_plugin_instance_action ExecutePluginInstanceAction}
    # API with the given action id. To set the schedule, the user can provide
    # the cron expression in the
    # [PluginAction][PluginAction.schedule_cron_expression] field for a given
    # plugin instance. To support this, the plugin hosting service should
    # handle this action id as part of execute call.
    # Note, on demand execution will be supported by default in this trigger
    # mode.
    API_HUB_SCHEDULE_TRIGGER = 2

    # The execution of this plugin is not handled by API hub. In this case,
    # the plugin hosting service need not handle this action id as part of
    # the execute call.
    NON_API_HUB_MANAGED = 3
  end
end