Class: Google::Cloud::ApiHub::V1::PluginInstance

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/plugin_service.rb

Overview

Represents a plugin instance resource in the API Hub. A PluginInstance is a specific instance of a hub plugin with its own configuration, state, and execution details.

Defined Under Namespace

Modules: State Classes: AdditionalConfigEntry

Instance Attribute Summary collapse

Instance Attribute Details

#actions::Array<::Google::Cloud::ApiHub::V1::PluginInstanceAction>

Returns Required. The action status for the plugin instance.

Returns:



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 393

class PluginInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::ConfigVariable]
  class AdditionalConfigEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The plugin instance is being created.
    CREATING = 1

    # The plugin instance is active and ready for executions. This is the only
    # state where executions can run on the plugin instance.
    ACTIVE = 2

    # The updated config that contains
    # {::Google::Cloud::ApiHub::V1::PluginInstance#additional_config additional_config}
    # and {::Google::Cloud::ApiHub::V1::PluginInstance#auth_config auth_config} is
    # being applied.
    APPLYING_CONFIG = 3

    # The ERROR state can come while applying config. Users
    # can retrigger
    # [ApplyPluginInstanceConfig][google.cloud.apihub.v1.ApiHubPlugin.ApplyPluginInstanceConfig]
    # to restore the plugin instance back to active state. Note, In case the
    # ERROR state happens while applying config (auth_config,
    # additional_config), the plugin instance will reflect the config which was
    # trying to be applied while error happened. In order to overwrite, trigger
    # ApplyConfig with a new config.
    ERROR = 4

    # The plugin instance is in a failed state. This indicates that an
    # unrecoverable error occurred during a previous operation (Create,
    # Delete).
    FAILED = 5

    # The plugin instance is being deleted. Delete is only possible if there is
    # no other operation running on the plugin instance and plugin instance
    # action.
    DELETING = 6
  end
end

#additional_config::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::ConfigVariable}

Returns Optional. The additional information for this plugin instance corresponding to the additional config template of the plugin. This information will be sent to plugin hosting service on each call to plugin hosted service. The key will be the config_variable_template.display_name to uniquely identify the config variable.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::ConfigVariable})

    Optional. The additional information for this plugin instance corresponding to the additional config template of the plugin. This information will be sent to plugin hosting service on each call to plugin hosted service. The key will be the config_variable_template.display_name to uniquely identify the config variable.



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 393

class PluginInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::ConfigVariable]
  class AdditionalConfigEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The plugin instance is being created.
    CREATING = 1

    # The plugin instance is active and ready for executions. This is the only
    # state where executions can run on the plugin instance.
    ACTIVE = 2

    # The updated config that contains
    # {::Google::Cloud::ApiHub::V1::PluginInstance#additional_config additional_config}
    # and {::Google::Cloud::ApiHub::V1::PluginInstance#auth_config auth_config} is
    # being applied.
    APPLYING_CONFIG = 3

    # The ERROR state can come while applying config. Users
    # can retrigger
    # [ApplyPluginInstanceConfig][google.cloud.apihub.v1.ApiHubPlugin.ApplyPluginInstanceConfig]
    # to restore the plugin instance back to active state. Note, In case the
    # ERROR state happens while applying config (auth_config,
    # additional_config), the plugin instance will reflect the config which was
    # trying to be applied while error happened. In order to overwrite, trigger
    # ApplyConfig with a new config.
    ERROR = 4

    # The plugin instance is in a failed state. This indicates that an
    # unrecoverable error occurred during a previous operation (Create,
    # Delete).
    FAILED = 5

    # The plugin instance is being deleted. Delete is only possible if there is
    # no other operation running on the plugin instance and plugin instance
    # action.
    DELETING = 6
  end
end

#auth_config::Google::Cloud::ApiHub::V1::AuthConfig

Returns Optional. The authentication information for this plugin instance.

Returns:



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 393

class PluginInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::ConfigVariable]
  class AdditionalConfigEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The plugin instance is being created.
    CREATING = 1

    # The plugin instance is active and ready for executions. This is the only
    # state where executions can run on the plugin instance.
    ACTIVE = 2

    # The updated config that contains
    # {::Google::Cloud::ApiHub::V1::PluginInstance#additional_config additional_config}
    # and {::Google::Cloud::ApiHub::V1::PluginInstance#auth_config auth_config} is
    # being applied.
    APPLYING_CONFIG = 3

    # The ERROR state can come while applying config. Users
    # can retrigger
    # [ApplyPluginInstanceConfig][google.cloud.apihub.v1.ApiHubPlugin.ApplyPluginInstanceConfig]
    # to restore the plugin instance back to active state. Note, In case the
    # ERROR state happens while applying config (auth_config,
    # additional_config), the plugin instance will reflect the config which was
    # trying to be applied while error happened. In order to overwrite, trigger
    # ApplyConfig with a new config.
    ERROR = 4

    # The plugin instance is in a failed state. This indicates that an
    # unrecoverable error occurred during a previous operation (Create,
    # Delete).
    FAILED = 5

    # The plugin instance is being deleted. Delete is only possible if there is
    # no other operation running on the plugin instance and plugin instance
    # action.
    DELETING = 6
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp indicating when the plugin instance was created.

Returns:



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 393

class PluginInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::ConfigVariable]
  class AdditionalConfigEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The plugin instance is being created.
    CREATING = 1

    # The plugin instance is active and ready for executions. This is the only
    # state where executions can run on the plugin instance.
    ACTIVE = 2

    # The updated config that contains
    # {::Google::Cloud::ApiHub::V1::PluginInstance#additional_config additional_config}
    # and {::Google::Cloud::ApiHub::V1::PluginInstance#auth_config auth_config} is
    # being applied.
    APPLYING_CONFIG = 3

    # The ERROR state can come while applying config. Users
    # can retrigger
    # [ApplyPluginInstanceConfig][google.cloud.apihub.v1.ApiHubPlugin.ApplyPluginInstanceConfig]
    # to restore the plugin instance back to active state. Note, In case the
    # ERROR state happens while applying config (auth_config,
    # additional_config), the plugin instance will reflect the config which was
    # trying to be applied while error happened. In order to overwrite, trigger
    # ApplyConfig with a new config.
    ERROR = 4

    # The plugin instance is in a failed state. This indicates that an
    # unrecoverable error occurred during a previous operation (Create,
    # Delete).
    FAILED = 5

    # The plugin instance is being deleted. Delete is only possible if there is
    # no other operation running on the plugin instance and plugin instance
    # action.
    DELETING = 6
  end
end

#display_name::String

Returns Required. The display name for this plugin instance. Max length is 255 characters.

Returns:

  • (::String)

    Required. The display name for this plugin instance. Max length is 255 characters.



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 393

class PluginInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::ConfigVariable]
  class AdditionalConfigEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The plugin instance is being created.
    CREATING = 1

    # The plugin instance is active and ready for executions. This is the only
    # state where executions can run on the plugin instance.
    ACTIVE = 2

    # The updated config that contains
    # {::Google::Cloud::ApiHub::V1::PluginInstance#additional_config additional_config}
    # and {::Google::Cloud::ApiHub::V1::PluginInstance#auth_config auth_config} is
    # being applied.
    APPLYING_CONFIG = 3

    # The ERROR state can come while applying config. Users
    # can retrigger
    # [ApplyPluginInstanceConfig][google.cloud.apihub.v1.ApiHubPlugin.ApplyPluginInstanceConfig]
    # to restore the plugin instance back to active state. Note, In case the
    # ERROR state happens while applying config (auth_config,
    # additional_config), the plugin instance will reflect the config which was
    # trying to be applied while error happened. In order to overwrite, trigger
    # ApplyConfig with a new config.
    ERROR = 4

    # The plugin instance is in a failed state. This indicates that an
    # unrecoverable error occurred during a previous operation (Create,
    # Delete).
    FAILED = 5

    # The plugin instance is being deleted. Delete is only possible if there is
    # no other operation running on the plugin instance and plugin instance
    # action.
    DELETING = 6
  end
end

#error_message::String (readonly)

Returns Output only. Error message describing the failure, if any, during Create, Delete or ApplyConfig operation corresponding to the plugin instance.This field will only be populated if the plugin instance is in the ERROR or FAILED state.

Returns:

  • (::String)

    Output only. Error message describing the failure, if any, during Create, Delete or ApplyConfig operation corresponding to the plugin instance.This field will only be populated if the plugin instance is in the ERROR or FAILED state.



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 393

class PluginInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::ConfigVariable]
  class AdditionalConfigEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The plugin instance is being created.
    CREATING = 1

    # The plugin instance is active and ready for executions. This is the only
    # state where executions can run on the plugin instance.
    ACTIVE = 2

    # The updated config that contains
    # {::Google::Cloud::ApiHub::V1::PluginInstance#additional_config additional_config}
    # and {::Google::Cloud::ApiHub::V1::PluginInstance#auth_config auth_config} is
    # being applied.
    APPLYING_CONFIG = 3

    # The ERROR state can come while applying config. Users
    # can retrigger
    # [ApplyPluginInstanceConfig][google.cloud.apihub.v1.ApiHubPlugin.ApplyPluginInstanceConfig]
    # to restore the plugin instance back to active state. Note, In case the
    # ERROR state happens while applying config (auth_config,
    # additional_config), the plugin instance will reflect the config which was
    # trying to be applied while error happened. In order to overwrite, trigger
    # ApplyConfig with a new config.
    ERROR = 4

    # The plugin instance is in a failed state. This indicates that an
    # unrecoverable error occurred during a previous operation (Create,
    # Delete).
    FAILED = 5

    # The plugin instance is being deleted. Delete is only possible if there is
    # no other operation running on the plugin instance and plugin instance
    # action.
    DELETING = 6
  end
end

#name::String

Returns Identifier. The unique name of the plugin instance resource. Format: projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}.

Returns:

  • (::String)

    Identifier. The unique name of the plugin instance resource. Format: projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 393

class PluginInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::ConfigVariable]
  class AdditionalConfigEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The plugin instance is being created.
    CREATING = 1

    # The plugin instance is active and ready for executions. This is the only
    # state where executions can run on the plugin instance.
    ACTIVE = 2

    # The updated config that contains
    # {::Google::Cloud::ApiHub::V1::PluginInstance#additional_config additional_config}
    # and {::Google::Cloud::ApiHub::V1::PluginInstance#auth_config auth_config} is
    # being applied.
    APPLYING_CONFIG = 3

    # The ERROR state can come while applying config. Users
    # can retrigger
    # [ApplyPluginInstanceConfig][google.cloud.apihub.v1.ApiHubPlugin.ApplyPluginInstanceConfig]
    # to restore the plugin instance back to active state. Note, In case the
    # ERROR state happens while applying config (auth_config,
    # additional_config), the plugin instance will reflect the config which was
    # trying to be applied while error happened. In order to overwrite, trigger
    # ApplyConfig with a new config.
    ERROR = 4

    # The plugin instance is in a failed state. This indicates that an
    # unrecoverable error occurred during a previous operation (Create,
    # Delete).
    FAILED = 5

    # The plugin instance is being deleted. Delete is only possible if there is
    # no other operation running on the plugin instance and plugin instance
    # action.
    DELETING = 6
  end
end

#source_project_id::String

Returns Optional. The source project id of the plugin instance. This will be the id of runtime project in case of gcp based plugins and org id in case of non gcp based plugins. This field will be a required field for Google provided on-ramp plugins.

Returns:

  • (::String)

    Optional. The source project id of the plugin instance. This will be the id of runtime project in case of gcp based plugins and org id in case of non gcp based plugins. This field will be a required field for Google provided on-ramp plugins.



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 393

class PluginInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::ConfigVariable]
  class AdditionalConfigEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The plugin instance is being created.
    CREATING = 1

    # The plugin instance is active and ready for executions. This is the only
    # state where executions can run on the plugin instance.
    ACTIVE = 2

    # The updated config that contains
    # {::Google::Cloud::ApiHub::V1::PluginInstance#additional_config additional_config}
    # and {::Google::Cloud::ApiHub::V1::PluginInstance#auth_config auth_config} is
    # being applied.
    APPLYING_CONFIG = 3

    # The ERROR state can come while applying config. Users
    # can retrigger
    # [ApplyPluginInstanceConfig][google.cloud.apihub.v1.ApiHubPlugin.ApplyPluginInstanceConfig]
    # to restore the plugin instance back to active state. Note, In case the
    # ERROR state happens while applying config (auth_config,
    # additional_config), the plugin instance will reflect the config which was
    # trying to be applied while error happened. In order to overwrite, trigger
    # ApplyConfig with a new config.
    ERROR = 4

    # The plugin instance is in a failed state. This indicates that an
    # unrecoverable error occurred during a previous operation (Create,
    # Delete).
    FAILED = 5

    # The plugin instance is being deleted. Delete is only possible if there is
    # no other operation running on the plugin instance and plugin instance
    # action.
    DELETING = 6
  end
end

#state::Google::Cloud::ApiHub::V1::PluginInstance::State (readonly)

Returns Output only. The current state of the plugin instance (e.g., enabled, disabled, provisioning).

Returns:



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 393

class PluginInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::ConfigVariable]
  class AdditionalConfigEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The plugin instance is being created.
    CREATING = 1

    # The plugin instance is active and ready for executions. This is the only
    # state where executions can run on the plugin instance.
    ACTIVE = 2

    # The updated config that contains
    # {::Google::Cloud::ApiHub::V1::PluginInstance#additional_config additional_config}
    # and {::Google::Cloud::ApiHub::V1::PluginInstance#auth_config auth_config} is
    # being applied.
    APPLYING_CONFIG = 3

    # The ERROR state can come while applying config. Users
    # can retrigger
    # [ApplyPluginInstanceConfig][google.cloud.apihub.v1.ApiHubPlugin.ApplyPluginInstanceConfig]
    # to restore the plugin instance back to active state. Note, In case the
    # ERROR state happens while applying config (auth_config,
    # additional_config), the plugin instance will reflect the config which was
    # trying to be applied while error happened. In order to overwrite, trigger
    # ApplyConfig with a new config.
    ERROR = 4

    # The plugin instance is in a failed state. This indicates that an
    # unrecoverable error occurred during a previous operation (Create,
    # Delete).
    FAILED = 5

    # The plugin instance is being deleted. Delete is only possible if there is
    # no other operation running on the plugin instance and plugin instance
    # action.
    DELETING = 6
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp indicating when the plugin instance was last updated.

Returns:



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 393

class PluginInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::ConfigVariable]
  class AdditionalConfigEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The plugin instance is being created.
    CREATING = 1

    # The plugin instance is active and ready for executions. This is the only
    # state where executions can run on the plugin instance.
    ACTIVE = 2

    # The updated config that contains
    # {::Google::Cloud::ApiHub::V1::PluginInstance#additional_config additional_config}
    # and {::Google::Cloud::ApiHub::V1::PluginInstance#auth_config auth_config} is
    # being applied.
    APPLYING_CONFIG = 3

    # The ERROR state can come while applying config. Users
    # can retrigger
    # [ApplyPluginInstanceConfig][google.cloud.apihub.v1.ApiHubPlugin.ApplyPluginInstanceConfig]
    # to restore the plugin instance back to active state. Note, In case the
    # ERROR state happens while applying config (auth_config,
    # additional_config), the plugin instance will reflect the config which was
    # trying to be applied while error happened. In order to overwrite, trigger
    # ApplyConfig with a new config.
    ERROR = 4

    # The plugin instance is in a failed state. This indicates that an
    # unrecoverable error occurred during a previous operation (Create,
    # Delete).
    FAILED = 5

    # The plugin instance is being deleted. Delete is only possible if there is
    # no other operation running on the plugin instance and plugin instance
    # action.
    DELETING = 6
  end
end