Module: Google::Cloud::ApiHub::V1::PluginInstance::State

Defined in:
proto_docs/google/cloud/apihub/v1/plugin_service.rb

Overview

State represents the state of the plugin instance.

Constant Summary collapse

STATE_UNSPECIFIED =

Default unspecified state.

0
CREATING =

The plugin instance is being created.

1
ACTIVE =

The plugin instance is active and ready for executions. This is the only state where executions can run on the plugin instance.

2
APPLYING_CONFIG =

The updated config that contains additional_config and auth_config is being applied.

3
ERROR =

The ERROR state can come while applying config. Users can retrigger [ApplyPluginInstanceConfig][google.cloud.apihub.v1.ApiHubPlugin.ApplyPluginInstanceConfig] to restore the plugin instance back to active state. Note, In case the ERROR state happens while applying config (auth_config, additional_config), the plugin instance will reflect the config which was trying to be applied while error happened. In order to overwrite, trigger ApplyConfig with a new config.

4
FAILED =

The plugin instance is in a failed state. This indicates that an unrecoverable error occurred during a previous operation (Create, Delete).

5
DELETING =

The plugin instance is being deleted. Delete is only possible if there is no other operation running on the plugin instance and plugin instance action.

6