Class: Google::Cloud::ApiHub::V1::PluginInstanceAction

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/plugin_service.rb

Overview

PluginInstanceAction represents an action which can be executed in the plugin instance.

Defined Under Namespace

Modules: State Classes: ResourceConfig

Instance Attribute Summary collapse

Instance Attribute Details

#action_id::String

Returns Required. This should map to one of the [action id][google.cloud.apihub.v1.PluginActionConfig.id] specified in actions_config in the plugin.

Returns:

  • (::String)

    Required. This should map to one of the [action id][google.cloud.apihub.v1.PluginActionConfig.id] specified in actions_config in the plugin.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 296

class PluginInstanceAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration of resources created for a given plugin instance action.
  # @!attribute [r] action_type
  #   @return [::Google::Cloud::ApiHub::V1::ActionType]
  #     Output only. The type of the action.
  # @!attribute [r] pubsub_topic
  #   @return [::String]
  #     Output only. The pubsub topic to publish the data to. Format is
  #     projects/\\{project}/topics/\\{topic}
  class ResourceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance action.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The action is enabled in the plugin instance i.e., executions can
    # be triggered for this action.
    ENABLED = 1

    # The action is disabled in the plugin instance i.e., no executions
    # can be triggered for this action. This state indicates that the user
    # explicitly disabled the instance, and no further action is needed unless
    # the user wants to re-enable it.
    DISABLED = 2

    # The action in the plugin instance is being enabled.
    ENABLING = 3

    # The action in the plugin instance is being disabled.
    DISABLING = 4

    # The ERROR state can come while enabling/disabling plugin instance action.
    # Users can retrigger enable, disable via
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#enable_plugin_instance_action EnablePluginInstanceAction}
    # and
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#disable_plugin_instance_action DisablePluginInstanceAction}
    # to restore the action back to enabled/disabled state. Note enable/disable
    # on actions can only be triggered if plugin instance is in Active state.
    ERROR = 5
  end
end

#curation_config::Google::Cloud::ApiHub::V1::CurationConfig

Returns Optional. This configuration should be provided if the plugin action is publishing data to API hub curate layer.

Returns:



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 296

class PluginInstanceAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration of resources created for a given plugin instance action.
  # @!attribute [r] action_type
  #   @return [::Google::Cloud::ApiHub::V1::ActionType]
  #     Output only. The type of the action.
  # @!attribute [r] pubsub_topic
  #   @return [::String]
  #     Output only. The pubsub topic to publish the data to. Format is
  #     projects/\\{project}/topics/\\{topic}
  class ResourceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance action.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The action is enabled in the plugin instance i.e., executions can
    # be triggered for this action.
    ENABLED = 1

    # The action is disabled in the plugin instance i.e., no executions
    # can be triggered for this action. This state indicates that the user
    # explicitly disabled the instance, and no further action is needed unless
    # the user wants to re-enable it.
    DISABLED = 2

    # The action in the plugin instance is being enabled.
    ENABLING = 3

    # The action in the plugin instance is being disabled.
    DISABLING = 4

    # The ERROR state can come while enabling/disabling plugin instance action.
    # Users can retrigger enable, disable via
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#enable_plugin_instance_action EnablePluginInstanceAction}
    # and
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#disable_plugin_instance_action DisablePluginInstanceAction}
    # to restore the action back to enabled/disabled state. Note enable/disable
    # on actions can only be triggered if plugin instance is in Active state.
    ERROR = 5
  end
end

#hub_instance_action::Google::Cloud::ApiHub::V1::ExecutionStatus

Returns Optional. The execution information for the plugin instance action done corresponding to an API hub instance.

Returns:



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 296

class PluginInstanceAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration of resources created for a given plugin instance action.
  # @!attribute [r] action_type
  #   @return [::Google::Cloud::ApiHub::V1::ActionType]
  #     Output only. The type of the action.
  # @!attribute [r] pubsub_topic
  #   @return [::String]
  #     Output only. The pubsub topic to publish the data to. Format is
  #     projects/\\{project}/topics/\\{topic}
  class ResourceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance action.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The action is enabled in the plugin instance i.e., executions can
    # be triggered for this action.
    ENABLED = 1

    # The action is disabled in the plugin instance i.e., no executions
    # can be triggered for this action. This state indicates that the user
    # explicitly disabled the instance, and no further action is needed unless
    # the user wants to re-enable it.
    DISABLED = 2

    # The action in the plugin instance is being enabled.
    ENABLING = 3

    # The action in the plugin instance is being disabled.
    DISABLING = 4

    # The ERROR state can come while enabling/disabling plugin instance action.
    # Users can retrigger enable, disable via
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#enable_plugin_instance_action EnablePluginInstanceAction}
    # and
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#disable_plugin_instance_action DisablePluginInstanceAction}
    # to restore the action back to enabled/disabled state. Note enable/disable
    # on actions can only be triggered if plugin instance is in Active state.
    ERROR = 5
  end
end

#resource_config::Google::Cloud::ApiHub::V1::PluginInstanceAction::ResourceConfig (readonly)

Returns Output only. The configuration of resources created for a given plugin instance action. Note these will be returned only in case of Non-GCP plugins like OPDK.

Returns:



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 296

class PluginInstanceAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration of resources created for a given plugin instance action.
  # @!attribute [r] action_type
  #   @return [::Google::Cloud::ApiHub::V1::ActionType]
  #     Output only. The type of the action.
  # @!attribute [r] pubsub_topic
  #   @return [::String]
  #     Output only. The pubsub topic to publish the data to. Format is
  #     projects/\\{project}/topics/\\{topic}
  class ResourceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance action.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The action is enabled in the plugin instance i.e., executions can
    # be triggered for this action.
    ENABLED = 1

    # The action is disabled in the plugin instance i.e., no executions
    # can be triggered for this action. This state indicates that the user
    # explicitly disabled the instance, and no further action is needed unless
    # the user wants to re-enable it.
    DISABLED = 2

    # The action in the plugin instance is being enabled.
    ENABLING = 3

    # The action in the plugin instance is being disabled.
    DISABLING = 4

    # The ERROR state can come while enabling/disabling plugin instance action.
    # Users can retrigger enable, disable via
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#enable_plugin_instance_action EnablePluginInstanceAction}
    # and
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#disable_plugin_instance_action DisablePluginInstanceAction}
    # to restore the action back to enabled/disabled state. Note enable/disable
    # on actions can only be triggered if plugin instance is in Active state.
    ERROR = 5
  end
end

#schedule_cron_expression::String

Returns Optional. The schedule for this plugin instance action. This can only be set if the plugin supports API_HUB_SCHEDULE_TRIGGER mode for this action.

Returns:

  • (::String)

    Optional. The schedule for this plugin instance action. This can only be set if the plugin supports API_HUB_SCHEDULE_TRIGGER mode for this action.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 296

class PluginInstanceAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration of resources created for a given plugin instance action.
  # @!attribute [r] action_type
  #   @return [::Google::Cloud::ApiHub::V1::ActionType]
  #     Output only. The type of the action.
  # @!attribute [r] pubsub_topic
  #   @return [::String]
  #     Output only. The pubsub topic to publish the data to. Format is
  #     projects/\\{project}/topics/\\{topic}
  class ResourceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance action.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The action is enabled in the plugin instance i.e., executions can
    # be triggered for this action.
    ENABLED = 1

    # The action is disabled in the plugin instance i.e., no executions
    # can be triggered for this action. This state indicates that the user
    # explicitly disabled the instance, and no further action is needed unless
    # the user wants to re-enable it.
    DISABLED = 2

    # The action in the plugin instance is being enabled.
    ENABLING = 3

    # The action in the plugin instance is being disabled.
    DISABLING = 4

    # The ERROR state can come while enabling/disabling plugin instance action.
    # Users can retrigger enable, disable via
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#enable_plugin_instance_action EnablePluginInstanceAction}
    # and
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#disable_plugin_instance_action DisablePluginInstanceAction}
    # to restore the action back to enabled/disabled state. Note enable/disable
    # on actions can only be triggered if plugin instance is in Active state.
    ERROR = 5
  end
end

#schedule_time_zone::String

Returns Optional. The time zone for the schedule cron expression. If not provided, UTC will be used.

Returns:

  • (::String)

    Optional. The time zone for the schedule cron expression. If not provided, UTC will be used.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 296

class PluginInstanceAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration of resources created for a given plugin instance action.
  # @!attribute [r] action_type
  #   @return [::Google::Cloud::ApiHub::V1::ActionType]
  #     Output only. The type of the action.
  # @!attribute [r] pubsub_topic
  #   @return [::String]
  #     Output only. The pubsub topic to publish the data to. Format is
  #     projects/\\{project}/topics/\\{topic}
  class ResourceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance action.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The action is enabled in the plugin instance i.e., executions can
    # be triggered for this action.
    ENABLED = 1

    # The action is disabled in the plugin instance i.e., no executions
    # can be triggered for this action. This state indicates that the user
    # explicitly disabled the instance, and no further action is needed unless
    # the user wants to re-enable it.
    DISABLED = 2

    # The action in the plugin instance is being enabled.
    ENABLING = 3

    # The action in the plugin instance is being disabled.
    DISABLING = 4

    # The ERROR state can come while enabling/disabling plugin instance action.
    # Users can retrigger enable, disable via
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#enable_plugin_instance_action EnablePluginInstanceAction}
    # and
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#disable_plugin_instance_action DisablePluginInstanceAction}
    # to restore the action back to enabled/disabled state. Note enable/disable
    # on actions can only be triggered if plugin instance is in Active state.
    ERROR = 5
  end
end

#service_account::String

Returns Optional. The service account used to publish data. Note, the service account will only be accepted for non GCP plugins like OPDK.

Returns:

  • (::String)

    Optional. The service account used to publish data. Note, the service account will only be accepted for non GCP plugins like OPDK.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 296

class PluginInstanceAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration of resources created for a given plugin instance action.
  # @!attribute [r] action_type
  #   @return [::Google::Cloud::ApiHub::V1::ActionType]
  #     Output only. The type of the action.
  # @!attribute [r] pubsub_topic
  #   @return [::String]
  #     Output only. The pubsub topic to publish the data to. Format is
  #     projects/\\{project}/topics/\\{topic}
  class ResourceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance action.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The action is enabled in the plugin instance i.e., executions can
    # be triggered for this action.
    ENABLED = 1

    # The action is disabled in the plugin instance i.e., no executions
    # can be triggered for this action. This state indicates that the user
    # explicitly disabled the instance, and no further action is needed unless
    # the user wants to re-enable it.
    DISABLED = 2

    # The action in the plugin instance is being enabled.
    ENABLING = 3

    # The action in the plugin instance is being disabled.
    DISABLING = 4

    # The ERROR state can come while enabling/disabling plugin instance action.
    # Users can retrigger enable, disable via
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#enable_plugin_instance_action EnablePluginInstanceAction}
    # and
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#disable_plugin_instance_action DisablePluginInstanceAction}
    # to restore the action back to enabled/disabled state. Note enable/disable
    # on actions can only be triggered if plugin instance is in Active state.
    ERROR = 5
  end
end

#state::Google::Cloud::ApiHub::V1::PluginInstanceAction::State (readonly)

Returns Output only. The current state of the plugin action in the plugin instance.

Returns:



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 296

class PluginInstanceAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration of resources created for a given plugin instance action.
  # @!attribute [r] action_type
  #   @return [::Google::Cloud::ApiHub::V1::ActionType]
  #     Output only. The type of the action.
  # @!attribute [r] pubsub_topic
  #   @return [::String]
  #     Output only. The pubsub topic to publish the data to. Format is
  #     projects/\\{project}/topics/\\{topic}
  class ResourceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State represents the state of the plugin instance action.
  module State
    # Default unspecified state.
    STATE_UNSPECIFIED = 0

    # The action is enabled in the plugin instance i.e., executions can
    # be triggered for this action.
    ENABLED = 1

    # The action is disabled in the plugin instance i.e., no executions
    # can be triggered for this action. This state indicates that the user
    # explicitly disabled the instance, and no further action is needed unless
    # the user wants to re-enable it.
    DISABLED = 2

    # The action in the plugin instance is being enabled.
    ENABLING = 3

    # The action in the plugin instance is being disabled.
    DISABLING = 4

    # The ERROR state can come while enabling/disabling plugin instance action.
    # Users can retrigger enable, disable via
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#enable_plugin_instance_action EnablePluginInstanceAction}
    # and
    # {::Google::Cloud::ApiHub::V1::ApiHubPlugin::Rest::Client#disable_plugin_instance_action DisablePluginInstanceAction}
    # to restore the action back to enabled/disabled state. Note enable/disable
    # on actions can only be triggered if plugin instance is in Active state.
    ERROR = 5
  end
end