Class: Google::Cloud::ApiHub::V1::SearchResourcesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::SearchResourcesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/apihub_service.rb
Overview
Response for the SearchResources method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
Pass this token in the SearchResourcesRequest to continue to list results.
-
#search_results ⇒ ::Array<::Google::Cloud::ApiHub::V1::SearchResult>
List of search results according to the filter and search query specified.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns Pass this token in the SearchResourcesRequest to continue to list results. If all results have been returned, this field is an empty string or not present in the response.
1311 1312 1313 1314 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1311 class SearchResourcesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#search_results ⇒ ::Array<::Google::Cloud::ApiHub::V1::SearchResult>
Returns List of search results according to the filter and search query specified. The order of search results represents the ranking.
1311 1312 1313 1314 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 1311 class SearchResourcesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |