Class: Google::Cloud::ApiHub::V1::Secret

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

Secret provides a reference to entries in Secret Manager.

Instance Attribute Summary collapse

Instance Attribute Details

#secret_version::String

Returns Required. The resource name of the secret version in the format, format as: projects/*/secrets/*/versions/*.

Returns:

  • (::String)

    Required. The resource name of the secret version in the format, format as: projects/*/secrets/*/versions/*.



1415
1416
1417
1418
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1415

class Secret
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end