Class: Google::Cloud::ApiHub::V1::SourceMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

SourceMetadata represents the metadata for a resource at the source.

Defined Under Namespace

Modules: SourceType Classes: PluginInstanceActionSource

Instance Attribute Summary collapse

Instance Attribute Details

#original_resource_create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the resource was created at the source.

Returns:



1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1698

class SourceMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # PluginInstanceActionSource represents the plugin instance action source.
  # @!attribute [r] plugin_instance
  #   @return [::String]
  #     Output only. The resource name of the source plugin instance.
  #     Format is
  #     `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}`
  # @!attribute [r] action_id
  #   @return [::String]
  #     Output only. The id of the plugin instance action.
  class PluginInstanceActionSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The possible types of the source.
  module SourceType
    # Source type not specified.
    SOURCE_TYPE_UNSPECIFIED = 0

    # Source type plugin.
    PLUGIN = 1
  end
end

#original_resource_id::String (readonly)

Returns Output only. The unique identifier of the resource at the source.

Returns:

  • (::String)

    Output only. The unique identifier of the resource at the source.



1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1698

class SourceMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # PluginInstanceActionSource represents the plugin instance action source.
  # @!attribute [r] plugin_instance
  #   @return [::String]
  #     Output only. The resource name of the source plugin instance.
  #     Format is
  #     `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}`
  # @!attribute [r] action_id
  #   @return [::String]
  #     Output only. The id of the plugin instance action.
  class PluginInstanceActionSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The possible types of the source.
  module SourceType
    # Source type not specified.
    SOURCE_TYPE_UNSPECIFIED = 0

    # Source type plugin.
    PLUGIN = 1
  end
end

#original_resource_update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the resource was last updated at the source.

Returns:



1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1698

class SourceMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # PluginInstanceActionSource represents the plugin instance action source.
  # @!attribute [r] plugin_instance
  #   @return [::String]
  #     Output only. The resource name of the source plugin instance.
  #     Format is
  #     `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}`
  # @!attribute [r] action_id
  #   @return [::String]
  #     Output only. The id of the plugin instance action.
  class PluginInstanceActionSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The possible types of the source.
  module SourceType
    # Source type not specified.
    SOURCE_TYPE_UNSPECIFIED = 0

    # Source type plugin.
    PLUGIN = 1
  end
end

#plugin_instance_action_source::Google::Cloud::ApiHub::V1::SourceMetadata::PluginInstanceActionSource (readonly)

Returns Output only. The source of the resource is a plugin instance action.

Returns:



1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1698

class SourceMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # PluginInstanceActionSource represents the plugin instance action source.
  # @!attribute [r] plugin_instance
  #   @return [::String]
  #     Output only. The resource name of the source plugin instance.
  #     Format is
  #     `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}`
  # @!attribute [r] action_id
  #   @return [::String]
  #     Output only. The id of the plugin instance action.
  class PluginInstanceActionSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The possible types of the source.
  module SourceType
    # Source type not specified.
    SOURCE_TYPE_UNSPECIFIED = 0

    # Source type plugin.
    PLUGIN = 1
  end
end

#source_type::Google::Cloud::ApiHub::V1::SourceMetadata::SourceType (readonly)

Returns Output only. The type of the source.

Returns:



1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1698

class SourceMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # PluginInstanceActionSource represents the plugin instance action source.
  # @!attribute [r] plugin_instance
  #   @return [::String]
  #     Output only. The resource name of the source plugin instance.
  #     Format is
  #     `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}`
  # @!attribute [r] action_id
  #   @return [::String]
  #     Output only. The id of the plugin instance action.
  class PluginInstanceActionSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The possible types of the source.
  module SourceType
    # Source type not specified.
    SOURCE_TYPE_UNSPECIFIED = 0

    # Source type plugin.
    PLUGIN = 1
  end
end