Class: Google::Cloud::ApiHub::V1::Spec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

Represents a spec associated with an API version in the API Hub. Note that specs of various types can be uploaded, however parsing of details is supported for OpenAPI spec currently.

Defined Under Namespace

Modules: ParsingMode Classes: AttributesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#attributes::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues}

Returns Optional. The list of user defined attributes associated with the spec. The key is the attribute name. It will be of the format: projects/{project}/locations/{location}/attributes/{attribute}. The value is the attribute values associated with the resource.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues})

    Optional. The list of user defined attributes associated with the spec. The key is the attribute name. It will be of the format: projects/{project}/locations/{location}/attributes/{attribute}. The value is the attribute values associated with the resource.



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end

#contents::Google::Cloud::ApiHub::V1::SpecContents

Returns Optional. Input only. The contents of the uploaded spec.

Returns:



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the spec was created.

Returns:



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end

#details::Google::Cloud::ApiHub::V1::SpecDetails (readonly)

Returns Output only. Details parsed from the spec.

Returns:



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end

#display_name::String

Returns Required. The display name of the spec. This can contain the file name of the spec.

Returns:

  • (::String)

    Required. The display name of the spec. This can contain the file name of the spec.



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end

#documentation::Google::Cloud::ApiHub::V1::Documentation

Returns Optional. The documentation of the spec. For OpenAPI spec, this will be populated from externalDocs in OpenAPI spec.

Returns:



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end

#lint_response::Google::Cloud::ApiHub::V1::LintResponse

Returns Optional. The lint response for the spec.

Returns:



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end

#name::String

Returns Identifier. The name of the spec.

Format: projects/{project}/locations/{location}/apis/{api}/versions/{version}/specs/{spec}.

Returns:

  • (::String)

    Identifier. The name of the spec.

    Format: projects/{project}/locations/{location}/apis/{api}/versions/{version}/specs/{spec}



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end

#parsing_mode::Google::Cloud::ApiHub::V1::Spec::ParsingMode

Returns Optional. Input only. Enum specifying the parsing mode for OpenAPI Specification (OAS) parsing.

Returns:



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end

#source_metadata::Array<::Google::Cloud::ApiHub::V1::SourceMetadata> (readonly)

Returns Output only. The list of sources and metadata from the sources of the spec.

Returns:



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end

#source_uri::String

Returns Optional. The URI of the spec source in case file is uploaded from an external version control system.

Returns:

  • (::String)

    Optional. The URI of the spec source in case file is uploaded from an external version control system.



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end

#spec_type::Google::Cloud::ApiHub::V1::AttributeValues

Returns Required. The type of spec. The value should be one of the allowed values defined for projects/{project}/locations/{location}/attributes/system-spec-type attribute. The number of values for this attribute will be based on the cardinality of the attribute. The same can be retrieved via GetAttribute API.

Note, this field is mandatory if content is provided.

Returns:

  • (::Google::Cloud::ApiHub::V1::AttributeValues)

    Required. The type of spec. The value should be one of the allowed values defined for projects/{project}/locations/{location}/attributes/system-spec-type attribute. The number of values for this attribute will be based on the cardinality of the attribute. The same can be retrieved via GetAttribute API.

    Note, this field is mandatory if content is provided.



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the spec was last updated.

Returns:



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 335

class Spec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specifies the parsing mode for API specifications during creation and
  # update.
  # - `RELAXED`: Parsing errors in the specification content do not fail the
  # API call.
  # - `STRICT`: Parsing errors in the specification content result in failure
  # of the API call.
  # If not specified, defaults to `RELAXED`.
  module ParsingMode
    # Defaults to `RELAXED`.
    PARSING_MODE_UNSPECIFIED = 0

    # Parsing of the Spec on create and update is relaxed, meaning that
    # parsing errors the spec contents will not fail the API call.
    RELAXED = 1

    # Parsing of the Spec on create and update is strict, meaning that
    # parsing errors in the spec contents will fail the API call.
    STRICT = 2
  end
end