Module: Google::Cloud::ApiHub::V1::Spec::ParsingMode
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
Specifies the parsing mode for API specifications during creation and update.
RELAXED: Parsing errors in the specification content do not fail the API call.STRICT: Parsing errors in the specification content result in failure of the API call. If not specified, defaults toRELAXED.
Constant Summary collapse
- PARSING_MODE_UNSPECIFIED =
Defaults to
RELAXED. 0- RELAXED =
Parsing of the Spec on create and update is relaxed, meaning that parsing errors the spec contents will not fail the API call.
1- STRICT =
Parsing of the Spec on create and update is strict, meaning that parsing errors in the spec contents will fail the API call.
2