Class: Google::Cloud::ApiHub::V1::UpdateCurationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/curate_service.rb

Overview

The [UpdateCuration][ApiHub.UpdateCuration] method's request.

Instance Attribute Summary collapse

Instance Attribute Details

#curation::Google::Cloud::ApiHub::V1::Curation

Returns Required. The curation resource to update.

The curation resource's name field is used to identify the curation resource to update. Format: projects/{project}/locations/{location}/curations/{curation}.

Returns:

  • (::Google::Cloud::ApiHub::V1::Curation)

    Required. The curation resource to update.

    The curation resource's name field is used to identify the curation resource to update. Format: projects/{project}/locations/{location}/curations/{curation}



70
71
72
73
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 70

class UpdateCurationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. The list of fields to update.

Returns:



70
71
72
73
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 70

class UpdateCurationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end