Class: Google::Cloud::ApiHub::V1::UpdateVersionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/apihub_service.rb

Overview

The UpdateVersion method's request.

Instance Attribute Summary collapse

Instance Attribute Details

#update_mask::Google::Protobuf::FieldMask

Returns Required. The list of fields to update.

Returns:



289
290
291
292
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 289

class UpdateVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#version::Google::Cloud::ApiHub::V1::Version

Returns Required. The API version to update.

The version's name field is used to identify the API version to update. Format: projects/{project}/locations/{location}/apis/{api}/versions/{version}.

Returns:

  • (::Google::Cloud::ApiHub::V1::Version)

    Required. The API version to update.

    The version's name field is used to identify the API version to update. Format: projects/{project}/locations/{location}/apis/{api}/versions/{version}



289
290
291
292
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 289

class UpdateVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end