Class: Google::Cloud::ApiHub::V1::Version

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/common_fields.rb

Overview

Represents a version of the API resource in API hub. This is also referred to as the API version.

Defined Under Namespace

Classes: AttributesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#accreditation::Google::Cloud::ApiHub::V1::AttributeValues

Returns Optional. The accreditations associated with the API version. This maps to the following system defined attribute: projects/{project}/locations/{location}/attributes/system-accreditation attribute. The number of values for this attribute will be based on the cardinality of the attribute. The same can be retrieved via GetAttribute API. All values should be from the list of allowed values defined for the attribute.

Returns:

  • (::Google::Cloud::ApiHub::V1::AttributeValues)

    Optional. The accreditations associated with the API version. This maps to the following system defined attribute: projects/{project}/locations/{location}/attributes/system-accreditation attribute. The number of values for this attribute will be based on the cardinality of the attribute. The same can be retrieved via GetAttribute API. All values should be from the list of allowed values defined for the attribute.



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#api_operations::Array<::String> (readonly)

Returns Output only. The operations contained in the API version. These operations will be added to the version when a new spec is added or when an existing spec is updated. Format is projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}.

Returns:

  • (::Array<::String>)

    Output only. The operations contained in the API version. These operations will be added to the version when a new spec is added or when an existing spec is updated. Format is projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#attributes::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues}

Returns Optional. The list of user defined attributes associated with the Version resource. The key is the attribute name. It will be of the format: projects/{project}/locations/{location}/attributes/{attribute}. The value is the attribute values associated with the resource.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues})

    Optional. The list of user defined attributes associated with the Version resource. The key is the attribute name. It will be of the format: projects/{project}/locations/{location}/attributes/{attribute}. The value is the attribute values associated with the resource.



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#compliance::Google::Cloud::ApiHub::V1::AttributeValues

Returns Optional. The compliance associated with the API version. This maps to the following system defined attribute: projects/{project}/locations/{location}/attributes/system-compliance attribute. The number of values for this attribute will be based on the cardinality of the attribute. The same can be retrieved via GetAttribute API. All values should be from the list of allowed values defined for the attribute.

Returns:

  • (::Google::Cloud::ApiHub::V1::AttributeValues)

    Optional. The compliance associated with the API version. This maps to the following system defined attribute: projects/{project}/locations/{location}/attributes/system-compliance attribute. The number of values for this attribute will be based on the cardinality of the attribute. The same can be retrieved via GetAttribute API. All values should be from the list of allowed values defined for the attribute.



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the version was created.

Returns:



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#definitions::Array<::String> (readonly)

Returns Output only. The definitions contained in the API version. These definitions will be added to the version when a new spec is added or when an existing spec is updated. Format is projects/{project}/locations/{location}/apis/{api}/versions/{version}/definitions/{definition}.

Returns:

  • (::Array<::String>)

    Output only. The definitions contained in the API version. These definitions will be added to the version when a new spec is added or when an existing spec is updated. Format is projects/{project}/locations/{location}/apis/{api}/versions/{version}/definitions/{definition}



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#deployments::Array<::String>

Returns Optional. The deployments linked to this API version. Note: A particular API version could be deployed to multiple deployments (for dev deployment, UAT deployment, etc) Format is projects/{project}/locations/{location}/deployments/{deployment}.

Returns:

  • (::Array<::String>)

    Optional. The deployments linked to this API version. Note: A particular API version could be deployed to multiple deployments (for dev deployment, UAT deployment, etc) Format is projects/{project}/locations/{location}/deployments/{deployment}



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns Optional. The description of the version.

Returns:

  • (::String)

    Optional. The description of the version.



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Required. The display name of the version.

Returns:

  • (::String)

    Required. The display name of the version.



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#documentation::Google::Cloud::ApiHub::V1::Documentation

Returns Optional. The documentation of the version.

Returns:



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#lifecycle::Google::Cloud::ApiHub::V1::AttributeValues

Returns Optional. The lifecycle of the API version. This maps to the following system defined attribute: projects/{project}/locations/{location}/attributes/system-lifecycle attribute. The number of values for this attribute will be based on the cardinality of the attribute. The same can be retrieved via GetAttribute API. All values should be from the list of allowed values defined for the attribute.

Returns:

  • (::Google::Cloud::ApiHub::V1::AttributeValues)

    Optional. The lifecycle of the API version. This maps to the following system defined attribute: projects/{project}/locations/{location}/attributes/system-lifecycle attribute. The number of values for this attribute will be based on the cardinality of the attribute. The same can be retrieved via GetAttribute API. All values should be from the list of allowed values defined for the attribute.



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. The name of the version.

Format: projects/{project}/locations/{location}/apis/{api}/versions/{version}.

Returns:

  • (::String)

    Identifier. The name of the version.

    Format: projects/{project}/locations/{location}/apis/{api}/versions/{version}



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#selected_deployment::String

Returns Optional. The selected deployment for a Version resource. This can be used when special handling is needed on client side for a particular deployment linked to the version. Format is projects/{project}/locations/{location}/deployments/{deployment}.

Returns:

  • (::String)

    Optional. The selected deployment for a Version resource. This can be used when special handling is needed on client side for a particular deployment linked to the version. Format is projects/{project}/locations/{location}/deployments/{deployment}



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#source_metadata::Array<::Google::Cloud::ApiHub::V1::SourceMetadata> (readonly)

Returns Output only. The list of sources and metadata from the sources of the version.

Returns:



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#specs::Array<::String> (readonly)

Returns Output only. The specs associated with this version. Note that an API version can be associated with multiple specs. Format is projects/{project}/locations/{location}/apis/{api}/versions/{version}/specs/{spec}.

Returns:

  • (::Array<::String>)

    Output only. The specs associated with this version. Note that an API version can be associated with multiple specs. Format is projects/{project}/locations/{location}/apis/{api}/versions/{version}/specs/{spec}



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the version was last updated.

Returns:



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 260

class Version
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ApiHub::V1::AttributeValues]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end