Class: Google::Cloud::ApiHub::V1::VersionMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apihub/v1/collect_service.rb

Overview

The metadata associated with a version of the API resource.

Instance Attribute Summary collapse

Instance Attribute Details

#deployments::Array<::Google::Cloud::ApiHub::V1::DeploymentMetadata>

Returns Optional. The deployments linked to this API version. Note: A particular API version could be deployed to multiple deployments (for dev deployment, UAT deployment, etc.).

Returns:



118
119
120
121
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 118

class VersionMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#original_create_time::Google::Protobuf::Timestamp

Returns Optional. Timestamp indicating when the version was created at the source.

Returns:



118
119
120
121
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 118

class VersionMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#original_id::String

Returns Optional. The unique identifier of the version in the system where it was originally created.

Returns:

  • (::String)

    Optional. The unique identifier of the version in the system where it was originally created.



118
119
120
121
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 118

class VersionMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#original_update_time::Google::Protobuf::Timestamp

Returns Required. Timestamp indicating when the version was last updated at the source.

Returns:



118
119
120
121
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 118

class VersionMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#specs::Array<::Google::Cloud::ApiHub::V1::SpecMetadata>

Returns Optional. The specs associated with this version. Note that an API version can be associated with multiple specs.

Returns:



118
119
120
121
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 118

class VersionMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#version::Google::Cloud::ApiHub::V1::Version

Returns Required. Represents a version of the API resource in API hub. The ID of the version will be generated by Hub.

Returns:



118
119
120
121
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 118

class VersionMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end