Class: Google::Cloud::ApiHub::V1::Api
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::Api
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
An API resource in the API Hub.
Defined Under Namespace
Classes: AttributesEntry
Instance Attribute Summary collapse
-
#api_functional_requirements ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Optional.
-
#api_requirements ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Optional.
-
#api_style ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Optional.
-
#api_technical_requirements ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Optional.
-
#attributes ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues}
Optional.
-
#business_unit ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Required.
-
#documentation ⇒ ::Google::Cloud::ApiHub::V1::Documentation
Optional.
-
#fingerprint ⇒ ::String
Optional.
-
#maturity_level ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Optional.
-
#name ⇒ ::String
Identifier.
-
#owner ⇒ ::Google::Cloud::ApiHub::V1::Owner
Optional.
-
#selected_version ⇒ ::String
Optional.
-
#source_metadata ⇒ ::Array<::Google::Cloud::ApiHub::V1::SourceMetadata>
readonly
Output only.
-
#target_user ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Optional.
-
#team ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Optional.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#versions ⇒ ::Array<::String>
readonly
Output only.
Instance Attribute Details
#api_functional_requirements ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Optional. The api functional requirements associated with the API resource.
Carinality is 1 for this attribute.
This maps to the following system defined attribute:
projects/{project}/locations/{location}/attributes/system-api-functional-requirements
attribute. The value of the attribute should be a proper URI, and in case
of Cloud Storage URI, it should point to a Cloud Storage object,
not a directory.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#api_requirements ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Optional. The api requirement doc associated with the API resource.
Carinality is 1 for this attribute. This maps to the following system
defined attribute:
projects/{project}/locations/{location}/attributes/system-api-requirements
attribute. The value of the attribute should be a proper URI, and in case
of Cloud Storage URI, it should point to a Cloud Storage object,
not a directory.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#api_style ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Optional. The style of the API.
This maps to the following system defined attribute:
projects/{project}/locations/{location}/attributes/system-api-style
attribute.
The number of values for this attribute will be based on the
cardinality of the attribute. The same can be retrieved via GetAttribute
API. All values should be from the list of allowed values defined for the
attribute.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#api_technical_requirements ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Optional. The api technical requirements associated with the API resource.
Carinality is 1 for this attribute. This maps to the following system
defined attribute:
projects/{project}/locations/{location}/attributes/system-api-technical-requirements
attribute. The value of the attribute should be a proper URI, and in case
of Cloud Storage URI, it should point to a Cloud Storage object,
not a directory.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#attributes ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues}
Returns Optional. The list of user defined attributes associated with the API
resource. The key is the attribute name. It will be of the format:
projects/{project}/locations/{location}/attributes/{attribute}.
The value is the attribute values associated with the resource.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#business_unit ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Optional. The business unit owning the API.
This maps to the following system defined attribute:
projects/{project}/locations/{location}/attributes/system-business-unit
attribute.
The number of values for this attribute will be based on the
cardinality of the attribute. The same can be retrieved via GetAttribute
API. All values should be from the list of allowed values defined for the
attribute.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the API resource was created.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns Optional. The description of the API resource.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#display_name ⇒ ::String
Returns Required. The display name of the API resource.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#documentation ⇒ ::Google::Cloud::ApiHub::V1::Documentation
Returns Optional. The documentation for the API resource.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#fingerprint ⇒ ::String
Returns Optional. Fingerprint of the API resource.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#maturity_level ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Optional. The maturity level of the API.
This maps to the following system defined attribute:
projects/{project}/locations/{location}/attributes/system-maturity-level
attribute.
The number of values for this attribute will be based on the
cardinality of the attribute. The same can be retrieved via GetAttribute
API. All values should be from the list of allowed values defined for the
attribute.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The name of the API resource in the API Hub.
Format:
projects/{project}/locations/{location}/apis/{api}.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#owner ⇒ ::Google::Cloud::ApiHub::V1::Owner
Returns Optional. Owner details for the API resource.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#selected_version ⇒ ::String
Returns Optional. The selected version for an API resource.
This can be used when special handling is needed on client side for
particular version of the API. Format is
projects/{project}/locations/{location}/apis/{api}/versions/{version}.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#source_metadata ⇒ ::Array<::Google::Cloud::ApiHub::V1::SourceMetadata> (readonly)
Returns Output only. The list of sources and metadata from the sources of the API resource.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#target_user ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Optional. The target users for the API.
This maps to the following system defined attribute:
projects/{project}/locations/{location}/attributes/system-target-user
attribute.
The number of values for this attribute will be based on the
cardinality of the attribute. The same can be retrieved via GetAttribute
API. All values should be from the list of allowed values defined for the
attribute.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#team ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Optional. The team owning the API.
This maps to the following system defined attribute:
projects/{project}/locations/{location}/attributes/system-team
attribute.
The number of values for this attribute will be based on the
cardinality of the attribute. The same can be retrieved via GetAttribute
API. All values should be from the list of allowed values defined for the
attribute.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the API resource was last updated.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#versions ⇒ ::Array<::String> (readonly)
Returns Output only. The list of versions present in an API resource.
Note: An API resource can be associated with more than 1 version.
Format is
projects/{project}/locations/{location}/apis/{api}/versions/{version}.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 151 class Api include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |