Class: Google::Cloud::ApiHub::V1::ApiHubCurate::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ApiHubCurate::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/api_hub/v1/api_hub_curate/rest/client.rb
Overview
REST client for the ApiHubCurate service.
This service is used for managing curations for processing API data consumed from collect layer.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the ApiHubCurate Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the ApiHubCurate Client instance.
-
#create_curation(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::ApiHub::V1::Curation
Create a curation resource in the API hub.
-
#delete_curation(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Delete a curation resource in the API hub.
-
#get_curation(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::ApiHub::V1::Curation
Get curation resource details.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new ApiHubCurate REST client object.
-
#list_curations(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ApiHub::V1::Curation>
List curation resources in the API hub.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_curation(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::ApiHub::V1::Curation
Update a curation resource in the API hub.
Methods included from Paths
#curation_path, #location_path, #plugin_instance_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new ApiHubCurate REST client object.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/google/cloud/api_hub/v1/api_hub_curate/rest/client.rb', line 128 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @api_hub_curate_stub = ::Google::Cloud::ApiHub::V1::ApiHubCurate::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @api_hub_curate_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @api_hub_curate_stub.endpoint config.universe_domain = @api_hub_curate_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @api_hub_curate_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
184 185 186 |
# File 'lib/google/cloud/api_hub/v1/api_hub_curate/rest/client.rb', line 184 def location_client @location_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the ApiHubCurate Client class.
See Configuration for a description of the configuration fields.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/google/cloud/api_hub/v1/api_hub_curate/rest/client.rb', line 66 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "ApiHub", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the ApiHubCurate Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
98 99 100 101 |
# File 'lib/google/cloud/api_hub/v1/api_hub_curate/rest/client.rb', line 98 def configure yield @config if block_given? @config end |
#create_curation(request, options = nil) ⇒ ::Google::Cloud::ApiHub::V1::Curation #create_curation(parent: nil, curation_id: nil, curation: nil) ⇒ ::Google::Cloud::ApiHub::V1::Curation
Create a curation resource in the API hub. Once a curation resource is created, plugin instances can start using it.
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/google/cloud/api_hub/v1/api_hub_curate/rest/client.rb', line 255 def create_curation request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ApiHub::V1::CreateCurationRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_curation..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ApiHub::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_curation.timeout, metadata: , retry_policy: @config.rpcs.create_curation.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @api_hub_curate_stub.create_curation request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_curation(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_curation(name: nil) ⇒ ::Google::Protobuf::Empty
Delete a curation resource in the API hub. A curation can only be deleted if it's not being used by any plugin instance.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 |
# File 'lib/google/cloud/api_hub/v1/api_hub_curate/rest/client.rb', line 632 def delete_curation request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ApiHub::V1::DeleteCurationRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_curation..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ApiHub::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_curation.timeout, metadata: , retry_policy: @config.rpcs.delete_curation.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @api_hub_curate_stub.delete_curation request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_curation(request, options = nil) ⇒ ::Google::Cloud::ApiHub::V1::Curation #get_curation(name: nil) ⇒ ::Google::Cloud::ApiHub::V1::Curation
Get curation resource details.
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/google/cloud/api_hub/v1/api_hub_curate/rest/client.rb', line 334 def get_curation request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ApiHub::V1::GetCurationRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_curation..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ApiHub::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_curation.timeout, metadata: , retry_policy: @config.rpcs.get_curation.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @api_hub_curate_stub.get_curation request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_curations(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ApiHub::V1::Curation> #list_curations(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ApiHub::V1::Curation>
List curation resources in the API hub.
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/google/cloud/api_hub/v1/api_hub_curate/rest/client.rb', line 458 def list_curations request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ApiHub::V1::ListCurationsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_curations..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ApiHub::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_curations.timeout, metadata: , retry_policy: @config.rpcs.list_curations.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @api_hub_curate_stub.list_curations request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @api_hub_curate_stub, :list_curations, "curations", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
191 192 193 |
# File 'lib/google/cloud/api_hub/v1/api_hub_curate/rest/client.rb', line 191 def logger @api_hub_curate_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
108 109 110 |
# File 'lib/google/cloud/api_hub/v1/api_hub_curate/rest/client.rb', line 108 def universe_domain @api_hub_curate_stub.universe_domain end |
#update_curation(request, options = nil) ⇒ ::Google::Cloud::ApiHub::V1::Curation #update_curation(curation: nil, update_mask: nil) ⇒ ::Google::Cloud::ApiHub::V1::Curation
Update a curation resource in the API hub. The following fields in the curation can be updated:
The update_mask should be used to specify the fields being updated.
552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 |
# File 'lib/google/cloud/api_hub/v1/api_hub_curate/rest/client.rb', line 552 def update_curation request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ApiHub::V1::UpdateCurationRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_curation..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ApiHub::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_curation.timeout, metadata: , retry_policy: @config.rpcs.update_curation.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @api_hub_curate_stub.update_curation request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |