Class: Google::Cloud::ApiHub::V1::Attribute
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::Attribute
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
An attribute in the API Hub. An attribute is a name value pair which can be attached to different resources in the API hub based on the scope of the attribute. Attributes can either be pre-defined by the API Hub or created by users.
Defined Under Namespace
Modules: DataType, DefinitionType, Scope Classes: AllowedValue
Instance Attribute Summary collapse
-
#allowed_values ⇒ ::Array<::Google::Cloud::ApiHub::V1::Attribute::AllowedValue>
Optional.
-
#cardinality ⇒ ::Integer
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#data_type ⇒ ::Google::Cloud::ApiHub::V1::Attribute::DataType
Required.
-
#definition_type ⇒ ::Google::Cloud::ApiHub::V1::Attribute::DefinitionType
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Required.
-
#mandatory ⇒ ::Boolean
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#scope ⇒ ::Google::Cloud::ApiHub::V1::Attribute::Scope
Required.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#allowed_values ⇒ ::Array<::Google::Cloud::ApiHub::V1::Attribute::AllowedValue>
Returns Optional. The list of allowed values when the attribute value is of type enum. This is required when the data_type of the attribute is ENUM. The maximum number of allowed values of an attribute will be 1000.
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 659 class Attribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The value that can be assigned to the attribute when the data type is # enum. # @!attribute [rw] id # @return [::String] # Required. The ID of the allowed value. # * If provided, the same will be used. The service will throw an error if # the specified id is already used by another allowed value in the same # attribute resource. # * If not provided, a system generated id derived from the display name # will be used. In this case, the service will handle conflict resolution # by adding a system generated suffix in case of duplicates. # # This value should be 4-63 characters, and valid characters # are /[a-z][0-9]-/. # @!attribute [rw] display_name # @return [::String] # Required. The display name of the allowed value. # @!attribute [rw] description # @return [::String] # Optional. The detailed description of the allowed value. # @!attribute [rw] immutable # @return [::Boolean] # Optional. When set to true, the allowed value cannot be updated or # deleted by the user. It can only be true for System defined attributes. class AllowedValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enumeration of attribute definition types. module DefinitionType # Attribute definition type unspecified. DEFINITION_TYPE_UNSPECIFIED = 0 # The attribute is predefined by the API Hub. Note that only the list of # allowed values can be updated in this case via UpdateAttribute method. SYSTEM_DEFINED = 1 # The attribute is defined by the user. USER_DEFINED = 2 end # Enumeration for the scope of the attribute representing the resource in the # API Hub to which the attribute can be linked. module Scope # Scope Unspecified. SCOPE_UNSPECIFIED = 0 # Attribute can be linked to an API. API = 1 # Attribute can be linked to an API version. VERSION = 2 # Attribute can be linked to a Spec. SPEC = 3 # Attribute can be linked to an API Operation. API_OPERATION = 4 # Attribute can be linked to a Deployment. DEPLOYMENT = 5 # Attribute can be linked to a Dependency. DEPENDENCY = 6 # Attribute can be linked to a definition. DEFINITION = 7 # Attribute can be linked to a ExternalAPI. EXTERNAL_API = 8 # Attribute can be linked to a Plugin. PLUGIN = 9 end # Enumeration of attribute's data type. module DataType # Attribute data type unspecified. DATA_TYPE_UNSPECIFIED = 0 # Attribute's value is of type enum. ENUM = 1 # Attribute's value is of type json. JSON = 2 # Attribute's value is of type string. STRING = 3 # Attribute's value is of type uri. URI = 4 end end |
#cardinality ⇒ ::Integer
Returns Optional. The maximum number of values that the attribute can have when associated with an API Hub resource. Cardinality 1 would represent a single-valued attribute. It must not be less than 1 or greater than 20. If not specified, the cardinality would be set to 1 by default and represent a single-valued attribute.
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 659 class Attribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The value that can be assigned to the attribute when the data type is # enum. # @!attribute [rw] id # @return [::String] # Required. The ID of the allowed value. # * If provided, the same will be used. The service will throw an error if # the specified id is already used by another allowed value in the same # attribute resource. # * If not provided, a system generated id derived from the display name # will be used. In this case, the service will handle conflict resolution # by adding a system generated suffix in case of duplicates. # # This value should be 4-63 characters, and valid characters # are /[a-z][0-9]-/. # @!attribute [rw] display_name # @return [::String] # Required. The display name of the allowed value. # @!attribute [rw] description # @return [::String] # Optional. The detailed description of the allowed value. # @!attribute [rw] immutable # @return [::Boolean] # Optional. When set to true, the allowed value cannot be updated or # deleted by the user. It can only be true for System defined attributes. class AllowedValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enumeration of attribute definition types. module DefinitionType # Attribute definition type unspecified. DEFINITION_TYPE_UNSPECIFIED = 0 # The attribute is predefined by the API Hub. Note that only the list of # allowed values can be updated in this case via UpdateAttribute method. SYSTEM_DEFINED = 1 # The attribute is defined by the user. USER_DEFINED = 2 end # Enumeration for the scope of the attribute representing the resource in the # API Hub to which the attribute can be linked. module Scope # Scope Unspecified. SCOPE_UNSPECIFIED = 0 # Attribute can be linked to an API. API = 1 # Attribute can be linked to an API version. VERSION = 2 # Attribute can be linked to a Spec. SPEC = 3 # Attribute can be linked to an API Operation. API_OPERATION = 4 # Attribute can be linked to a Deployment. DEPLOYMENT = 5 # Attribute can be linked to a Dependency. DEPENDENCY = 6 # Attribute can be linked to a definition. DEFINITION = 7 # Attribute can be linked to a ExternalAPI. EXTERNAL_API = 8 # Attribute can be linked to a Plugin. PLUGIN = 9 end # Enumeration of attribute's data type. module DataType # Attribute data type unspecified. DATA_TYPE_UNSPECIFIED = 0 # Attribute's value is of type enum. ENUM = 1 # Attribute's value is of type json. JSON = 2 # Attribute's value is of type string. STRING = 3 # Attribute's value is of type uri. URI = 4 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the attribute was created.
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 659 class Attribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The value that can be assigned to the attribute when the data type is # enum. # @!attribute [rw] id # @return [::String] # Required. The ID of the allowed value. # * If provided, the same will be used. The service will throw an error if # the specified id is already used by another allowed value in the same # attribute resource. # * If not provided, a system generated id derived from the display name # will be used. In this case, the service will handle conflict resolution # by adding a system generated suffix in case of duplicates. # # This value should be 4-63 characters, and valid characters # are /[a-z][0-9]-/. # @!attribute [rw] display_name # @return [::String] # Required. The display name of the allowed value. # @!attribute [rw] description # @return [::String] # Optional. The detailed description of the allowed value. # @!attribute [rw] immutable # @return [::Boolean] # Optional. When set to true, the allowed value cannot be updated or # deleted by the user. It can only be true for System defined attributes. class AllowedValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enumeration of attribute definition types. module DefinitionType # Attribute definition type unspecified. DEFINITION_TYPE_UNSPECIFIED = 0 # The attribute is predefined by the API Hub. Note that only the list of # allowed values can be updated in this case via UpdateAttribute method. SYSTEM_DEFINED = 1 # The attribute is defined by the user. USER_DEFINED = 2 end # Enumeration for the scope of the attribute representing the resource in the # API Hub to which the attribute can be linked. module Scope # Scope Unspecified. SCOPE_UNSPECIFIED = 0 # Attribute can be linked to an API. API = 1 # Attribute can be linked to an API version. VERSION = 2 # Attribute can be linked to a Spec. SPEC = 3 # Attribute can be linked to an API Operation. API_OPERATION = 4 # Attribute can be linked to a Deployment. DEPLOYMENT = 5 # Attribute can be linked to a Dependency. DEPENDENCY = 6 # Attribute can be linked to a definition. DEFINITION = 7 # Attribute can be linked to a ExternalAPI. EXTERNAL_API = 8 # Attribute can be linked to a Plugin. PLUGIN = 9 end # Enumeration of attribute's data type. module DataType # Attribute data type unspecified. DATA_TYPE_UNSPECIFIED = 0 # Attribute's value is of type enum. ENUM = 1 # Attribute's value is of type json. JSON = 2 # Attribute's value is of type string. STRING = 3 # Attribute's value is of type uri. URI = 4 end end |
#data_type ⇒ ::Google::Cloud::ApiHub::V1::Attribute::DataType
Returns Required. The type of the data of the attribute.
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 659 class Attribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The value that can be assigned to the attribute when the data type is # enum. # @!attribute [rw] id # @return [::String] # Required. The ID of the allowed value. # * If provided, the same will be used. The service will throw an error if # the specified id is already used by another allowed value in the same # attribute resource. # * If not provided, a system generated id derived from the display name # will be used. In this case, the service will handle conflict resolution # by adding a system generated suffix in case of duplicates. # # This value should be 4-63 characters, and valid characters # are /[a-z][0-9]-/. # @!attribute [rw] display_name # @return [::String] # Required. The display name of the allowed value. # @!attribute [rw] description # @return [::String] # Optional. The detailed description of the allowed value. # @!attribute [rw] immutable # @return [::Boolean] # Optional. When set to true, the allowed value cannot be updated or # deleted by the user. It can only be true for System defined attributes. class AllowedValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enumeration of attribute definition types. module DefinitionType # Attribute definition type unspecified. DEFINITION_TYPE_UNSPECIFIED = 0 # The attribute is predefined by the API Hub. Note that only the list of # allowed values can be updated in this case via UpdateAttribute method. SYSTEM_DEFINED = 1 # The attribute is defined by the user. USER_DEFINED = 2 end # Enumeration for the scope of the attribute representing the resource in the # API Hub to which the attribute can be linked. module Scope # Scope Unspecified. SCOPE_UNSPECIFIED = 0 # Attribute can be linked to an API. API = 1 # Attribute can be linked to an API version. VERSION = 2 # Attribute can be linked to a Spec. SPEC = 3 # Attribute can be linked to an API Operation. API_OPERATION = 4 # Attribute can be linked to a Deployment. DEPLOYMENT = 5 # Attribute can be linked to a Dependency. DEPENDENCY = 6 # Attribute can be linked to a definition. DEFINITION = 7 # Attribute can be linked to a ExternalAPI. EXTERNAL_API = 8 # Attribute can be linked to a Plugin. PLUGIN = 9 end # Enumeration of attribute's data type. module DataType # Attribute data type unspecified. DATA_TYPE_UNSPECIFIED = 0 # Attribute's value is of type enum. ENUM = 1 # Attribute's value is of type json. JSON = 2 # Attribute's value is of type string. STRING = 3 # Attribute's value is of type uri. URI = 4 end end |
#definition_type ⇒ ::Google::Cloud::ApiHub::V1::Attribute::DefinitionType (readonly)
Returns Output only. The definition type of the attribute.
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 659 class Attribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The value that can be assigned to the attribute when the data type is # enum. # @!attribute [rw] id # @return [::String] # Required. The ID of the allowed value. # * If provided, the same will be used. The service will throw an error if # the specified id is already used by another allowed value in the same # attribute resource. # * If not provided, a system generated id derived from the display name # will be used. In this case, the service will handle conflict resolution # by adding a system generated suffix in case of duplicates. # # This value should be 4-63 characters, and valid characters # are /[a-z][0-9]-/. # @!attribute [rw] display_name # @return [::String] # Required. The display name of the allowed value. # @!attribute [rw] description # @return [::String] # Optional. The detailed description of the allowed value. # @!attribute [rw] immutable # @return [::Boolean] # Optional. When set to true, the allowed value cannot be updated or # deleted by the user. It can only be true for System defined attributes. class AllowedValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enumeration of attribute definition types. module DefinitionType # Attribute definition type unspecified. DEFINITION_TYPE_UNSPECIFIED = 0 # The attribute is predefined by the API Hub. Note that only the list of # allowed values can be updated in this case via UpdateAttribute method. SYSTEM_DEFINED = 1 # The attribute is defined by the user. USER_DEFINED = 2 end # Enumeration for the scope of the attribute representing the resource in the # API Hub to which the attribute can be linked. module Scope # Scope Unspecified. SCOPE_UNSPECIFIED = 0 # Attribute can be linked to an API. API = 1 # Attribute can be linked to an API version. VERSION = 2 # Attribute can be linked to a Spec. SPEC = 3 # Attribute can be linked to an API Operation. API_OPERATION = 4 # Attribute can be linked to a Deployment. DEPLOYMENT = 5 # Attribute can be linked to a Dependency. DEPENDENCY = 6 # Attribute can be linked to a definition. DEFINITION = 7 # Attribute can be linked to a ExternalAPI. EXTERNAL_API = 8 # Attribute can be linked to a Plugin. PLUGIN = 9 end # Enumeration of attribute's data type. module DataType # Attribute data type unspecified. DATA_TYPE_UNSPECIFIED = 0 # Attribute's value is of type enum. ENUM = 1 # Attribute's value is of type json. JSON = 2 # Attribute's value is of type string. STRING = 3 # Attribute's value is of type uri. URI = 4 end end |
#description ⇒ ::String
Returns Optional. The description of the attribute.
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 659 class Attribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The value that can be assigned to the attribute when the data type is # enum. # @!attribute [rw] id # @return [::String] # Required. The ID of the allowed value. # * If provided, the same will be used. The service will throw an error if # the specified id is already used by another allowed value in the same # attribute resource. # * If not provided, a system generated id derived from the display name # will be used. In this case, the service will handle conflict resolution # by adding a system generated suffix in case of duplicates. # # This value should be 4-63 characters, and valid characters # are /[a-z][0-9]-/. # @!attribute [rw] display_name # @return [::String] # Required. The display name of the allowed value. # @!attribute [rw] description # @return [::String] # Optional. The detailed description of the allowed value. # @!attribute [rw] immutable # @return [::Boolean] # Optional. When set to true, the allowed value cannot be updated or # deleted by the user. It can only be true for System defined attributes. class AllowedValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enumeration of attribute definition types. module DefinitionType # Attribute definition type unspecified. DEFINITION_TYPE_UNSPECIFIED = 0 # The attribute is predefined by the API Hub. Note that only the list of # allowed values can be updated in this case via UpdateAttribute method. SYSTEM_DEFINED = 1 # The attribute is defined by the user. USER_DEFINED = 2 end # Enumeration for the scope of the attribute representing the resource in the # API Hub to which the attribute can be linked. module Scope # Scope Unspecified. SCOPE_UNSPECIFIED = 0 # Attribute can be linked to an API. API = 1 # Attribute can be linked to an API version. VERSION = 2 # Attribute can be linked to a Spec. SPEC = 3 # Attribute can be linked to an API Operation. API_OPERATION = 4 # Attribute can be linked to a Deployment. DEPLOYMENT = 5 # Attribute can be linked to a Dependency. DEPENDENCY = 6 # Attribute can be linked to a definition. DEFINITION = 7 # Attribute can be linked to a ExternalAPI. EXTERNAL_API = 8 # Attribute can be linked to a Plugin. PLUGIN = 9 end # Enumeration of attribute's data type. module DataType # Attribute data type unspecified. DATA_TYPE_UNSPECIFIED = 0 # Attribute's value is of type enum. ENUM = 1 # Attribute's value is of type json. JSON = 2 # Attribute's value is of type string. STRING = 3 # Attribute's value is of type uri. URI = 4 end end |
#display_name ⇒ ::String
Returns Required. The display name of the attribute.
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 659 class Attribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The value that can be assigned to the attribute when the data type is # enum. # @!attribute [rw] id # @return [::String] # Required. The ID of the allowed value. # * If provided, the same will be used. The service will throw an error if # the specified id is already used by another allowed value in the same # attribute resource. # * If not provided, a system generated id derived from the display name # will be used. In this case, the service will handle conflict resolution # by adding a system generated suffix in case of duplicates. # # This value should be 4-63 characters, and valid characters # are /[a-z][0-9]-/. # @!attribute [rw] display_name # @return [::String] # Required. The display name of the allowed value. # @!attribute [rw] description # @return [::String] # Optional. The detailed description of the allowed value. # @!attribute [rw] immutable # @return [::Boolean] # Optional. When set to true, the allowed value cannot be updated or # deleted by the user. It can only be true for System defined attributes. class AllowedValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enumeration of attribute definition types. module DefinitionType # Attribute definition type unspecified. DEFINITION_TYPE_UNSPECIFIED = 0 # The attribute is predefined by the API Hub. Note that only the list of # allowed values can be updated in this case via UpdateAttribute method. SYSTEM_DEFINED = 1 # The attribute is defined by the user. USER_DEFINED = 2 end # Enumeration for the scope of the attribute representing the resource in the # API Hub to which the attribute can be linked. module Scope # Scope Unspecified. SCOPE_UNSPECIFIED = 0 # Attribute can be linked to an API. API = 1 # Attribute can be linked to an API version. VERSION = 2 # Attribute can be linked to a Spec. SPEC = 3 # Attribute can be linked to an API Operation. API_OPERATION = 4 # Attribute can be linked to a Deployment. DEPLOYMENT = 5 # Attribute can be linked to a Dependency. DEPENDENCY = 6 # Attribute can be linked to a definition. DEFINITION = 7 # Attribute can be linked to a ExternalAPI. EXTERNAL_API = 8 # Attribute can be linked to a Plugin. PLUGIN = 9 end # Enumeration of attribute's data type. module DataType # Attribute data type unspecified. DATA_TYPE_UNSPECIFIED = 0 # Attribute's value is of type enum. ENUM = 1 # Attribute's value is of type json. JSON = 2 # Attribute's value is of type string. STRING = 3 # Attribute's value is of type uri. URI = 4 end end |
#mandatory ⇒ ::Boolean (readonly)
Returns Output only. When mandatory is true, the attribute is mandatory for the resource specified in the scope. Only System defined attributes can be mandatory.
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 659 class Attribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The value that can be assigned to the attribute when the data type is # enum. # @!attribute [rw] id # @return [::String] # Required. The ID of the allowed value. # * If provided, the same will be used. The service will throw an error if # the specified id is already used by another allowed value in the same # attribute resource. # * If not provided, a system generated id derived from the display name # will be used. In this case, the service will handle conflict resolution # by adding a system generated suffix in case of duplicates. # # This value should be 4-63 characters, and valid characters # are /[a-z][0-9]-/. # @!attribute [rw] display_name # @return [::String] # Required. The display name of the allowed value. # @!attribute [rw] description # @return [::String] # Optional. The detailed description of the allowed value. # @!attribute [rw] immutable # @return [::Boolean] # Optional. When set to true, the allowed value cannot be updated or # deleted by the user. It can only be true for System defined attributes. class AllowedValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enumeration of attribute definition types. module DefinitionType # Attribute definition type unspecified. DEFINITION_TYPE_UNSPECIFIED = 0 # The attribute is predefined by the API Hub. Note that only the list of # allowed values can be updated in this case via UpdateAttribute method. SYSTEM_DEFINED = 1 # The attribute is defined by the user. USER_DEFINED = 2 end # Enumeration for the scope of the attribute representing the resource in the # API Hub to which the attribute can be linked. module Scope # Scope Unspecified. SCOPE_UNSPECIFIED = 0 # Attribute can be linked to an API. API = 1 # Attribute can be linked to an API version. VERSION = 2 # Attribute can be linked to a Spec. SPEC = 3 # Attribute can be linked to an API Operation. API_OPERATION = 4 # Attribute can be linked to a Deployment. DEPLOYMENT = 5 # Attribute can be linked to a Dependency. DEPENDENCY = 6 # Attribute can be linked to a definition. DEFINITION = 7 # Attribute can be linked to a ExternalAPI. EXTERNAL_API = 8 # Attribute can be linked to a Plugin. PLUGIN = 9 end # Enumeration of attribute's data type. module DataType # Attribute data type unspecified. DATA_TYPE_UNSPECIFIED = 0 # Attribute's value is of type enum. ENUM = 1 # Attribute's value is of type json. JSON = 2 # Attribute's value is of type string. STRING = 3 # Attribute's value is of type uri. URI = 4 end end |
#name ⇒ ::String
Returns Identifier. The name of the attribute in the API Hub.
Format:
projects/{project}/locations/{location}/attributes/{attribute}.
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 659 class Attribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The value that can be assigned to the attribute when the data type is # enum. # @!attribute [rw] id # @return [::String] # Required. The ID of the allowed value. # * If provided, the same will be used. The service will throw an error if # the specified id is already used by another allowed value in the same # attribute resource. # * If not provided, a system generated id derived from the display name # will be used. In this case, the service will handle conflict resolution # by adding a system generated suffix in case of duplicates. # # This value should be 4-63 characters, and valid characters # are /[a-z][0-9]-/. # @!attribute [rw] display_name # @return [::String] # Required. The display name of the allowed value. # @!attribute [rw] description # @return [::String] # Optional. The detailed description of the allowed value. # @!attribute [rw] immutable # @return [::Boolean] # Optional. When set to true, the allowed value cannot be updated or # deleted by the user. It can only be true for System defined attributes. class AllowedValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enumeration of attribute definition types. module DefinitionType # Attribute definition type unspecified. DEFINITION_TYPE_UNSPECIFIED = 0 # The attribute is predefined by the API Hub. Note that only the list of # allowed values can be updated in this case via UpdateAttribute method. SYSTEM_DEFINED = 1 # The attribute is defined by the user. USER_DEFINED = 2 end # Enumeration for the scope of the attribute representing the resource in the # API Hub to which the attribute can be linked. module Scope # Scope Unspecified. SCOPE_UNSPECIFIED = 0 # Attribute can be linked to an API. API = 1 # Attribute can be linked to an API version. VERSION = 2 # Attribute can be linked to a Spec. SPEC = 3 # Attribute can be linked to an API Operation. API_OPERATION = 4 # Attribute can be linked to a Deployment. DEPLOYMENT = 5 # Attribute can be linked to a Dependency. DEPENDENCY = 6 # Attribute can be linked to a definition. DEFINITION = 7 # Attribute can be linked to a ExternalAPI. EXTERNAL_API = 8 # Attribute can be linked to a Plugin. PLUGIN = 9 end # Enumeration of attribute's data type. module DataType # Attribute data type unspecified. DATA_TYPE_UNSPECIFIED = 0 # Attribute's value is of type enum. ENUM = 1 # Attribute's value is of type json. JSON = 2 # Attribute's value is of type string. STRING = 3 # Attribute's value is of type uri. URI = 4 end end |
#scope ⇒ ::Google::Cloud::ApiHub::V1::Attribute::Scope
Returns Required. The scope of the attribute. It represents the resource in the API Hub to which the attribute can be linked.
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 659 class Attribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The value that can be assigned to the attribute when the data type is # enum. # @!attribute [rw] id # @return [::String] # Required. The ID of the allowed value. # * If provided, the same will be used. The service will throw an error if # the specified id is already used by another allowed value in the same # attribute resource. # * If not provided, a system generated id derived from the display name # will be used. In this case, the service will handle conflict resolution # by adding a system generated suffix in case of duplicates. # # This value should be 4-63 characters, and valid characters # are /[a-z][0-9]-/. # @!attribute [rw] display_name # @return [::String] # Required. The display name of the allowed value. # @!attribute [rw] description # @return [::String] # Optional. The detailed description of the allowed value. # @!attribute [rw] immutable # @return [::Boolean] # Optional. When set to true, the allowed value cannot be updated or # deleted by the user. It can only be true for System defined attributes. class AllowedValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enumeration of attribute definition types. module DefinitionType # Attribute definition type unspecified. DEFINITION_TYPE_UNSPECIFIED = 0 # The attribute is predefined by the API Hub. Note that only the list of # allowed values can be updated in this case via UpdateAttribute method. SYSTEM_DEFINED = 1 # The attribute is defined by the user. USER_DEFINED = 2 end # Enumeration for the scope of the attribute representing the resource in the # API Hub to which the attribute can be linked. module Scope # Scope Unspecified. SCOPE_UNSPECIFIED = 0 # Attribute can be linked to an API. API = 1 # Attribute can be linked to an API version. VERSION = 2 # Attribute can be linked to a Spec. SPEC = 3 # Attribute can be linked to an API Operation. API_OPERATION = 4 # Attribute can be linked to a Deployment. DEPLOYMENT = 5 # Attribute can be linked to a Dependency. DEPENDENCY = 6 # Attribute can be linked to a definition. DEFINITION = 7 # Attribute can be linked to a ExternalAPI. EXTERNAL_API = 8 # Attribute can be linked to a Plugin. PLUGIN = 9 end # Enumeration of attribute's data type. module DataType # Attribute data type unspecified. DATA_TYPE_UNSPECIFIED = 0 # Attribute's value is of type enum. ENUM = 1 # Attribute's value is of type json. JSON = 2 # Attribute's value is of type string. STRING = 3 # Attribute's value is of type uri. URI = 4 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the attribute was last updated.
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 659 class Attribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The value that can be assigned to the attribute when the data type is # enum. # @!attribute [rw] id # @return [::String] # Required. The ID of the allowed value. # * If provided, the same will be used. The service will throw an error if # the specified id is already used by another allowed value in the same # attribute resource. # * If not provided, a system generated id derived from the display name # will be used. In this case, the service will handle conflict resolution # by adding a system generated suffix in case of duplicates. # # This value should be 4-63 characters, and valid characters # are /[a-z][0-9]-/. # @!attribute [rw] display_name # @return [::String] # Required. The display name of the allowed value. # @!attribute [rw] description # @return [::String] # Optional. The detailed description of the allowed value. # @!attribute [rw] immutable # @return [::Boolean] # Optional. When set to true, the allowed value cannot be updated or # deleted by the user. It can only be true for System defined attributes. class AllowedValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Enumeration of attribute definition types. module DefinitionType # Attribute definition type unspecified. DEFINITION_TYPE_UNSPECIFIED = 0 # The attribute is predefined by the API Hub. Note that only the list of # allowed values can be updated in this case via UpdateAttribute method. SYSTEM_DEFINED = 1 # The attribute is defined by the user. USER_DEFINED = 2 end # Enumeration for the scope of the attribute representing the resource in the # API Hub to which the attribute can be linked. module Scope # Scope Unspecified. SCOPE_UNSPECIFIED = 0 # Attribute can be linked to an API. API = 1 # Attribute can be linked to an API version. VERSION = 2 # Attribute can be linked to a Spec. SPEC = 3 # Attribute can be linked to an API Operation. API_OPERATION = 4 # Attribute can be linked to a Deployment. DEPLOYMENT = 5 # Attribute can be linked to a Dependency. DEPENDENCY = 6 # Attribute can be linked to a definition. DEFINITION = 7 # Attribute can be linked to a ExternalAPI. EXTERNAL_API = 8 # Attribute can be linked to a Plugin. PLUGIN = 9 end # Enumeration of attribute's data type. module DataType # Attribute data type unspecified. DATA_TYPE_UNSPECIFIED = 0 # Attribute's value is of type enum. ENUM = 1 # Attribute's value is of type json. JSON = 2 # Attribute's value is of type string. STRING = 3 # Attribute's value is of type uri. URI = 4 end end |