Class: Google::Cloud::ApiHub::V1::AuthConfig
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::AuthConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
AuthConfig represents the authentication information.
Defined Under Namespace
Classes: ApiKeyConfig, Oauth2ClientCredentialsConfig, UserPasswordConfig
Instance Attribute Summary collapse
-
#api_key_config ⇒ ::Google::Cloud::ApiHub::V1::AuthConfig::ApiKeyConfig
Api Key Config.
-
#auth_type ⇒ ::Google::Cloud::ApiHub::V1::AuthType
Required.
-
#google_service_account_config ⇒ ::Google::Cloud::ApiHub::V1::GoogleServiceAccountConfig
Google Service Account.
-
#oauth2_client_credentials_config ⇒ ::Google::Cloud::ApiHub::V1::AuthConfig::Oauth2ClientCredentialsConfig
Oauth2.0 Client Credentials.
-
#user_password_config ⇒ ::Google::Cloud::ApiHub::V1::AuthConfig::UserPasswordConfig
User Password.
Instance Attribute Details
#api_key_config ⇒ ::Google::Cloud::ApiHub::V1::AuthConfig::ApiKeyConfig
Returns Api Key Config.
Note: The following fields are mutually exclusive: api_key_config, google_service_account_config, user_password_config, oauth2_client_credentials_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1605 class AuthConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters to support Username and Password Authentication. # @!attribute [rw] username # @return [::String] # Required. Username. # @!attribute [rw] password # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. Secret version reference containing the password. # The `secretmanager.versions.access` permission should be # granted to the service account accessing the secret. class UserPasswordConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Parameters to support Oauth 2.0 client credentials grant authentication. # See https://tools.ietf.org/html/rfc6749#section-1.3.4 for more details. # @!attribute [rw] client_id # @return [::String] # Required. The client identifier. # @!attribute [rw] client_secret # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. Secret version reference containing the client secret. # The `secretmanager.versions.access` permission should be # granted to the service account accessing the secret. class Oauth2ClientCredentialsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for authentication with API key. # @!attribute [rw] name # @return [::String] # Required. The parameter name of the API key. # E.g. If the API request is "https://example.com/act?api_key=<API KEY>", # "api_key" would be the parameter name. # @!attribute [rw] api_key # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. The name of the SecretManager secret version resource storing # the API key. Format: # `projects/{project}/secrets/{secrete}/versions/{version}`. The # `secretmanager.versions.access` permission should be granted to the # service account accessing the secret. # @!attribute [rw] http_element_location # @return [::Google::Cloud::ApiHub::V1::AuthConfig::ApiKeyConfig::HttpElementLocation] # Required. The location of the API key. # The default value is QUERY. class ApiKeyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of location an HTTP element can be. module HttpElementLocation # HTTP element location not specified. HTTP_ELEMENT_LOCATION_UNSPECIFIED = 0 # Element is in the HTTP request query. QUERY = 1 # Element is in the HTTP request header. HEADER = 2 # Element is in the HTTP request path. PATH = 3 # Element is in the HTTP request body. BODY = 4 # Element is in the HTTP request cookie. COOKIE = 5 end end end |
#auth_type ⇒ ::Google::Cloud::ApiHub::V1::AuthType
Returns Required. The authentication type.
1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1605 class AuthConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters to support Username and Password Authentication. # @!attribute [rw] username # @return [::String] # Required. Username. # @!attribute [rw] password # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. Secret version reference containing the password. # The `secretmanager.versions.access` permission should be # granted to the service account accessing the secret. class UserPasswordConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Parameters to support Oauth 2.0 client credentials grant authentication. # See https://tools.ietf.org/html/rfc6749#section-1.3.4 for more details. # @!attribute [rw] client_id # @return [::String] # Required. The client identifier. # @!attribute [rw] client_secret # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. Secret version reference containing the client secret. # The `secretmanager.versions.access` permission should be # granted to the service account accessing the secret. class Oauth2ClientCredentialsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for authentication with API key. # @!attribute [rw] name # @return [::String] # Required. The parameter name of the API key. # E.g. If the API request is "https://example.com/act?api_key=<API KEY>", # "api_key" would be the parameter name. # @!attribute [rw] api_key # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. The name of the SecretManager secret version resource storing # the API key. Format: # `projects/{project}/secrets/{secrete}/versions/{version}`. The # `secretmanager.versions.access` permission should be granted to the # service account accessing the secret. # @!attribute [rw] http_element_location # @return [::Google::Cloud::ApiHub::V1::AuthConfig::ApiKeyConfig::HttpElementLocation] # Required. The location of the API key. # The default value is QUERY. class ApiKeyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of location an HTTP element can be. module HttpElementLocation # HTTP element location not specified. HTTP_ELEMENT_LOCATION_UNSPECIFIED = 0 # Element is in the HTTP request query. QUERY = 1 # Element is in the HTTP request header. HEADER = 2 # Element is in the HTTP request path. PATH = 3 # Element is in the HTTP request body. BODY = 4 # Element is in the HTTP request cookie. COOKIE = 5 end end end |
#google_service_account_config ⇒ ::Google::Cloud::ApiHub::V1::GoogleServiceAccountConfig
Returns Google Service Account.
Note: The following fields are mutually exclusive: google_service_account_config, user_password_config, api_key_config, oauth2_client_credentials_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1605 class AuthConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters to support Username and Password Authentication. # @!attribute [rw] username # @return [::String] # Required. Username. # @!attribute [rw] password # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. Secret version reference containing the password. # The `secretmanager.versions.access` permission should be # granted to the service account accessing the secret. class UserPasswordConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Parameters to support Oauth 2.0 client credentials grant authentication. # See https://tools.ietf.org/html/rfc6749#section-1.3.4 for more details. # @!attribute [rw] client_id # @return [::String] # Required. The client identifier. # @!attribute [rw] client_secret # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. Secret version reference containing the client secret. # The `secretmanager.versions.access` permission should be # granted to the service account accessing the secret. class Oauth2ClientCredentialsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for authentication with API key. # @!attribute [rw] name # @return [::String] # Required. The parameter name of the API key. # E.g. If the API request is "https://example.com/act?api_key=<API KEY>", # "api_key" would be the parameter name. # @!attribute [rw] api_key # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. The name of the SecretManager secret version resource storing # the API key. Format: # `projects/{project}/secrets/{secrete}/versions/{version}`. The # `secretmanager.versions.access` permission should be granted to the # service account accessing the secret. # @!attribute [rw] http_element_location # @return [::Google::Cloud::ApiHub::V1::AuthConfig::ApiKeyConfig::HttpElementLocation] # Required. The location of the API key. # The default value is QUERY. class ApiKeyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of location an HTTP element can be. module HttpElementLocation # HTTP element location not specified. HTTP_ELEMENT_LOCATION_UNSPECIFIED = 0 # Element is in the HTTP request query. QUERY = 1 # Element is in the HTTP request header. HEADER = 2 # Element is in the HTTP request path. PATH = 3 # Element is in the HTTP request body. BODY = 4 # Element is in the HTTP request cookie. COOKIE = 5 end end end |
#oauth2_client_credentials_config ⇒ ::Google::Cloud::ApiHub::V1::AuthConfig::Oauth2ClientCredentialsConfig
Returns Oauth2.0 Client Credentials.
Note: The following fields are mutually exclusive: oauth2_client_credentials_config, google_service_account_config, user_password_config, api_key_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1605 class AuthConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters to support Username and Password Authentication. # @!attribute [rw] username # @return [::String] # Required. Username. # @!attribute [rw] password # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. Secret version reference containing the password. # The `secretmanager.versions.access` permission should be # granted to the service account accessing the secret. class UserPasswordConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Parameters to support Oauth 2.0 client credentials grant authentication. # See https://tools.ietf.org/html/rfc6749#section-1.3.4 for more details. # @!attribute [rw] client_id # @return [::String] # Required. The client identifier. # @!attribute [rw] client_secret # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. Secret version reference containing the client secret. # The `secretmanager.versions.access` permission should be # granted to the service account accessing the secret. class Oauth2ClientCredentialsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for authentication with API key. # @!attribute [rw] name # @return [::String] # Required. The parameter name of the API key. # E.g. If the API request is "https://example.com/act?api_key=<API KEY>", # "api_key" would be the parameter name. # @!attribute [rw] api_key # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. The name of the SecretManager secret version resource storing # the API key. Format: # `projects/{project}/secrets/{secrete}/versions/{version}`. The # `secretmanager.versions.access` permission should be granted to the # service account accessing the secret. # @!attribute [rw] http_element_location # @return [::Google::Cloud::ApiHub::V1::AuthConfig::ApiKeyConfig::HttpElementLocation] # Required. The location of the API key. # The default value is QUERY. class ApiKeyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of location an HTTP element can be. module HttpElementLocation # HTTP element location not specified. HTTP_ELEMENT_LOCATION_UNSPECIFIED = 0 # Element is in the HTTP request query. QUERY = 1 # Element is in the HTTP request header. HEADER = 2 # Element is in the HTTP request path. PATH = 3 # Element is in the HTTP request body. BODY = 4 # Element is in the HTTP request cookie. COOKIE = 5 end end end |
#user_password_config ⇒ ::Google::Cloud::ApiHub::V1::AuthConfig::UserPasswordConfig
Returns User Password.
Note: The following fields are mutually exclusive: user_password_config, google_service_account_config, api_key_config, oauth2_client_credentials_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1605 class AuthConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters to support Username and Password Authentication. # @!attribute [rw] username # @return [::String] # Required. Username. # @!attribute [rw] password # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. Secret version reference containing the password. # The `secretmanager.versions.access` permission should be # granted to the service account accessing the secret. class UserPasswordConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Parameters to support Oauth 2.0 client credentials grant authentication. # See https://tools.ietf.org/html/rfc6749#section-1.3.4 for more details. # @!attribute [rw] client_id # @return [::String] # Required. The client identifier. # @!attribute [rw] client_secret # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. Secret version reference containing the client secret. # The `secretmanager.versions.access` permission should be # granted to the service account accessing the secret. class Oauth2ClientCredentialsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for authentication with API key. # @!attribute [rw] name # @return [::String] # Required. The parameter name of the API key. # E.g. If the API request is "https://example.com/act?api_key=<API KEY>", # "api_key" would be the parameter name. # @!attribute [rw] api_key # @return [::Google::Cloud::ApiHub::V1::Secret] # Required. The name of the SecretManager secret version resource storing # the API key. Format: # `projects/{project}/secrets/{secrete}/versions/{version}`. The # `secretmanager.versions.access` permission should be granted to the # service account accessing the secret. # @!attribute [rw] http_element_location # @return [::Google::Cloud::ApiHub::V1::AuthConfig::ApiKeyConfig::HttpElementLocation] # Required. The location of the API key. # The default value is QUERY. class ApiKeyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of location an HTTP element can be. module HttpElementLocation # HTTP element location not specified. HTTP_ELEMENT_LOCATION_UNSPECIFIED = 0 # Element is in the HTTP request query. QUERY = 1 # Element is in the HTTP request header. HEADER = 2 # Element is in the HTTP request path. PATH = 3 # Element is in the HTTP request body. BODY = 4 # Element is in the HTTP request cookie. COOKIE = 5 end end end |