Class: Google::Cloud::ApiHub::V1::ConfigVariable
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ConfigVariable
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
ConfigVariable represents a additional configuration variable present in a PluginInstance Config or AuthConfig, based on a ConfigVariableTemplate.
Defined Under Namespace
Classes: MultiIntValues, MultiSelectValues, MultiStringValues
Instance Attribute Summary collapse
-
#bool_value ⇒ ::Boolean
Optional.
-
#enum_value ⇒ ::Google::Cloud::ApiHub::V1::ConfigValueOption
Optional.
-
#int_value ⇒ ::Integer
Optional.
-
#key ⇒ ::String
readonly
Output only.
-
#multi_int_values ⇒ ::Google::Cloud::ApiHub::V1::ConfigVariable::MultiIntValues
Optional.
-
#multi_select_values ⇒ ::Google::Cloud::ApiHub::V1::ConfigVariable::MultiSelectValues
Optional.
-
#multi_string_values ⇒ ::Google::Cloud::ApiHub::V1::ConfigVariable::MultiStringValues
Optional.
-
#secret_value ⇒ ::Google::Cloud::ApiHub::V1::Secret
Optional.
-
#string_value ⇒ ::String
Optional.
Instance Attribute Details
#bool_value ⇒ ::Boolean
Returns Optional. The config variable value in case of config variable of type boolean.
Note: The following fields are mutually exclusive: bool_value, string_value, int_value, secret_value, enum_value, multi_select_values, multi_string_values, multi_int_values. If a field in that set is populated, all other fields in the set will automatically be cleared.
1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1537 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The config variable value of data type multi select. # @!attribute [rw] values # @return [::Array<::Google::Cloud::ApiHub::V1::ConfigValueOption>] # Optional. The config variable value of data type multi select. class MultiSelectValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi string. # @!attribute [rw] values # @return [::Array<::String>] # Optional. The config variable value of data type multi string. class MultiStringValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi int. # @!attribute [rw] values # @return [::Array<::Integer>] # Optional. The config variable value of data type multi int. class MultiIntValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enum_value ⇒ ::Google::Cloud::ApiHub::V1::ConfigValueOption
Returns Optional. The config variable value in case of config variable of type enum.
Note: The following fields are mutually exclusive: enum_value, string_value, int_value, bool_value, secret_value, multi_select_values, multi_string_values, multi_int_values. If a field in that set is populated, all other fields in the set will automatically be cleared.
1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1537 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The config variable value of data type multi select. # @!attribute [rw] values # @return [::Array<::Google::Cloud::ApiHub::V1::ConfigValueOption>] # Optional. The config variable value of data type multi select. class MultiSelectValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi string. # @!attribute [rw] values # @return [::Array<::String>] # Optional. The config variable value of data type multi string. class MultiStringValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi int. # @!attribute [rw] values # @return [::Array<::Integer>] # Optional. The config variable value of data type multi int. class MultiIntValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#int_value ⇒ ::Integer
Returns Optional. The config variable value in case of config variable of type integer.
Note: The following fields are mutually exclusive: int_value, string_value, bool_value, secret_value, enum_value, multi_select_values, multi_string_values, multi_int_values. If a field in that set is populated, all other fields in the set will automatically be cleared.
1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1537 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The config variable value of data type multi select. # @!attribute [rw] values # @return [::Array<::Google::Cloud::ApiHub::V1::ConfigValueOption>] # Optional. The config variable value of data type multi select. class MultiSelectValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi string. # @!attribute [rw] values # @return [::Array<::String>] # Optional. The config variable value of data type multi string. class MultiStringValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi int. # @!attribute [rw] values # @return [::Array<::Integer>] # Optional. The config variable value of data type multi int. class MultiIntValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#key ⇒ ::String (readonly)
Returns Output only. Key will be the id to uniquely identify the config variable.
1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1537 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The config variable value of data type multi select. # @!attribute [rw] values # @return [::Array<::Google::Cloud::ApiHub::V1::ConfigValueOption>] # Optional. The config variable value of data type multi select. class MultiSelectValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi string. # @!attribute [rw] values # @return [::Array<::String>] # Optional. The config variable value of data type multi string. class MultiStringValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi int. # @!attribute [rw] values # @return [::Array<::Integer>] # Optional. The config variable value of data type multi int. class MultiIntValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#multi_int_values ⇒ ::Google::Cloud::ApiHub::V1::ConfigVariable::MultiIntValues
Returns Optional. The config variable value in case of config variable of type multi integer.
Note: The following fields are mutually exclusive: multi_int_values, string_value, int_value, bool_value, secret_value, enum_value, multi_select_values, multi_string_values. If a field in that set is populated, all other fields in the set will automatically be cleared.
1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1537 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The config variable value of data type multi select. # @!attribute [rw] values # @return [::Array<::Google::Cloud::ApiHub::V1::ConfigValueOption>] # Optional. The config variable value of data type multi select. class MultiSelectValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi string. # @!attribute [rw] values # @return [::Array<::String>] # Optional. The config variable value of data type multi string. class MultiStringValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi int. # @!attribute [rw] values # @return [::Array<::Integer>] # Optional. The config variable value of data type multi int. class MultiIntValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#multi_select_values ⇒ ::Google::Cloud::ApiHub::V1::ConfigVariable::MultiSelectValues
Returns Optional. The config variable value in case of config variable of type multi select.
Note: The following fields are mutually exclusive: multi_select_values, string_value, int_value, bool_value, secret_value, enum_value, multi_string_values, multi_int_values. If a field in that set is populated, all other fields in the set will automatically be cleared.
1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1537 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The config variable value of data type multi select. # @!attribute [rw] values # @return [::Array<::Google::Cloud::ApiHub::V1::ConfigValueOption>] # Optional. The config variable value of data type multi select. class MultiSelectValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi string. # @!attribute [rw] values # @return [::Array<::String>] # Optional. The config variable value of data type multi string. class MultiStringValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi int. # @!attribute [rw] values # @return [::Array<::Integer>] # Optional. The config variable value of data type multi int. class MultiIntValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#multi_string_values ⇒ ::Google::Cloud::ApiHub::V1::ConfigVariable::MultiStringValues
Returns Optional. The config variable value in case of config variable of type multi string.
Note: The following fields are mutually exclusive: multi_string_values, string_value, int_value, bool_value, secret_value, enum_value, multi_select_values, multi_int_values. If a field in that set is populated, all other fields in the set will automatically be cleared.
1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1537 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The config variable value of data type multi select. # @!attribute [rw] values # @return [::Array<::Google::Cloud::ApiHub::V1::ConfigValueOption>] # Optional. The config variable value of data type multi select. class MultiSelectValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi string. # @!attribute [rw] values # @return [::Array<::String>] # Optional. The config variable value of data type multi string. class MultiStringValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi int. # @!attribute [rw] values # @return [::Array<::Integer>] # Optional. The config variable value of data type multi int. class MultiIntValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#secret_value ⇒ ::Google::Cloud::ApiHub::V1::Secret
Returns Optional. The config variable value in case of config variable of type secret.
Note: The following fields are mutually exclusive: secret_value, string_value, int_value, bool_value, enum_value, multi_select_values, multi_string_values, multi_int_values. If a field in that set is populated, all other fields in the set will automatically be cleared.
1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1537 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The config variable value of data type multi select. # @!attribute [rw] values # @return [::Array<::Google::Cloud::ApiHub::V1::ConfigValueOption>] # Optional. The config variable value of data type multi select. class MultiSelectValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi string. # @!attribute [rw] values # @return [::Array<::String>] # Optional. The config variable value of data type multi string. class MultiStringValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi int. # @!attribute [rw] values # @return [::Array<::Integer>] # Optional. The config variable value of data type multi int. class MultiIntValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#string_value ⇒ ::String
Returns Optional. The config variable value in case of config variable of type string.
Note: The following fields are mutually exclusive: string_value, int_value, bool_value, secret_value, enum_value, multi_select_values, multi_string_values, multi_int_values. If a field in that set is populated, all other fields in the set will automatically be cleared.
1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1537 class ConfigVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The config variable value of data type multi select. # @!attribute [rw] values # @return [::Array<::Google::Cloud::ApiHub::V1::ConfigValueOption>] # Optional. The config variable value of data type multi select. class MultiSelectValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi string. # @!attribute [rw] values # @return [::Array<::String>] # Optional. The config variable value of data type multi string. class MultiStringValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The config variable value of data type multi int. # @!attribute [rw] values # @return [::Array<::Integer>] # Optional. The config variable value of data type multi int. class MultiIntValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |