Class: Google::Cloud::ApiHub::V1::ConfigVariable::MultiSelectValues
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ConfigVariable::MultiSelectValues
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
The config variable value of data type multi select.
Instance Attribute Summary collapse
Instance Attribute Details
#values ⇒ ::Array<::Google::Cloud::ApiHub::V1::ConfigValueOption>
Returns Optional. The config variable value of data type multi select.
1545 1546 1547 1548 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1545 class MultiSelectValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |