Class: Google::Cloud::ApiHub::V1::CreateApiOperationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::CreateApiOperationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/apihub_service.rb
Overview
The CreateApiOperation method's request.
Instance Attribute Summary collapse
-
#api_operation ⇒ ::Google::Cloud::ApiHub::V1::ApiOperation
Required.
-
#api_operation_id ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#api_operation ⇒ ::Google::Cloud::ApiHub::V1::ApiOperation
Returns Required. The operation resource to create.
664 665 666 667 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 664 class CreateApiOperationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#api_operation_id ⇒ ::String
Returns Optional. The ID to use for the operation resource, which will become the final component of the operation's resource name. This field is optional.
- If provided, the same will be used. The service will throw an error if the specified id is already used by another operation resource in the API hub.
- If not provided, a system generated id will be used.
This value should be 4-500 characters, overall resource name which
will be of format
projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation},
its length is limited to 700 characters, and valid characters are
/[a-z][A-Z][0-9]-_/.
664 665 666 667 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 664 class CreateApiOperationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource for the operation resource.
Format:
projects/{project}/locations/{location}/apis/{api}/versions/{version}.
664 665 666 667 |
# File 'proto_docs/google/cloud/apihub/v1/apihub_service.rb', line 664 class CreateApiOperationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |