Class: Google::Cloud::ApiHub::V1::CreatePluginInstanceRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::CreatePluginInstanceRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/plugin_service.rb
Overview
The CreatePluginInstance method's request.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#plugin_instance ⇒ ::Google::Cloud::ApiHub::V1::PluginInstance
Required.
-
#plugin_instance_id ⇒ ::String
Optional.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The parent of the plugin instance resource.
Format: projects/{project}/locations/{location}/plugins/{plugin}.
649 650 651 652 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 649 class CreatePluginInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#plugin_instance ⇒ ::Google::Cloud::ApiHub::V1::PluginInstance
Returns Required. The plugin instance to create.
649 650 651 652 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 649 class CreatePluginInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#plugin_instance_id ⇒ ::String
Returns Optional. The ID to use for the plugin instance, which will become the final component of the plugin instance's resource name. This field is optional.
- If provided, the same will be used. The service will throw an error if the specified id is already used by another plugin instance in the plugin resource.
- If not provided, a system generated id will be used.
This value should be 4-63 characters, and valid characters are /[a-z][A-Z][0-9]-_/.
649 650 651 652 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 649 class CreatePluginInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |