Class: Google::Cloud::ApiHub::V1::Curation
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::Curation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/curate_service.rb
Overview
A curation resource in the API Hub.
Defined Under Namespace
Modules: ErrorCode, LastExecutionState Classes: PluginInstanceActionID
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Required.
-
#endpoint ⇒ ::Google::Cloud::ApiHub::V1::Endpoint
Required.
-
#last_execution_error_code ⇒ ::Google::Cloud::ApiHub::V1::Curation::ErrorCode
readonly
Output only.
-
#last_execution_error_message ⇒ ::String
readonly
Output only.
-
#last_execution_state ⇒ ::Google::Cloud::ApiHub::V1::Curation::LastExecutionState
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#plugin_instance_actions ⇒ ::Array<::Google::Cloud::ApiHub::V1::Curation::PluginInstanceActionID>
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the curation was created.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 190 class Curation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The plugin instance and associated action that is using the curation. # @!attribute [r] plugin_instance # @return [::String] # Output only. Plugin instance that is using the curation. # Format is # `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}` # @!attribute [r] action_id # @return [::String] # Output only. The action ID that is using the curation. # This should map to one of the action IDs specified # in action configs in the plugin. class PluginInstanceActionID include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the last execution of the curation. module LastExecutionState # Default unspecified state. LAST_EXECUTION_STATE_UNSPECIFIED = 0 # The last curation execution was successful. SUCCEEDED = 1 # The last curation execution failed. FAILED = 2 end # The error codes for failed executions. module ErrorCode # Default unspecified error code. ERROR_CODE_UNSPECIFIED = 0 # The execution failed due to an internal error. INTERNAL_ERROR = 1 # The curation is not authorized to trigger the endpoint uri. UNAUTHORIZED = 2 end end |
#description ⇒ ::String
Returns Optional. The description of the curation.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 190 class Curation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The plugin instance and associated action that is using the curation. # @!attribute [r] plugin_instance # @return [::String] # Output only. Plugin instance that is using the curation. # Format is # `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}` # @!attribute [r] action_id # @return [::String] # Output only. The action ID that is using the curation. # This should map to one of the action IDs specified # in action configs in the plugin. class PluginInstanceActionID include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the last execution of the curation. module LastExecutionState # Default unspecified state. LAST_EXECUTION_STATE_UNSPECIFIED = 0 # The last curation execution was successful. SUCCEEDED = 1 # The last curation execution failed. FAILED = 2 end # The error codes for failed executions. module ErrorCode # Default unspecified error code. ERROR_CODE_UNSPECIFIED = 0 # The execution failed due to an internal error. INTERNAL_ERROR = 1 # The curation is not authorized to trigger the endpoint uri. UNAUTHORIZED = 2 end end |
#display_name ⇒ ::String
Returns Required. The display name of the curation.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 190 class Curation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The plugin instance and associated action that is using the curation. # @!attribute [r] plugin_instance # @return [::String] # Output only. Plugin instance that is using the curation. # Format is # `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}` # @!attribute [r] action_id # @return [::String] # Output only. The action ID that is using the curation. # This should map to one of the action IDs specified # in action configs in the plugin. class PluginInstanceActionID include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the last execution of the curation. module LastExecutionState # Default unspecified state. LAST_EXECUTION_STATE_UNSPECIFIED = 0 # The last curation execution was successful. SUCCEEDED = 1 # The last curation execution failed. FAILED = 2 end # The error codes for failed executions. module ErrorCode # Default unspecified error code. ERROR_CODE_UNSPECIFIED = 0 # The execution failed due to an internal error. INTERNAL_ERROR = 1 # The curation is not authorized to trigger the endpoint uri. UNAUTHORIZED = 2 end end |
#endpoint ⇒ ::Google::Cloud::ApiHub::V1::Endpoint
Returns Required. The endpoint to be triggered for curation.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 190 class Curation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The plugin instance and associated action that is using the curation. # @!attribute [r] plugin_instance # @return [::String] # Output only. Plugin instance that is using the curation. # Format is # `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}` # @!attribute [r] action_id # @return [::String] # Output only. The action ID that is using the curation. # This should map to one of the action IDs specified # in action configs in the plugin. class PluginInstanceActionID include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the last execution of the curation. module LastExecutionState # Default unspecified state. LAST_EXECUTION_STATE_UNSPECIFIED = 0 # The last curation execution was successful. SUCCEEDED = 1 # The last curation execution failed. FAILED = 2 end # The error codes for failed executions. module ErrorCode # Default unspecified error code. ERROR_CODE_UNSPECIFIED = 0 # The execution failed due to an internal error. INTERNAL_ERROR = 1 # The curation is not authorized to trigger the endpoint uri. UNAUTHORIZED = 2 end end |
#last_execution_error_code ⇒ ::Google::Cloud::ApiHub::V1::Curation::ErrorCode (readonly)
Returns Output only. The error code of the last execution of the curation. The error code is populated only when the last execution state is failed.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 190 class Curation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The plugin instance and associated action that is using the curation. # @!attribute [r] plugin_instance # @return [::String] # Output only. Plugin instance that is using the curation. # Format is # `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}` # @!attribute [r] action_id # @return [::String] # Output only. The action ID that is using the curation. # This should map to one of the action IDs specified # in action configs in the plugin. class PluginInstanceActionID include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the last execution of the curation. module LastExecutionState # Default unspecified state. LAST_EXECUTION_STATE_UNSPECIFIED = 0 # The last curation execution was successful. SUCCEEDED = 1 # The last curation execution failed. FAILED = 2 end # The error codes for failed executions. module ErrorCode # Default unspecified error code. ERROR_CODE_UNSPECIFIED = 0 # The execution failed due to an internal error. INTERNAL_ERROR = 1 # The curation is not authorized to trigger the endpoint uri. UNAUTHORIZED = 2 end end |
#last_execution_error_message ⇒ ::String (readonly)
Returns Output only. Error message describing the failure, if any, during the last execution of the curation.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 190 class Curation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The plugin instance and associated action that is using the curation. # @!attribute [r] plugin_instance # @return [::String] # Output only. Plugin instance that is using the curation. # Format is # `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}` # @!attribute [r] action_id # @return [::String] # Output only. The action ID that is using the curation. # This should map to one of the action IDs specified # in action configs in the plugin. class PluginInstanceActionID include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the last execution of the curation. module LastExecutionState # Default unspecified state. LAST_EXECUTION_STATE_UNSPECIFIED = 0 # The last curation execution was successful. SUCCEEDED = 1 # The last curation execution failed. FAILED = 2 end # The error codes for failed executions. module ErrorCode # Default unspecified error code. ERROR_CODE_UNSPECIFIED = 0 # The execution failed due to an internal error. INTERNAL_ERROR = 1 # The curation is not authorized to trigger the endpoint uri. UNAUTHORIZED = 2 end end |
#last_execution_state ⇒ ::Google::Cloud::ApiHub::V1::Curation::LastExecutionState (readonly)
Returns Output only. The last execution state of the curation.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 190 class Curation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The plugin instance and associated action that is using the curation. # @!attribute [r] plugin_instance # @return [::String] # Output only. Plugin instance that is using the curation. # Format is # `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}` # @!attribute [r] action_id # @return [::String] # Output only. The action ID that is using the curation. # This should map to one of the action IDs specified # in action configs in the plugin. class PluginInstanceActionID include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the last execution of the curation. module LastExecutionState # Default unspecified state. LAST_EXECUTION_STATE_UNSPECIFIED = 0 # The last curation execution was successful. SUCCEEDED = 1 # The last curation execution failed. FAILED = 2 end # The error codes for failed executions. module ErrorCode # Default unspecified error code. ERROR_CODE_UNSPECIFIED = 0 # The execution failed due to an internal error. INTERNAL_ERROR = 1 # The curation is not authorized to trigger the endpoint uri. UNAUTHORIZED = 2 end end |
#name ⇒ ::String
Returns Identifier. The name of the curation.
Format:
projects/{project}/locations/{location}/curations/{curation}.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 190 class Curation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The plugin instance and associated action that is using the curation. # @!attribute [r] plugin_instance # @return [::String] # Output only. Plugin instance that is using the curation. # Format is # `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}` # @!attribute [r] action_id # @return [::String] # Output only. The action ID that is using the curation. # This should map to one of the action IDs specified # in action configs in the plugin. class PluginInstanceActionID include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the last execution of the curation. module LastExecutionState # Default unspecified state. LAST_EXECUTION_STATE_UNSPECIFIED = 0 # The last curation execution was successful. SUCCEEDED = 1 # The last curation execution failed. FAILED = 2 end # The error codes for failed executions. module ErrorCode # Default unspecified error code. ERROR_CODE_UNSPECIFIED = 0 # The execution failed due to an internal error. INTERNAL_ERROR = 1 # The curation is not authorized to trigger the endpoint uri. UNAUTHORIZED = 2 end end |
#plugin_instance_actions ⇒ ::Array<::Google::Cloud::ApiHub::V1::Curation::PluginInstanceActionID> (readonly)
Returns Output only. The plugin instances and associated actions that are using the curation. Note: A particular curation could be used by multiple plugin instances or multiple actions in a plugin instance.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 190 class Curation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The plugin instance and associated action that is using the curation. # @!attribute [r] plugin_instance # @return [::String] # Output only. Plugin instance that is using the curation. # Format is # `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}` # @!attribute [r] action_id # @return [::String] # Output only. The action ID that is using the curation. # This should map to one of the action IDs specified # in action configs in the plugin. class PluginInstanceActionID include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the last execution of the curation. module LastExecutionState # Default unspecified state. LAST_EXECUTION_STATE_UNSPECIFIED = 0 # The last curation execution was successful. SUCCEEDED = 1 # The last curation execution failed. FAILED = 2 end # The error codes for failed executions. module ErrorCode # Default unspecified error code. ERROR_CODE_UNSPECIFIED = 0 # The execution failed due to an internal error. INTERNAL_ERROR = 1 # The curation is not authorized to trigger the endpoint uri. UNAUTHORIZED = 2 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the curation was last updated.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 190 class Curation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The plugin instance and associated action that is using the curation. # @!attribute [r] plugin_instance # @return [::String] # Output only. Plugin instance that is using the curation. # Format is # `projects/{project}/locations/{location}/plugins/{plugin}/instances/{instance}` # @!attribute [r] action_id # @return [::String] # Output only. The action ID that is using the curation. # This should map to one of the action IDs specified # in action configs in the plugin. class PluginInstanceActionID include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the last execution of the curation. module LastExecutionState # Default unspecified state. LAST_EXECUTION_STATE_UNSPECIFIED = 0 # The last curation execution was successful. SUCCEEDED = 1 # The last curation execution failed. FAILED = 2 end # The error codes for failed executions. module ErrorCode # Default unspecified error code. ERROR_CODE_UNSPECIFIED = 0 # The execution failed due to an internal error. INTERNAL_ERROR = 1 # The curation is not authorized to trigger the endpoint uri. UNAUTHORIZED = 2 end end |