Class: Google::Cloud::ApiHub::V1::Deployment
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::Deployment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
Details of the deployment where APIs are hosted. A deployment could represent an Apigee proxy, API gateway, other Google Cloud services or non-Google Cloud services as well. A deployment entity is a root level entity in the API hub and exists independent of any API.
Defined Under Namespace
Classes: AttributesEntry
Instance Attribute Summary collapse
-
#api_versions ⇒ ::Array<::String>
readonly
Output only.
-
#attributes ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues}
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#deployment_type ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Required.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Required.
-
#documentation ⇒ ::Google::Cloud::ApiHub::V1::Documentation
Optional.
-
#endpoints ⇒ ::Array<::String>
Required.
-
#environment ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Optional.
-
#management_url ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Optional.
-
#name ⇒ ::String
Identifier.
-
#resource_uri ⇒ ::String
Required.
-
#slo ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Optional.
-
#source_environment ⇒ ::String
Optional.
-
#source_metadata ⇒ ::Array<::Google::Cloud::ApiHub::V1::SourceMetadata>
readonly
Output only.
-
#source_project ⇒ ::String
Optional.
-
#source_uri ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Optional.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#api_versions ⇒ ::Array<::String> (readonly)
Returns Output only. The API versions linked to this deployment. Note: A particular deployment could be linked to multiple different API versions (of same or different APIs).
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#attributes ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::ApiHub::V1::AttributeValues}
Returns Optional. The list of user defined attributes associated with the
deployment resource. The key is the attribute name. It will be of the
format: projects/{project}/locations/{location}/attributes/{attribute}.
The value is the attribute values associated with the resource.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the deployment was created.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#deployment_type ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Required. The type of deployment.
This maps to the following system defined attribute:
projects/{project}/locations/{location}/attributes/system-deployment-type
attribute.
The number of values for this attribute will be based on the
cardinality of the attribute. The same can be retrieved via GetAttribute
API. All values should be from the list of allowed values defined for the
attribute.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns Optional. The description of the deployment.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#display_name ⇒ ::String
Returns Required. The display name of the deployment.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#documentation ⇒ ::Google::Cloud::ApiHub::V1::Documentation
Returns Optional. The documentation of the deployment.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#endpoints ⇒ ::Array<::String>
Returns Required. The endpoints at which this deployment resource is listening for API requests. This could be a list of complete URIs, hostnames or an IP addresses.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#environment ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Optional. The environment mapping to this deployment.
This maps to the following system defined attribute:
projects/{project}/locations/{location}/attributes/system-environment
attribute.
The number of values for this attribute will be based on the
cardinality of the attribute. The same can be retrieved via GetAttribute
API. All values should be from the list of allowed values defined for the
attribute.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#management_url ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Optional. The uri where users can navigate to for the management of the
deployment. This maps to the following system defined attribute:
projects/{project}/locations/{location}/attributes/system-management-url
The number of values for this attribute will be based on the
cardinality of the attribute. The same can be retrieved via GetAttribute
API. The value of the attribute should be a valid URL.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The name of the deployment.
Format:
projects/{project}/locations/{location}/deployments/{deployment}.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#resource_uri ⇒ ::String
Returns Required. The resource URI identifies the deployment within its gateway.
For Apigee gateways, its recommended to use the format:
organizations/{org}/environments/{env}/apis/{api}.
For ex: if a proxy with name orders is deployed in staging
environment of cymbal organization, the resource URI would be:
organizations/cymbal/environments/staging/apis/orders.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#slo ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Optional. The SLO for this deployment.
This maps to the following system defined attribute:
projects/{project}/locations/{location}/attributes/system-slo
attribute.
The number of values for this attribute will be based on the
cardinality of the attribute. The same can be retrieved via GetAttribute
API. All values should be from the list of allowed values defined for the
attribute.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#source_environment ⇒ ::String
Returns Optional. The environment at source for the deployment. For example: prod, dev, staging, etc.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#source_metadata ⇒ ::Array<::Google::Cloud::ApiHub::V1::SourceMetadata> (readonly)
Returns Output only. The list of sources and metadata from the sources of the deployment.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#source_project ⇒ ::String
Returns Optional. The project to which the deployment belongs. For GCP gateways, this will refer to the project identifier. For others like Edge/OPDK, this will refer to the org identifier.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#source_uri ⇒ ::Google::Cloud::ApiHub::V1::AttributeValues
Returns Optional. The uri where additional source specific information for this
deployment can be found. This maps to the following system defined
attribute:
projects/{project}/locations/{location}/attributes/system-source-uri
The number of values for this attribute will be based on the
cardinality of the attribute. The same can be retrieved via GetAttribute
API. The value of the attribute should be a valid URI, and in case
of Cloud Storage URI, it should point to a Cloud Storage object,
not a directory.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the deployment was last updated.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 480 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ApiHub::V1::AttributeValues] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |