Class: Google::Cloud::ApiHub::V1::DiscoveredApiObservation
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::DiscoveredApiObservation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
Respresents an API Observation observed in one of the sources.
Defined Under Namespace
Modules: SourceType, Style
Instance Attribute Summary collapse
-
#api_operation_count ⇒ ::Integer
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#hostname ⇒ ::String
Optional.
-
#known_operations_count ⇒ ::Integer
readonly
Output only.
-
#last_event_detected_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#name ⇒ ::String
Identifier.
-
#origin ⇒ ::String
Optional.
-
#server_ips ⇒ ::Array<::String>
Optional.
-
#source_locations ⇒ ::Array<::String>
Optional.
-
#source_metadata ⇒ ::Google::Cloud::ApiHub::V1::SourceMetadata
readonly
Output only.
-
#source_types ⇒ ::Array<::Google::Cloud::ApiHub::V1::DiscoveredApiObservation::SourceType>
Optional.
-
#style ⇒ ::Google::Cloud::ApiHub::V1::DiscoveredApiObservation::Style
Optional.
-
#unknown_operations_count ⇒ ::Integer
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#api_operation_count ⇒ ::Integer
Returns Optional. The number of observed API Operations.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Create time stamp of the observation in API Hub.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#hostname ⇒ ::String
Returns Optional. The hostname of requests processed for this Observation.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#known_operations_count ⇒ ::Integer (readonly)
Returns Output only. The number of known API Operations.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#last_event_detected_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. Last event detected time stamp.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#name ⇒ ::String
Returns Identifier. The name of the discovered API Observation.
Format:
projects/{project}/locations/{location}/discoveredApiObservations/{discovered_api_observation}.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#origin ⇒ ::String
Returns Optional. For an observation pushed from a gcp resource, this would be the gcp project id.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#server_ips ⇒ ::Array<::String>
Returns Optional. The IP address (IPv4 or IPv6) of the origin server that the
request was sent to. This field can include port information. Examples:
"192.168.1.1", "10.0.0.1:80", "FE80::0202:B3FF:FE1E:8329".
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#source_locations ⇒ ::Array<::String>
Returns Optional. The location of the observation source.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#source_metadata ⇒ ::Google::Cloud::ApiHub::V1::SourceMetadata (readonly)
Returns Output only. The metadata of the source from which the observation was collected.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#source_types ⇒ ::Array<::Google::Cloud::ApiHub::V1::DiscoveredApiObservation::SourceType>
Returns Optional. The type of the source from which the observation was collected.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#style ⇒ ::Google::Cloud::ApiHub::V1::DiscoveredApiObservation::Style
Returns Optional. Style of ApiObservation.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#unknown_operations_count ⇒ ::Integer (readonly)
Returns Output only. The number of unknown API Operations.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Update time stamp of the observation in API Hub.
1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1776 class DiscoveredApiObservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DiscoveredApiObservation protocol style module Style # Unknown style STYLE_UNSPECIFIED = 0 # Style is Rest API REST = 1 # Style is Grpc API GRPC = 2 # Style is GraphQL API GRAPHQL = 3 end # The possible types of the source from which the observation was collected. module SourceType # Source type not specified. SOURCE_TYPE_UNSPECIFIED = 0 # GCP external load balancer. GCP_XLB = 1 # GCP internal load balancer. GCP_ILB = 2 end end |