Class: Google::Cloud::ApiHub::V1::DiscoveredApiOperation
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::DiscoveredApiOperation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
DiscoveredApiOperation represents an API Operation observed in one of the sources.
Defined Under Namespace
Modules: Classification Classes: MatchResult
Instance Attribute Summary collapse
-
#classification ⇒ ::Google::Cloud::ApiHub::V1::DiscoveredApiOperation::Classification
readonly
Output only.
-
#count ⇒ ::Integer
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#first_seen_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#http_operation ⇒ ::Google::Cloud::ApiHub::V1::HttpOperationDetails
Optional.
-
#last_seen_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#match_results ⇒ ::Array<::Google::Cloud::ApiHub::V1::DiscoveredApiOperation::MatchResult>
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#source_metadata ⇒ ::Google::Cloud::ApiHub::V1::SourceMetadata
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#classification ⇒ ::Google::Cloud::ApiHub::V1::DiscoveredApiOperation::Classification (readonly)
Returns Output only. The classification of the discovered API operation.
1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1847 class DiscoveredApiOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # MatchResult represents the result of matching a discovered API operation # with a catalog API operation. # @!attribute [r] name # @return [::String] # Output only. The name of the matched API Operation. # # Format: # `projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}` class MatchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The classification of the discovered API operation. module Classification # Operation is not classified as known or unknown. CLASSIFICATION_UNSPECIFIED = 0 # Operation has a matched catalog operation. KNOWN = 1 # Operation does not have a matched catalog operation. UNKNOWN = 2 end end |
#count ⇒ ::Integer
Returns Optional. The number of occurrences of this API Operation.
1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1847 class DiscoveredApiOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # MatchResult represents the result of matching a discovered API operation # with a catalog API operation. # @!attribute [r] name # @return [::String] # Output only. The name of the matched API Operation. # # Format: # `projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}` class MatchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The classification of the discovered API operation. module Classification # Operation is not classified as known or unknown. CLASSIFICATION_UNSPECIFIED = 0 # Operation has a matched catalog operation. KNOWN = 1 # Operation does not have a matched catalog operation. UNKNOWN = 2 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Create time stamp of the discovered API operation in API Hub.
1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1847 class DiscoveredApiOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # MatchResult represents the result of matching a discovered API operation # with a catalog API operation. # @!attribute [r] name # @return [::String] # Output only. The name of the matched API Operation. # # Format: # `projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}` class MatchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The classification of the discovered API operation. module Classification # Operation is not classified as known or unknown. CLASSIFICATION_UNSPECIFIED = 0 # Operation has a matched catalog operation. KNOWN = 1 # Operation does not have a matched catalog operation. UNKNOWN = 2 end end |
#first_seen_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. First seen time stamp.
1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1847 class DiscoveredApiOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # MatchResult represents the result of matching a discovered API operation # with a catalog API operation. # @!attribute [r] name # @return [::String] # Output only. The name of the matched API Operation. # # Format: # `projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}` class MatchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The classification of the discovered API operation. module Classification # Operation is not classified as known or unknown. CLASSIFICATION_UNSPECIFIED = 0 # Operation has a matched catalog operation. KNOWN = 1 # Operation does not have a matched catalog operation. UNKNOWN = 2 end end |
#http_operation ⇒ ::Google::Cloud::ApiHub::V1::HttpOperationDetails
Returns Optional. An HTTP Operation.
1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1847 class DiscoveredApiOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # MatchResult represents the result of matching a discovered API operation # with a catalog API operation. # @!attribute [r] name # @return [::String] # Output only. The name of the matched API Operation. # # Format: # `projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}` class MatchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The classification of the discovered API operation. module Classification # Operation is not classified as known or unknown. CLASSIFICATION_UNSPECIFIED = 0 # Operation has a matched catalog operation. KNOWN = 1 # Operation does not have a matched catalog operation. UNKNOWN = 2 end end |
#last_seen_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. Last seen time stamp.
1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1847 class DiscoveredApiOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # MatchResult represents the result of matching a discovered API operation # with a catalog API operation. # @!attribute [r] name # @return [::String] # Output only. The name of the matched API Operation. # # Format: # `projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}` class MatchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The classification of the discovered API operation. module Classification # Operation is not classified as known or unknown. CLASSIFICATION_UNSPECIFIED = 0 # Operation has a matched catalog operation. KNOWN = 1 # Operation does not have a matched catalog operation. UNKNOWN = 2 end end |
#match_results ⇒ ::Array<::Google::Cloud::ApiHub::V1::DiscoveredApiOperation::MatchResult> (readonly)
Returns Output only. The list of matched results for the discovered API operation. This will be populated only if the classification is known. The current usecase is for a single match. Keeping it repeated to support multiple matches in future.
1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1847 class DiscoveredApiOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # MatchResult represents the result of matching a discovered API operation # with a catalog API operation. # @!attribute [r] name # @return [::String] # Output only. The name of the matched API Operation. # # Format: # `projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}` class MatchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The classification of the discovered API operation. module Classification # Operation is not classified as known or unknown. CLASSIFICATION_UNSPECIFIED = 0 # Operation has a matched catalog operation. KNOWN = 1 # Operation does not have a matched catalog operation. UNKNOWN = 2 end end |
#name ⇒ ::String
Returns Identifier. The name of the discovered API Operation.
Format:
projects/{project}/locations/{location}/discoveredApiObservations/{discovered_api_observation}/discoveredApiOperations/{discovered_api_operation}.
1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1847 class DiscoveredApiOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # MatchResult represents the result of matching a discovered API operation # with a catalog API operation. # @!attribute [r] name # @return [::String] # Output only. The name of the matched API Operation. # # Format: # `projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}` class MatchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The classification of the discovered API operation. module Classification # Operation is not classified as known or unknown. CLASSIFICATION_UNSPECIFIED = 0 # Operation has a matched catalog operation. KNOWN = 1 # Operation does not have a matched catalog operation. UNKNOWN = 2 end end |
#source_metadata ⇒ ::Google::Cloud::ApiHub::V1::SourceMetadata (readonly)
Returns Output only. The metadata of the source from which the api operation was collected.
1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1847 class DiscoveredApiOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # MatchResult represents the result of matching a discovered API operation # with a catalog API operation. # @!attribute [r] name # @return [::String] # Output only. The name of the matched API Operation. # # Format: # `projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}` class MatchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The classification of the discovered API operation. module Classification # Operation is not classified as known or unknown. CLASSIFICATION_UNSPECIFIED = 0 # Operation has a matched catalog operation. KNOWN = 1 # Operation does not have a matched catalog operation. UNKNOWN = 2 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Update time stamp of the discovered API operation in API Hub.
1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1847 class DiscoveredApiOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # MatchResult represents the result of matching a discovered API operation # with a catalog API operation. # @!attribute [r] name # @return [::String] # Output only. The name of the matched API Operation. # # Format: # `projects/{project}/locations/{location}/apis/{api}/versions/{version}/operations/{operation}` class MatchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The classification of the discovered API operation. module Classification # Operation is not classified as known or unknown. CLASSIFICATION_UNSPECIFIED = 0 # Operation has a matched catalog operation. KNOWN = 1 # Operation does not have a matched catalog operation. UNKNOWN = 2 end end |