Class: Google::Cloud::ApiHub::V1::ExecutionStatus::LastExecution
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ExecutionStatus::LastExecution
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/plugin_service.rb
Overview
The result of the last execution of the plugin instance.
Defined Under Namespace
Modules: Result
Instance Attribute Summary collapse
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#error_message ⇒ ::String
readonly
Output only.
-
#result ⇒ ::Google::Cloud::ApiHub::V1::ExecutionStatus::LastExecution::Result
readonly
Output only.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The last execution end time of the plugin instance.
494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 494 class LastExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for the result of the last execution of the plugin instance. module Result # Default unspecified execution result. RESULT_UNSPECIFIED = 0 # The plugin instance executed successfully. SUCCEEDED = 1 # The plugin instance execution failed. FAILED = 2 end end |
#error_message ⇒ ::String (readonly)
Returns Output only. Error message describing the failure, if any, during the last execution.
494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 494 class LastExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for the result of the last execution of the plugin instance. module Result # Default unspecified execution result. RESULT_UNSPECIFIED = 0 # The plugin instance executed successfully. SUCCEEDED = 1 # The plugin instance execution failed. FAILED = 2 end end |
#result ⇒ ::Google::Cloud::ApiHub::V1::ExecutionStatus::LastExecution::Result (readonly)
Returns Output only. The result of the last execution of the plugin instance.
494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 494 class LastExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for the result of the last execution of the plugin instance. module Result # Default unspecified execution result. RESULT_UNSPECIFIED = 0 # The plugin instance executed successfully. SUCCEEDED = 1 # The plugin instance execution failed. FAILED = 2 end end |
#start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The last execution start time of the plugin instance.
494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 494 class LastExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for the result of the last execution of the plugin instance. module Result # Default unspecified execution result. RESULT_UNSPECIFIED = 0 # The plugin instance executed successfully. SUCCEEDED = 1 # The plugin instance execution failed. FAILED = 2 end end |