Class: Google::Cloud::ApiHub::V1::HttpOperation
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::HttpOperation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
The HTTP Operation.
Defined Under Namespace
Modules: Method
Instance Attribute Summary collapse
-
#method ⇒ ::Google::Cloud::ApiHub::V1::HttpOperation::Method
Optional.
-
#path ⇒ ::Google::Cloud::ApiHub::V1::Path
Optional.
Instance Attribute Details
#method ⇒ ::Google::Cloud::ApiHub::V1::HttpOperation::Method
Returns Optional. Operation method Note: Even though this field is optional, it is required for CreateApiOperation API and we will fail the request if not provided.
857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 857 class HttpOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of Method types. module Method # Method unspecified. METHOD_UNSPECIFIED = 0 # Get Operation type. GET = 1 # Put Operation type. PUT = 2 # Post Operation type. POST = 3 # Delete Operation type. DELETE = 4 # Options Operation type. OPTIONS = 5 # Head Operation type. HEAD = 6 # Patch Operation type. PATCH = 7 # Trace Operation type. TRACE = 8 end end |
#path ⇒ ::Google::Cloud::ApiHub::V1::Path
Returns Optional. The path details for the Operation. Note: Even though this field is optional, it is required for CreateApiOperation API and we will fail the request if not provided.
857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 857 class HttpOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of Method types. module Method # Method unspecified. METHOD_UNSPECIFIED = 0 # Get Operation type. GET = 1 # Put Operation type. PUT = 2 # Post Operation type. POST = 3 # Delete Operation type. DELETE = 4 # Options Operation type. OPTIONS = 5 # Head Operation type. HEAD = 6 # Patch Operation type. PATCH = 7 # Trace Operation type. TRACE = 8 end end |