Class: Google::Cloud::ApiHub::V1::HttpOperationDetails::Header
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::HttpOperationDetails::Header
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
An aggregation of HTTP header occurrences.
Instance Attribute Summary collapse
-
#count ⇒ ::Integer
The number of occurrences of this Header across transactions.
-
#data_type ⇒ ::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType
Data type of header.
-
#name ⇒ ::String
Header name.
Instance Attribute Details
#count ⇒ ::Integer
Returns The number of occurrences of this Header across transactions.
1935 1936 1937 1938 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1935 class Header include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#data_type ⇒ ::Google::Cloud::ApiHub::V1::HttpOperationDetails::DataType
Returns Data type of header.
1935 1936 1937 1938 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1935 class Header include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |