Class: Google::Cloud::ApiHub::V1::Issue
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::Issue
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/common_fields.rb
Overview
Issue contains the details of a single issue found by the linter.
Instance Attribute Summary collapse
-
#code ⇒ ::String
Required.
-
#message ⇒ ::String
Required.
-
#path ⇒ ::Array<::String>
Required.
-
#range ⇒ ::Google::Cloud::ApiHub::V1::Range
Required.
-
#severity ⇒ ::Google::Cloud::ApiHub::V1::Severity
Required.
Instance Attribute Details
#code ⇒ ::String
Returns Required. Rule code unique to each rule defined in linter.
1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1179 class Issue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#message ⇒ ::String
Returns Required. Human-readable message describing the issue found by the linter.
1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1179 class Issue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#path ⇒ ::Array<::String>
Returns Required. An array of strings indicating the location in the analyzed document where the rule was triggered.
1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1179 class Issue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#range ⇒ ::Google::Cloud::ApiHub::V1::Range
Returns Required. Object describing where in the file the issue was found.
1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1179 class Issue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#severity ⇒ ::Google::Cloud::ApiHub::V1::Severity
Returns Required. Severity level of the rule violation.
1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/apihub/v1/common_fields.rb', line 1179 class Issue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |