Class: Google::Cloud::ApiHub::V1::ListCurationsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ListCurationsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/curate_service.rb
Overview
The [ListCurations][ApiHub.ListCurations] method's request.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. An expression that filters the list of curation resources.
A filter expression consists of a field name, a comparison
operator, and a value for filtering. The value must be a string. The
comparison operator must be one of: <, >, : or =. Filters are case
insensitive.
The following fields in the curation resource are eligible for filtering:
create_time- The time at which the curation was created. The value should be in the (RFC3339)[https://tools.ietf.org/html/rfc3339] format. Allowed comparison operators:>and<.display_name- The display name of the curation. Allowed comparison operators:=.state- The state of the curation. Allowed comparison operators:=.
Expressions are combined with either AND logic operator or OR logical
operator but not both of them together i.e. only one of the AND or OR
operator can be used throughout the filter string and both the operators
cannot be used together. No other logical operators are supported. At most
three filter fields are allowed in the filter string and if provided
more than that then INVALID_ARGUMENT error is returned by the API.
Here are a few examples:
create_time < \"2021-08-15T14:50:00Z\" AND create_time > \"2021-08-10T12:00:00Z\"- The curation resource was created before 2021-08-15 14:50:00 UTC and after 2021-08-10 12:00:00 UTC.
134 135 136 137 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 134 class ListCurationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of curation resources to return. The service may return fewer than this value. If unspecified, at most 50 curations will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
134 135 136 137 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 134 class ListCurationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous ListCurations call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters (except page_size) provided to
ListCurations must match the call that provided the page token.
134 135 136 137 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 134 class ListCurationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent, which owns this collection of curation resources.
Format: projects/{project}/locations/{location}.
134 135 136 137 |
# File 'proto_docs/google/cloud/apihub/v1/curate_service.rb', line 134 class ListCurationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |