Class: Google::Cloud::ApiHub::V1::ListDiscoveredApiObservationsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::ListDiscoveredApiObservationsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/discovery_service.rb
Overview
Message for response to listing DiscoveredApiObservations
Instance Attribute Summary collapse
-
#discovered_api_observations ⇒ ::Array<::Google::Cloud::ApiHub::V1::DiscoveredApiObservation>
The DiscoveredApiObservation from the specified project and location.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#discovered_api_observations ⇒ ::Array<::Google::Cloud::ApiHub::V1::DiscoveredApiObservation>
Returns The DiscoveredApiObservation from the specified project and location.
57 58 59 60 |
# File 'proto_docs/google/cloud/apihub/v1/discovery_service.rb', line 57 class ListDiscoveredApiObservationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
57 58 59 60 |
# File 'proto_docs/google/cloud/apihub/v1/discovery_service.rb', line 57 class ListDiscoveredApiObservationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |