Class: Google::Cloud::ApiHub::V1::Plugin::ConfigTemplate::AuthConfigTemplate
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::Plugin::ConfigTemplate::AuthConfigTemplate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/plugin_service.rb
Overview
AuthConfigTemplate represents the authentication template for a plugin.
Instance Attribute Summary collapse
-
#service_account ⇒ ::Google::Cloud::ApiHub::V1::GoogleServiceAccountConfig
Optional.
-
#supported_auth_types ⇒ ::Array<::Google::Cloud::ApiHub::V1::AuthType>
Required.
Instance Attribute Details
#service_account ⇒ ::Google::Cloud::ApiHub::V1::GoogleServiceAccountConfig
Returns Optional. The service account of the plugin hosting service. This service account should be granted the required permissions on the Auth Config parameters provided while creating the plugin instances corresponding to this plugin.
For example, if the plugin instance auth config requires a secret manager secret, the service account should be granted the secretmanager.versions.access permission on the corresponding secret, if the plugin instance auth config contains a service account, the service account should be granted the iam.serviceAccounts.getAccessToken permission on the corresponding service account.
144 145 146 147 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 144 class AuthConfigTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#supported_auth_types ⇒ ::Array<::Google::Cloud::ApiHub::V1::AuthType>
Returns Required. The list of authentication types supported by the plugin.
144 145 146 147 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 144 class AuthConfigTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |