Class: Google::Cloud::ApiHub::V1::Plugin::HostingService
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::Plugin::HostingService
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/plugin_service.rb
Overview
The information related to the service implemented by the plugin developer, used to invoke the plugin's functionality.
Instance Attribute Summary collapse
-
#service_uri ⇒ ::String
Optional.
Instance Attribute Details
#service_uri ⇒ ::String
Returns Optional. The URI of the service implemented by the plugin developer, used to invoke the plugin's functionality. This information is only required for user defined plugins.
109 110 111 112 |
# File 'proto_docs/google/cloud/apihub/v1/plugin_service.rb', line 109 class HostingService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |