Class: Google::Cloud::ApiHub::V1::SpecMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::ApiHub::V1::SpecMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apihub/v1/collect_service.rb
Overview
The metadata associated with a spec of the API version.
Instance Attribute Summary collapse
-
#original_create_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#original_id ⇒ ::String
Optional.
-
#original_update_time ⇒ ::Google::Protobuf::Timestamp
Required.
-
#spec ⇒ ::Google::Cloud::ApiHub::V1::Spec
Required.
Instance Attribute Details
#original_create_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. Timestamp indicating when the spec was created at the source.
139 140 141 142 |
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 139 class SpecMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#original_id ⇒ ::String
Returns Optional. The unique identifier of the spec in the system where it was originally created.
139 140 141 142 |
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 139 class SpecMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#original_update_time ⇒ ::Google::Protobuf::Timestamp
Returns Required. Timestamp indicating when the spec was last updated at the source.
139 140 141 142 |
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 139 class SpecMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#spec ⇒ ::Google::Cloud::ApiHub::V1::Spec
Returns Required. The spec resource to be pushed to Hub's collect layer. The ID of the spec will be generated by Hub.
139 140 141 142 |
# File 'proto_docs/google/cloud/apihub/v1/collect_service.rb', line 139 class SpecMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |